(function ($, elementor) {
    "use strict";

    var Kihost = {

        init: function () {

            var widgets = {
                'tt-hero-static.default': Kihost.Banner,
                'tt-domain-form.default': Kihost.Domain,
                'at-coming-soon.default': Kihost.ComingSoon,
                'tt-screenshots.default': Kihost.Slider,
                'tt-service-slider.default': Kihost.ServiceSlider,
                'tt-pricing-slider.default': Kihost.VpsSlider,
                'tt-pricing-table-advance.default': Kihost.Pricing,
                'tt-google-map.default': Kihost.GoogleMap,
                'tt-testimonial.default': Kihost.Testimonial,
                'tt-testimonial-two.default': Kihost.TestimonialTwo,
                'tt-logo-carousel.default': Kihost.Logo,
                'tt-popup-video.default': Kihost.PopupVideo,
            };
            $.each(widgets, function (widget, callback) {
                elementor.hooks.addAction('frontend/element_ready/' + widget, callback);
            });

        },

        Domain: function( $scope ) {

            var element = $scope.find('#tt-domain-search');

             /* Domain Check */
             var DomainCheck = {
                submit: function (e) {
                    e.preventDefault();

                    var obj = e.data,
                        el = obj.wap.find("#tt-domain-results"),
                        domainDefault = "themetags.com",
                        basename = obj.input.val() !== "" ? obj.input.val() : domainDefault,
                        ext = obj.select.val() !== "" ? obj.select.val() : '',
                        whmcs_url = obj.whmcs_url.val() !== "" ? obj.whmcs_url.val() : '',
                        extension = DomainCheck.dotExt(obj.input.val());

                    var domainName = "";
                    if (basename.indexOf('.') > -1) {
                        domainName = basename;
                    } else if (basename.indexOf('.') == -1) {
                        domainName = basename + (ext ? '.' + ext : '.com');
                    }

                    obj.security = obj.form.find("input[name=security]").val();
                    obj.el = el;
                    var domainData = {},
                        domainResultTable = $(
                            '<div id="tt_result_item" class="tt-result-domain-box" role="alert"> </div></div>'
                        ),
                        domainResult = $(
                            '<div class="inner-block-result-item">' +
                            '<div class="spinner tt-loading-results text-center">' +
                            '<i class="fas fa-spinner fa-spin fa-lg fa-fw"></i>' +
                            '<span> Seaching...</span>' +
                            '<span class="sr-only">...</span>' +
                            "</div>"
                        );

                    $.extend(domainData, obj);
                    domainData.domain = domainName;
                    domainData.extension = extension;
                    domainData.whmcs_url = whmcs_url;
                    domainData.el = domainResult;

                    domainResult.data("domain", domainData.domain);

                    if (obj.el.find("#tt_result_item").length == 0) {
                        obj.el.append(domainResultTable);
                        obj.el.find("#tt_result_item").append(domainResult);
                    } else {
                        obj.el.find("#tt_result_item").remove();
                        obj.el.append(domainResultTable);
                        obj.el.find("#tt_result_item").append(domainResult);
                    }            

                    DomainCheck.checkAjax(domainData);
                },

                name: function (domain) {
                    return domain.replace(/^.*\/|\.[^.]*$/g, "");
                },

                dotExt: function (ext) {
                    var fExt,
                        tExt = ext.split(".", 3);

                    if (tExt[1] === undefined) {
                        fExt = "com";
                    } else if (tExt[0] === "www") {
                        fExt = tExt[2];
                    } else {
                        fExt = tExt[1];
                    }

                    return fExt;
                },

                checkAjax: function (obj) {
                    var data = {
                        domain: obj.domain,
                        whmcs_url: obj.whmcs_url,
                        action: "tt_ajax_search_domain",
                        security: obj.security,
                    };

                    $.ajax({
                        url: tt_ajax_url,
                        type: "POST",
                        dataType: "json",
                        data: data,
                        success: function (data) {
                            obj.el.find(".spinner").remove();
                            obj.el.append(data.results_html);
                        },
                        error: function (xhr, ajaxOptions, thrownError) {
                            console.log(xhr);
                            console.log(thrownError);
                        },
                    });
                },
            };

            element.is(function () {
                var id = $(this),
                    submitEl = id.find("#tt-search"),
                    inputEl = id.find("#tt-domain"),
                    selectEl = id.find("#domainext"),
                    formEl = id.find("#tt-domain-form"),
                    acEl = id.find('input[name="whmcs_url"]'),
                    data;

                data = {
                    submit: submitEl,
                    input: inputEl,
                    select: selectEl,
                    whmcs_url: acEl,
                    form: formEl,
                    div: id,
                    wap: id,
                };

                submitEl.attr("disabled", true);
                inputEl.keyup(function () {
                    if ($(this).val().length != 0) submitEl.attr("disabled", false);
                    else submitEl.attr("disabled", true);
                });

                submitEl.on("click", data, DomainCheck.submit);
            });

            // Loading Screen
            const loadingClass = $(".loading"),
                removeFLow = $("html,body").css("overflow", "auto");

            if (loadingClass.length === 1) {
                $(window).on("load", function () {
                    loadingClass.fadeOut();
                    removeFLow;
                });
            }
        },

        Pricing: function ($scope) {
            var element = $scope.find('#js-contcheckbox');
            element.change(function () {
                if (this.checked) {
				    $('.monthly-price').css('display', 'none');
				    $('.yearly-price').css('display', 'block');
                    $('.switch-icon').addClass('yearly');	
                    $('.switch-icon').removeClass('monthly');			
				} else {
				    $('.monthly-price').css('display', 'block');
				    $('.yearly-price').css('display', 'none');
                    $('.switch-icon').removeClass('yearly');
                    $('.switch-icon').addClass('monthly');					
				}
            });
        },

        GoogleMap: function ($scope) {
            var map = $scope.find('.gmap3-area');

            map.each(function () {
                var $this = $(this),
                    key = $this.data('key'),
                    lat = $this.data('lat'),
                    lng = $this.data('lng'),
                    mrkr = $this.data('mrkr'),
                    zoom = $this.data('zoom'),
                    scrollwheel = $this.data('scrollwheel') || false;

                $this.gmap3({
                    center: [lat, lng],
                    zoom: zoom,
                    scrollwheel: scrollwheel,
                    mapTypeId: google.maps.MapTypeId.ROADMAP,
                    styles: [
                        {
                            "featureType": "administrative",
                            "elementType": "labels.text.fill",
                            "stylers": [
                                {
                                    "color": "#444444"
                                }
                            ]
                        },
                        {
                            "featureType": "landscape",
                            "elementType": "all",
                            "stylers": [
                                {
                                    "color": "#f2f2f2"
                                }
                            ]
                        },
                        {
                            "featureType": "poi",
                            "elementType": "all",
                            "stylers": [
                                {
                                    "visibility": "off"
                                }
                            ]
                        },
                        {
                            "featureType": "road",
                            "elementType": "all",
                            "stylers": [
                                {
                                    "saturation": -100
                                },
                                {
                                    "lightness": 45
                                }
                            ]
                        },
                        {
                            "featureType": "road.highway",
                            "elementType": "all",
                            "stylers": [
                                {
                                    "visibility": "simplified"
                                }
                            ]
                        },
                        {
                            "featureType": "road.arterial",
                            "elementType": "labels.icon",
                            "stylers": [
                                {
                                    "visibility": "off"
                                }
                            ]
                        },
                        {
                            "featureType": "transit",
                            "elementType": "all",
                            "stylers": [
                                {
                                    "visibility": "off"
                                }
                            ]
                        },
                        {
                            "featureType": "water",
                            "elementType": "all",
                            "stylers": [
                                {
                                    "color": "#cbcbcb"
                                },
                                {
                                    "visibility": "on"
                                }
                            ]
                        }
                    ]
                })
                // .marker(function (map) {
                //     return {
                //         position: map.getCenter(),
                //         icon: mrkr
                //     };
                // })

            });

        },

        Banner: function ($scope) {
            var counting = $scope.find('.countdown');

            counting.each(function (index, value) {
                var count_year = $(this).attr("data-count-year");
                var count_month = $(this).attr("data-count-month");
                var count_day = $(this).attr("data-count-day");
                var count_date = count_year + '/' + count_month + '/' + count_day;
                $(this).countdown(count_date, function (event) {
                    $(this).html(
                        event.strftime('<div class="counting"><span class="CountdownContent">%D<span class="CountdownLabel">Days</span></span><span class="CountdownSeparator">:</span></div><div class="counting"><span class="CountdownContent">%H <span class="CountdownLabel">Hours</span></span><span class="CountdownSeparator">:</span></div><div class="counting"><span class="CountdownContent">%M <span class="CountdownLabel">Minutes</span></span><span class="CountdownSeparator">:</span></div><div class="counting"><span class="CountdownContent">%S <span class="CountdownLabel">Seconds</span></span></div>')
                    );
                });
            });
        },

        ComingSoon: function ($scope) {
            var counting = $scope.find('.countdown');

            counting.each(function (index, value) {
                var count_year = $(this).attr("data-count-year");
                var count_month = $(this).attr("data-count-month");
                var count_day = $(this).attr("data-count-day");
                var count_date = count_year + '/' + count_month + '/' + count_day;
                $(this).countdown(count_date, function (event) {
                    $(this).html(
                        event.strftime('<div class="counting"><span class="CountdownContent">%D<span class="CountdownLabel">Days</span></span><span class="CountdownSeparator">:</span></div><div class="counting"><span class="CountdownContent">%H <span class="CountdownLabel">Hours</span></span><span class="CountdownSeparator">:</span></div><div class="counting"><span class="CountdownContent">%M <span class="CountdownLabel">Minutes</span></span><span class="CountdownSeparator">:</span></div><div class="counting"><span class="CountdownContent">%S <span class="CountdownLabel">Seconds</span></span></div>')
                    );
                });
            });
        },

        Slider: function ($scope) {
            var slideInit = $scope.find('[data-swiper]');

            slideInit.each(function () {
                var swps = document.querySelectorAll('[data-swiper]');

                if (swps.length > 0) {
                    swps.forEach(function (swp) {
                        var config = JSON.parse(swp.getAttribute('data-swiper'));
                        var mySwiper = new Swiper(swp, config);

                        $('.swiper-slide').on('mouseover', function () {
                            mySwiper.autoplay.stop();
                        });

                        $('.swiper-slide').on('mouseout', function () {
                            mySwiper.autoplay.start();
                        });
                    });

                }
            });
        },

        VpsSlider: function($scope) {
            // var cPlan = $('#c-plan');

            var cPlan = $scope.find('#c-plan');

            if (cPlan.length) {
    
                cPlan.slider({
                    tooltip: 'always'
                });
                cPlan.on("slide", function (e) {
    
                    $.each(vpsPriceInfo, function (index, vpsObj) {
                        if (vpsObj.vpsCore == e.value) {
                            setVpsValue(vpsObj);
                        }
                    });
                });
    
                initSlider();
            }
    
            function initSlider() {
    
    
                cPlan.value = cPlan.data("slider-value");
                var defaultVpsCore = parseInt(cPlan.value);
                $.each(vpsPriceInfo, function (index, vpsObj) {
                    // defaultVpsCore is default valeu to show. For my demo, I have set 6 from HTML.
                    // vps-hosting.html: <input id="c-plan" type="text" data-slider-min="1" data-slider-max="12" data-slider-step="1" data-slider-value="6" data-currency="$" data-unit="GB">. 
                    // You need to change accourting to your need.
                    if (vpsObj.vpsCore == defaultVpsCore) {
                        $('.slider .tooltip', '#custom-plan').append('<div class="tooltip-up"></div>');
                        $('.slider .tooltip-inner', '#custom-plan').attr("data-unit", cPlan.data("unit"));
                        $('.slider .tooltip-up', '#custom-plan').attr("data-currency", cPlan.data("currency"));
                        setVpsValue(vpsObj);
                    }
                });
            }
    
            function setVpsValue(vpsObj) {
                $('.slider .tooltip-up', '#custom-plan').text(vpsObj.vpsCore);
                $('.vpsPrice', '#custom-plan').text(cPlan.data("currency") + vpsObj.vpsPrice);
                $('.vpsCore span', '#custom-plan').text(vpsObj.vpsCore);
                $('.vpsMemory span', '#custom-plan').text(vpsObj.vpsMemory);
                $('.vpsStorage span', '#custom-plan').text(vpsObj.vpsStorage);
                $('.vpsBandwidth span', '#custom-plan').text(vpsObj.vpsBandwidth);
                $('.vpsWHmcsUrl', '#custom-plan').attr("href", vpsObj.vpsWHmcsUrl);
            }
        },


        Testimonial: function ($scope) {
            var slideInit = $scope.find('[data-testi]');

            slideInit.each(function () {
                var swps = document.querySelectorAll('[data-testi]');

                if (swps.length > 0) {
                    swps.forEach(function (swp) {
                        var config = JSON.parse(swp.getAttribute('data-testi'));
                        var mySwiper = new Swiper(swp, config);

                        $('.swiper-slide').on('mouseover', function () {
                            mySwiper.autoplay.stop();
                        });

                        $('.swiper-slide').on('mouseout', function () {
                            mySwiper.autoplay.start();
                        });
                    });
                }
            });
        },        
        
        ServiceSlider: function ($scope) {
            var slideInit = $scope.find('[data-service]');

            slideInit.each(function () {
                var swps = document.querySelectorAll('[data-service]');

                if (swps.length > 0) {
                    swps.forEach(function (swp) {
                        var config = JSON.parse(swp.getAttribute('data-service'));
                        var mySwiper = new Swiper(swp, config);

                        $('.swiper-slide').on('mouseover', function () {
                            mySwiper.autoplay.stop();
                        });

                        $('.swiper-slide').on('mouseout', function () {
                            mySwiper.autoplay.start();
                        });
                    });
                }
            });
        },


        TestimonialTwo: function ($scope) {
            var slideInit = $scope.find('[data-testi-two]');

            slideInit.each(function () {
                var swps = document.querySelectorAll('[data-testi-two]');

                if (swps.length > 0) {
                    swps.forEach(function (swp) {
                        var config = JSON.parse(swp.getAttribute('data-testi-two'));
                        var mySwiper = new Swiper(swp, config);

                        $('.swiper-slide').on('mouseover', function () {
                            mySwiper.autoplay.stop();
                        });

                        $('.swiper-slide').on('mouseout', function () {
                            mySwiper.autoplay.start();
                        });
                    });
                }
            });
        },

        Logo: function ($scope) {

            var slideInit = $scope.find('[data-logo]');

            slideInit.each(function () {
                var swps = document.querySelectorAll('[data-logo]');

                if (swps.length > 0) {
                    swps.forEach(function (swp) {
                        var config = JSON.parse(swp.getAttribute('data-logo'));
                        var mySwiper = new Swiper(swp, config);

                        $('.swiper-slide').on('mouseover', function () {
                            mySwiper.autoplay.stop();
                        });

                        $('.swiper-slide').on('mouseout', function () {
                            mySwiper.autoplay.start();
                        });
                    });

                }


            });
        },

        PopupVideo: function ($scope) {
            var popup = $scope.find('.popup-video');
            popup.each(function () {
                popup.magnificPopup({
                    type: 'iframe'
                });
            });
        }


    };
    $(window).on('elementor/frontend/init', Kihost.init);
}(jQuery, window.elementorFrontend));