<?php

/**
 *
 * Get Catagories/Taxonomies List
 * @since 1.0.0
 *
 */
if ( ! function_exists( 'kihost_category_list' ) ) {

	function kihost_category_list( $cat ) {
		$query_args = array(
			'orderby'    => 'ID',
			'order'      => 'DESC',
			'hide_empty' => 1,
			'taxonomy'   => $cat
		);

		$categories = get_categories( $query_args );
		$options    = array( esc_html__( '0', 'qhost-core' ) => 'All Category' );
		if ( is_array( $categories ) && count( $categories ) > 0 ) {
			foreach ( $categories as $cat ) {
				$options[ $cat->term_id ] = $cat->name;
			}

			return $options;
		}
	}

}


/**
 * Get Currency symbol
 *
 * it will use in elementor element to change the currency select to only symbol
 *
 * @param $symbol_name : the currency that will select
 *
 * @return mixed|string : symbol
 */
function wdes_get_currency_symbol( $symbol_name ) {
	$symbols = [
		'dollar'       => '&#36;',
		'euro'         => '&#128;',
		'franc'        => '&#8355;',
		'pound'        => '&#163;',
		'ruble'        => '&#8381;',
		'shekel'       => '&#8362;',
		'baht'         => '&#3647;',
		'yen'          => '&#165;',
		'won'          => '&#8361;',
		'guilder'      => '&fnof;',
		'peso'         => '&#8369;',
		'peseta'       => '&#8359',
		'lira'         => '&#8356;',
		'rupee'        => '&#8360;',
		'indian_rupee' => '&#8377;',
		'real'         => 'R$',
		'krona'        => 'kr',
	];

	return isset( $symbols[ $symbol_name ] ) ? $symbols[ $symbol_name ] : '';
}

//	static public function niro_category_list( $cat ) {
//			$query_args = array(
//				'orderby'    => 'ID',
//				'order'      => 'DESC',
//				'hide_empty' => 1,
//				'taxonomy'   => $cat
//			);
//
//			$categories  = get_categories( $query_args );
//
//			$options     = array( esc_html__( '0', 'qhost-core' ) => 'All Category' );
//			if ( is_array( $categories ) && count( $categories ) > 0 ) {
//				foreach ( $categories as $cat ) {
//					$options[ $cat->slug ] = $cat->name;
//				}
//				return $options;
//			}
//		}
//

function kihost_addons_get_contact_form7_forms() {
	$forms = get_posts( 'post_type=wpcf7_contact_form&posts_per_page=-1' );

	$results = array();
	if ( $forms ) {
		$results[] = __( 'Select A Form', 'qhost-core' );
		foreach ( $forms as $form ) {
			$results[ $form->ID ] = $form->post_title;
		}
		// array_unshift( $results, __( 'Select A Form', 'qhost-core' ) );
		// $results[] = __( 'Select A Form', 'qhost-core' );
	} else {
		$results[] = __( 'No contact forms found', 'qhost-core' );
	}

	return $results;
}

//Add extra profile information
add_action( 'show_user_profile', 'kihost_extra_user_profile_fields' );
add_action( 'edit_user_profile', 'kihost_extra_user_profile_fields' );

function kihost_extra_user_profile_fields( $user ) { ?>
    <h3><?php esc_html_e( "Extra profile information", 'qhost-core' ); ?></h3>

    <table class="form-table">
        <tr>
            <th><label for="facebook"><?php esc_html_e( "Facebook", 'qhost-core' ); ?></label></th>
            <td>
                <input type="text" name="facebook" id="facebook"
                       value="<?php echo esc_attr( get_the_author_meta( 'facebook', $user->ID ) ); ?>"
                       class="regular-text"/><br/>
                <span class="description"><?php esc_html_e( "Please enter your facebook url.", 'qhost-core' ); ?></span>
            </td>
        </tr>
        <tr>
            <th><label for="twitter"><?php esc_html_e( "Twitter", 'qhost-core' ); ?></label></th>
            <td>
                <input type="text" name="twitter" id="twitter"
                       value="<?php echo esc_attr( get_the_author_meta( 'twitter', $user->ID ) ); ?>"
                       class="regular-text"/><br/>
                <span class="description"><?php esc_html_e( "Please enter your twitter url.", 'qhost-core' ); ?></span>
            </td>
        </tr>
        <tr>
            <th><label for="linkedin"><?php esc_html_e( "Linkedin", 'qhost-core' ); ?></label></th>
            <td>
                <input type="text" name="linkedin" id="linkedin"
                       value="<?php echo esc_attr( get_the_author_meta( 'linkedin', $user->ID ) ); ?>"
                       class="regular-text"/><br/>
                <span class="description"><?php esc_html_e( "Please enter your linkedin url.", 'qhost-core' ); ?></span>
            </td>
        </tr>

        <tr>
            <th><label for="instagram"><?php esc_html_e( "Instagram", 'qhost-core' ); ?></label></th>
            <td>
                <input type="text" name="instagram" id="instagram"
                       value="<?php echo esc_attr( get_the_author_meta( 'instagram', $user->ID ) ); ?>"
                       class="regular-text"/><br/>
                <span class="description"><?php esc_html_e( "Please enter your instagram url.", 'qhost-core' ); ?></span>
            </td>
        </tr>
    </table>
<?php }

add_action( 'personal_options_update', 'kihost_name_save_extra_user_profile_fields' );
add_action( 'edit_user_profile_update', 'kihost_name_save_extra_user_profile_fields' );

function kihost_name_save_extra_user_profile_fields( $user_id ) {
	if ( ! current_user_can( 'edit_user', $user_id ) ) {
		return false;
	}
	update_user_meta( $user_id, 'instagram', $_POST['instagram'] );
	update_user_meta( $user_id, 'facebook', $_POST['facebook'] );
	update_user_meta( $user_id, 'linkedin', $_POST['linkedin'] );
	update_user_meta( $user_id, 'twitter', $_POST['twitter'] );
}

