<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

class Qhost_Accordion extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'tt-accordion';
	}

	public function get_title() {
		return __( 'Qhost Accordion', 'qhost-core' );
	}

	public function get_icon() {
		// Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
		return 'eicon-accordion';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_acc',
			[
				'label' => __( 'Content', 'qhost-core' ),
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'accordion_title', [
				'label'       => __( 'Title', 'qhost-core' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => __( 'List Title', 'qhost-core' ),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'accordion_content', [
				'label'      => __( 'Content', 'qhost-core' ),
				'type'       => \Elementor\Controls_Manager::WYSIWYG,
				'default'    => __( 'List Content', 'qhost-core' ),
				'show_label' => false,
			]
		);

		$repeater->add_control(
			'list_color',
			[
				'label'     => __( 'Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}}' => 'color: {{VALUE}}'
				],
			]
		);

		$this->add_control(
			'tt-accordion',
			[
				'label'       => __( 'Accordion List', 'qhost-core' ),
				'type'        => \Elementor\Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'accordion_title'   => __( 'Which license do I need?', 'qhost-core' ),
						'accordion_content' => __( 'Nihil anim keffiyeh helvetica, craft beer labore wes anderson cred nesciunt sapiente ea proident. Ad vegan excepteur butcher vice lomo. Leggings occaecat craft beer farm-to-table, raw denim aesthetic synth nesciunt you probably haven\'t heard of them accusamus labore sustainable VHS.', 'qhost-core' ),
					],
					[
						'accordion_title'   => __( 'How do I get access to a theme?', 'qhost-core' ),
						'accordion_content' => __( 'Nihil anim keffiyeh helvetica, craft beer labore wes anderson cred nesciunt sapiente ea proident. Ad vegan excepteur butcher vice lomo. Leggings occaecat craft beer farm-to-table, raw denim aesthetic synth nesciunt you probably haven\'t heard of them accusamus labore sustainable VHS.', 'qhost-core' ),
					],
					[
						'accordion_title'   => __( 'How do I see previous orders?', 'qhost-core' ),
						'accordion_content' => __( 'Nihil anim keffiyeh helvetica, craft beer labore wes anderson cred nesciunt sapiente ea proident. Ad vegan excepteur butcher vice lomo. Leggings occaecat craft beer farm-to-table, raw denim aesthetic synth nesciunt you probably haven\'t heard of them accusamus labore sustainable VHS.', 'qhost-core' ),
					],
					[
						'accordion_title'   => __( 'Support related issues for the template?', 'qhost-core' ),
						'accordion_content' => __( 'Nihil anim keffiyeh helvetica, craft beer labore wes anderson cred nesciunt sapiente ea proident. Ad vegan excepteur butcher vice lomo. Leggings occaecat craft beer farm-to-table, raw denim aesthetic synth nesciunt you probably haven\'t heard of them accusamus labore sustainable VHS.', 'qhost-core' ),
					],
				],
				'title_field' => '{{{ accordion_title }}}',
			]
		);

		$this->end_controls_section();


		/**
		 *  Accordian Style Controls
		 */

		$this->start_controls_section(
			'title_style_section',
			[
				'label' => __( 'Title', 'qhost-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'title_typography',
				'label'    => __( 'Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .faq .card .card-header .btn-link',
			]
		);

		$this->add_control(
			'faq_title_color',
			[
				'label'     => __( 'Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .faq .card .card-header .btn-link.collapsed' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'faq_title_bg_color',
			[
				'label'     => __( 'Background Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .faq .card .card-header .btn-link.collapsed' => 'background: {{VALUE}}',
				],
			]
		);	

		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'box_shadow',
				'label' => __( 'Box Shadow', 'plugin-domain' ),
				'selector' => '{{WRAPPER}} .faq .card .card-header',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'content_style_section',
			[
				'label' => __( 'Content', 'qhost-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'faq_content_typography',
				'label'    => __( 'Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .faq .card .card-body',
			]
		);

		$this->add_control(
			'faq_content_color',
			[
				'label'     => __( 'Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .faq .card .card-body' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'title_faq_section',
			[
				'label' => __( 'Faq Active', 'qhost-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'heading_color_type',
			array(
				'label'        => __( 'Color Type', 'qhost-core' ),
				'type'         => Controls_Manager::SELECT,
				'options'      => array(
					'color'    => __( 'Color', 'qhost-core' ),
					'gradient' => __( 'Background', 'qhost-core' ),
				),
				'default'      => 'color',
				'prefix_class' => 'tt-heading-fill-',
			)
		);

		$this->add_control(
			'subtitle_color', [
				'label'     => esc_html__( 'Background Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .faq .card .card-header .btn-link:not(.collapsed)' => 'background: {{VALUE}};',
				],
				'condition' => array(
					'heading_color_type' => 'color',
				),
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			array(
				'name'     => 'heading_color_gradient',
				'types'    => array( 'gradient', 'classic' ),
				'selector' => '{{WRAPPER}} .faq .card .card-header .btn-link:not(.collapsed)',

				'condition' => array(
					'heading_color_type' => 'gradient',
				),
			)
		);

		$this->add_control(
			'faq_title_active_color',
			[
				'label'     => __( 'Active Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .faq .card .card-header .btn-link:not(.collapsed)' => 'color: {{VALUE}}',
				],
			]
		);


		$this->end_controls_section();


	}

	protected function render() {

		$settings  = $this->get_settings_for_display();
		$accordion = $settings['tt-accordion'];

		$faq_id = 'apdash-accordion-' . substr( $this->get_id_int(), 0, 3 );
		$faq_o  = 'apdash-acco-' . substr( $this->get_id_int(), 0, 3 );
		?>

      
		<div class="tt-accordien">

			<div class="faq pixFade" id="<?php echo esc_attr( $faq_id ); ?>">

				<?php foreach ( $accordion as $index => $item ) :

					$tab_btn_setting_key = $this->get_repeater_setting_key( 'accordion_title', '', $index );

					$this->add_render_attribute( $tab_btn_setting_key, [
						'class'         => [ $index == 0 ? 'btn btn-link' : 'btn btn-link collapsed' ],
						'data-toggle'   => 'collapse',
						'data-target'   => '#' . 'faq-collapse-' . $faq_o . '-' . $index,
						'aria-expanded' => $index == 0 ? 'true' : 'false',
					] );

					$tab_body_setting_key = $this->get_repeater_setting_key( 'accordion_content', '', $index );

					$this->add_render_attribute( $tab_body_setting_key, [
						'id'          => 'faq-collapse-' . $faq_o . '-' . $index,
						'class'       => [ $index == 0 ? 'collapse show' : 'collapse' ],
						'data-parent' => "#" . $faq_id
					] ); ?>

					<div class="card <?php echo $index == 0 ? 'active' : ''; ?>">
						<div class="card-header" id="<?php echo $faq_o . '-' . $index; ?>">
							<h5 class="mb-0">
								<button <?php echo $this->get_render_attribute_string( $tab_btn_setting_key ); ?>>
									<?php echo $item['accordion_title']; ?>
								</button>
							</h5>
						</div>
						<div <?php echo $this->get_render_attribute_string( $tab_body_setting_key ); ?>>
							<div class="card-body">
								<?php echo $item['accordion_content']; ?>
							</div>
						</div>
					</div>
				<?php endforeach; ?>
			</div>
		</div>
   

		<?php


	}

	protected function _content_template() {
	}

}