<?php
namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}


/**
 * Get About.
 *
 * Retrieve Apdash Post.
 *
 * @since 1.0.0
 * @access public
 *
 * @return string Qhost Post.
 */

class Qhost_Post extends Widget_Base {

    public $base;

    public function get_name() {
        return 'tt-blog';
    }

    public function get_title() {
        return esc_html__( 'Qhost Posts', 'qhost-core' );
    }

    public function get_icon() {
        return 'eicon-posts-grid';
    }

    public function get_categories() {
        return [ 'tt-elements' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_tab',
            [
                'label' => esc_html__('Blog Post', 'qhost-core'),
            ]
        );

        $this->add_control(
            'post_count',
            [
                'label'         => esc_html__( 'Post count', 'qhost-core' ),
                'type'          => Controls_Manager::NUMBER,
                'default'       => esc_html__( '3', 'qhost-core' ),

            ]
        );

        $this->add_control(
            'count_col',
            [
                'label'     => esc_html__( 'Select Column', 'qhost-core' ),
                'type'      => Controls_Manager::SELECT,
                'default'   => 4,
                'options'   => [
                    '6'     => esc_html__( '2 Column', 'qhost-core' ),
                    '4'     => esc_html__( '3 Column', 'qhost-core' ),
                ],
            ]
        );

        $this->add_control(
            'post_cat',
            [
                'label'    =>esc_html__( 'Select category', 'qhost-core' ),
                'type'     => Controls_Manager::SELECT2,
                'multiple' => true,
                'label_block' => true,
                'options'  => kihost_category_list( 'category' ),
                'default'  => '0'
            ]
        ); 

        $this->end_controls_section();

        $this->start_controls_section(
            'section_subtitle_style', [
                'label'	 =>esc_html__( 'Title', 'qhost-core' ),
                'tab'	 => Controls_Manager::TAB_STYLE,
            ]
        ); 
        
        $this->add_control(
			'blog_title_color',
			[
				'label' => __( 'Color', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,			
				'selectors' => [
                    '{{WRAPPER}} .post-grid .blog-content .entry-title a, 
                    {{WRAPPER}}  .single_blog_post .post_content h4 a' => 'color: {{VALUE}}',
				],
			]
        );

        $this->add_control(
			'blog_title_color_hover',
			[
				'label' => __( 'Hover Color', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,			
				'selectors' => [
                    '{{WRAPPER}} .post-grid .blog-content .entry-title a:hover, 
                    {{WRAPPER}}  .single_blog_post .post_content h4 a:hover' => 'color: {{VALUE}}',
				],
			]
        );
        
        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'label' => __( 'Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .entry-title',
			]
		);

        $this->end_controls_section();

        $this->start_controls_section(
			'background_shape',
			[
				'label' => __( 'Meta', 'qhost-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );

        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'meta_typography',
				'label' => __( 'Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .single_blog_post .date h2',
			]
		);

        
        $this->add_control(
            'meta_show',
            [
                'label' => __( 'Post meta', 'qhost-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => __( 'Yes', 'qhost-core' ),
                'label_off' => __( 'No', 'qhost-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
			'title_color',
			[
				'label' => __( 'Color', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,		
				'selectors' => [
					'{{WRAPPER}} .post-meta li, {{WRAPPER}} .post-meta li.author a' => 'color: {{VALUE}}',
				],
			]
		);        

        $this->add_control(
			'title_color_hover',
			[
				'label' => __( 'Hover Color', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,		
				'selectors' => [
					'{{WRAPPER}} .post-meta li.author a:hover' => 'color: {{VALUE}}',
				],
			]
		);  
 

        $this->end_controls_section();
    }

    protected function render( ) {
        $settings = $this->get_settings_for_display();
        $post_cat = $settings['post_cat'];
        $count_col = $settings['count_col'];
        $post_count = $settings['post_count'];
      

        $paged = 1;
        if ( get_query_var('paged') ) $paged = get_query_var('paged');
        if ( get_query_var('page') ) $paged = get_query_var('page');


        $_tax_query = array();
	
		if (  $post_cat ) {
			$_tax_query = array(
				array(
					'taxonomy' => 'category',
					'field' => 'slug',
					'terms'    => $post_cat,
				)
			);
		}

        $query = array(
            'post_type'      => 'post',
            'post_status'    => 'publish',
            'posts_per_page' => $post_count,
            'tax_query' => $_tax_query,
            'paged' => $paged,
        );

        $corporx_query = new \WP_Query( $query );

        if($corporx_query->have_posts()):
            ?>
            <div class="tt-blog-posts">
                <?php
                $ant = 0.3;

                echo '<div class="row">';
                    while ($corporx_query->have_posts()) :
                        $corporx_query->the_post();
                           
                        require __DIR__ . '/templates/blog/blog.php';

                        $ant = $ant + 0.2;
                    endwhile;
                echo '</div>';
                ?>
            </div>

        <?php
        endif;
        wp_reset_postdata();
    }
    protected function _content_template() { }
}