<?php

if (!defined('ABSPATH')) exit;

class Qhost_Shortcode {
	/**
	 * Holds the class object.
	 *
	 * @since 1.0
	 *
	 */
	public static $_instance;

	/**
	 * Localize data array
	 *
	 * @var array
	 */
	public $localize_data = array();

	/**
	 * Load Construct
	 *
	 * @since 1.0
	 */

	public function __construct() {
		add_action( 'elementor/init', [ $this, 'qhost_elementor_init' ] );
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'qhost_shortcode_elements' ] );
		add_action( 'elementor/frontend/before_enqueue_scripts', [ $this, 'before_enqueue_scripts' ] );
		add_action( 'elementor/frontend/after_register_scripts', [ $this, 'after_register_scripts' ] );
	}

	public function after_register_scripts() {
		wp_register_script('countUp', QHOST_SCRIPTS . '/countUp.min.js', array('jquery'), QHOST_CORE_VERSION, true);
		wp_register_script('appear-js', QHOST_SCRIPTS . '/jquery.appear.js', array('jquery'), QHOST_CORE_VERSION, true);
		wp_register_script('countdown', QHOST_SCRIPTS . '/jquery.countdown.js', array('jquery'), QHOST_CORE_VERSION, true);
		wp_register_script('gmap3', QHOST_SCRIPTS . '/gmap.js', array('jquery'), QHOST_CORE_VERSION, true);
		wp_register_script('qhost-form', QHOST_SCRIPTS . '/form.js', array('jquery'), QHOST_CORE_VERSION, true);
	}

	/**
	 * Enqueue Scripts
	 *
	 * @return void
	 */

	public function before_enqueue_scripts() {
		wp_enqueue_script('qhost-elementor', QHOST_SCRIPTS . '/elementor.js', array('jquery', 'elementor-frontend'), QHOST_CORE_VERSION, true);
	}

	/**
	 * Elementor Initialization
	 *
	 * @since 1.0
	 *
	 */

	public function qhost_elementor_init() {
		\Elementor\Plugin::$instance->elements_manager->add_category('tt-elements',
			[
				'title' => esc_html__('Qhost Elements', 'qhost-core'),
				'icon' => 'fa fa-plug',
			]
		);
	}


	public function qhost_shortcode_elements($widgets_manager) {

		foreach (glob(__DIR__ . '/*.php') as $shortcode) {
			require_once($shortcode);
		}

		$widgets_manager->register_widget_type(new Elementor\Qhost_Hero_Static());
	    $widgets_manager->register_widget_type(new Elementor\Qhost_Icon_Box());
	    $widgets_manager->register_widget_type(new Elementor\Qhost_Menu_Item());
	    $widgets_manager->register_widget_type(new Elementor\Qhost_Service_Box());
	    $widgets_manager->register_widget_type(new Elementor\Qhost_Service_slider());
	    $widgets_manager->register_widget_type(new Elementor\Qhost_Counter());
		$widgets_manager->register_widget_type(new Elementor\Qhost_Heading());
		$widgets_manager->register_widget_type(new Elementor\Qhost_Accordion());
		$widgets_manager->register_widget_type(new Elementor\Qhost_Domain_Form());
		$widgets_manager->register_widget_type(new Elementor\Qhost_Domain_Box());
		$widgets_manager->register_widget_type(new Elementor\Qhost_List());
		$widgets_manager->register_widget_type(new Elementor\Qhost_Post());
		$widgets_manager->register_widget_type(new Elementor\Qhost_Button());
		$widgets_manager->register_widget_type(new Elementor\Qhost_Hotspot());
		$widgets_manager->register_widget_type(new Elementor\Qhost_Testimonial());
		$widgets_manager->register_widget_type(new Elementor\Qhost_Testimonial_Two());
		$widgets_manager->register_widget_type(new Elementor\Qhost_Team());
		$widgets_manager->register_widget_type(new Elementor\Qhost_Partner());
		$widgets_manager->register_widget_type(new Elementor\Qhost_Image());
		$widgets_manager->register_widget_type(new Elementor\Qhost_Popup_Video());
		$widgets_manager->register_widget_type(new Elementor\Qhost_Logo_Carousel());
		$widgets_manager->register_widget_type(new Elementor\Qhost_Logo_List());
		$widgets_manager->register_widget_type(new Elementor\Qhost_Newsletter());
		$widgets_manager->register_widget_type(new Elementor\Qhost_Info_Box());
		$widgets_manager->register_widget_type(new Elementor\Qhost_Pricing_Table());
		$widgets_manager->register_widget_type(new Elementor\Qhost_Pricing_Table_Advance());
		$widgets_manager->register_widget_type(new Elementor\Qhost_Range_Slider());
		$widgets_manager->register_widget_type(new Elementor\Qhost_Pricing_Table_Cloud());
		$widgets_manager->register_widget_type(new Elementor\Qhost_Contact_Form());
		$widgets_manager->register_widget_type(new Elementor\Qhost_Contact_Info());
		$widgets_manager->register_widget_type(new Elementor\Qhost_Social_Link());
		$widgets_manager->register_widget_type(new Elementor\Qhost_Map_Widget());
		$widgets_manager->register_widget_type(new Elementor\Qhost_Coming_Soon());
	}

	public static function Qhost_get_instance() {
		if (!isset(self::$_instance)) {
			self::$_instance = new Qhost_Shortcode();
		}
		return self::$_instance;
	}

}

$apdash_shortcode = Qhost_Shortcode::Qhost_get_instance();