<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

class Qhost_Coming_Soon extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'at-coming-soon';
	}


	public function get_title() {
		return __( 'Coming Soon', 'qhost-core' );
	}

	public function get_icon() {

		return 'eicon-social-icons';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return [ 'tt-elements' ];
	}

	/**
	 * Retrieve the list of scripts the image widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @return array Widget scripts dependencies.
	 * @since 1.3.0
	 * @access public
	 *
	 */
	public function get_script_depends() {
		return [ 'countdown', 'kihost-form' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'faq_content',
			[
				'label' => __( 'Coming Soon', 'qhost-core' ),
			]
		);

		$this->add_control(
			'soon_title', [
				'label'       => __( 'Title', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'default'     => __( 'We will be back soon', 'qhost-core' ),
			]
		);

		$this->add_control(
			'description', [
				'label'       => __( 'Description', 'qhost-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'label_block' => true,
				'default'     => __( 'You can subscribe us to get when our website is ready.', 'qhost-core' ),
			]
		);

		$this->add_control(
			'subscribe_text', [
				'label'       => __( '', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'default'     => __( 'Subscribe', 'qhost-core' ),
			]
		);

		$this->add_control(
			'year', [
				'label'       => __( 'Year', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'default'     => '2022',
			]
		);

		$this->add_control(
			'month',
			[
				'label'   => __( 'Month', 'qhost-core' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'default' => '1',
				'options' => [
					"1"  => __( "January", 'qhost-core' ),
					"2"  => __( "February", 'qhost-core' ),
					"3"  => __( "March", 'qhost-core' ),
					"4"  => __( "April", 'qhost-core' ),
					"5"  => __( "May", 'qhost-core' ),
					"6"  => __( "June", 'qhost-core' ),
					"7"  => __( "July", 'qhost-core' ),
					"8"  => __( "August", 'qhost-core' ),
					"9"  => __( "September", 'qhost-core' ),
					"10" => __( "October", 'qhost-core' ),
					"11" => __( "November", 'qhost-core' ),
					"12" => __( "December", 'qhost-core' )
				],
			]
		);

		$this->add_control(
			'day',
			[
				'label'   => __( 'Day', 'qhost-core' ),
				'type'    => \Elementor\Controls_Manager::NUMBER,
				'min'     => 1,
				'max'     => 31,
				'step'    => 1,
				'default' => 10,
			]
		);


		$this->end_controls_section();


		/**
		 * Style
		 */

		/* Title */
		$this->start_controls_section(
			'title_style_section',
			[
				'label' => __( 'Title', 'qhost-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'     => __( 'Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .coming-soon .soon-title' => 'color: {{VALUE}}'
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'title_typography',
				'label'    => __( 'Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .coming-soon .soon-title',
			]
		);

		$this->end_controls_section();

		/* Description */
		$this->start_controls_section(
			'des_section',
			[
				'label' => __( 'Description', 'qhost-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'des_color',
			[
				'label'     => __( 'Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .coming-soon-content .description' => 'color: {{VALUE}}'
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'des_typography',
				'label'    => __( 'Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .coming-soon-content .description',
			]
		);

		$this->end_controls_section();


		/* Time Style */
		$this->start_controls_section(
			'time_section',
			[
				'label' => __( 'Time', 'qhost-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'count_color',
			[
				'label'     => __( 'Time Count color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .counting' => 'color: {{VALUE}}'
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'count_typography',
				'label'    => __( 'Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .coming-soon-content .countdown .counting',
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'time_label_section',
			[
				'label' => __( 'Time Label', 'qhost-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'label_color',
			[
				'label'     => __( 'Time Count color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .CountdownLabel' => 'color: {{VALUE}}'
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'label_typography',
				'label'    => __( 'Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .CountdownLabel',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'newsletter_style_section',
			[
				'label' => __( 'Newsletter', 'qhost-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'btn_color',
			[
				'label'     => __( 'Button Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .newsletter-form .newsletter-submit' => 'color: {{VALUE}}'
				],
			]
		);

		$this->add_control(
			'btn_bg_color',
			[
				'label'     => __( 'Button BG Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .newsletter-form .newsletter-submit' => 'background-color: {{VALUE}}'
				],
			]
		);

		$this->add_control(
			'btn_hover_color',
			[
				'label'     => __( 'Button Hover Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .newsletter-form .newsletter-submit:hover' => 'color: {{VALUE}}'
				],
			]
		);

		$this->add_control(
			'btn_hover_bg_color',
			[
				'label'     => __( 'Button Hover BG Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .newsletter-form .newsletter-submit:hover' => 'background-color: {{VALUE}}'
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'btn_typography',
				'label'    => __( 'Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .newsletter-form .newsletter-submit',
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'bg_section',
			[
				'label' => __( 'Background', 'qhost-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);


		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name'     => 'background',
				'label'    => __( 'Background', 'qhost-core' ),
				'types'    => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .coming-soon',
			]
		);

		$this->end_controls_section();

		// Background Settings
		// =====================
		$this->start_controls_section(
			'style_background_overlay',
			[
				'label' => __( 'Background Overlay', 'qhost-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name'         => 'background_overlay',
				'label'        => __( 'Background', 'qhost-core' ),
				'types'        => [ 'classic', 'gradient' ],
				'selector'     => '{{WRAPPER}} .coming-soon:before',
				'prefix_class' => 'tt-bg-overlay-'
			]
		);

		$this->end_controls_section();

	}

	protected function render() {
		$settings       = $this->get_settings_for_display();
		$starting_year  = $settings['year'];
		$starting_month = $settings['month'];
		$starting_day   = $settings['day'];

		?>
        <div class="coming-soon">

            <div class="coming-soon-content text-center">

				<?php if ( ! empty( $settings['soon_title'] ) ) : ?>
                    <h2 class="soon-title"><?php echo esc_html( $settings['soon_title'] ); ?></h2>
				<?php endif; ?>

				<?php if ( ! empty( $settings['description'] ) ) : ?>
                    <p class="description"><?php echo $settings['description']; ?></p>
				<?php endif; ?>

                <div class="count-wrap">
                    <div class="countdown" data-count-year="<?php echo esc_attr( $starting_year ); ?>"
                         data-count-month="<?php echo esc_attr( $starting_month ); ?>"
                         data-count-day="<?php echo esc_attr( $starting_day ); ?>">

                    </div>
                </div><!-- /.count-wrap -->

                <div class="clearfix"></div>

                <form action="<?php echo admin_url( 'admin-ajax.php' ); ?>" method="post"
                      class="newsletter-form wow pixFadeUp" data-kihost-form="newsletter-subscribe">
                    <input type="hidden" name="action" value="apdash_mailchimp_subscribe">

                    <div class="newsletter-inner form-row justify-content-center">
                        <input type="email" name="email" class="form-control" id="newsletter-form-email"
                               placeholder="<?php echo esc_attr__( 'Email Address*', 'qhost-core' ); ?>" required>

                        <button type="submit" name="submit" id="newsletter-submit" class="newsletter-submit mt-0 cu_btn animate_btn_2">
                            <span><?php echo $settings['subscribe_text']; ?></span>
							<i class="fa fa-circle-o-notch fa-spin"></i>
                        </button>
                    </div>

                    <div class="form-result alert">
                        <div class="content"></div>
                    </div><!-- /.form-result-->
                </form><!-- /.newsletter-form -->

            </div>
        </div>
        <!-- /.coming-soon -->
		<?php
	}

}
