<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

class Qhost_Contact_Form extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'tt-contact-form';
	}


	public function get_title() {
		return __( 'Qhost Contact Form 7', 'qhost-core' );
	}

	public function get_icon() {
		// Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
		return 'eicon-form-horizontal';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'qhost-core' ),
			]
		);

		$this->add_control(
			'form_title',
			[
				'label'       => __( 'Form Title', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => '',
				'description' => __( '(Optional) Title to search if no ID selected or cannot find by ID.', 'qhost-core' ),
				'label_block' => true
			]
		);

		$this->add_control(
			'f_id',
			[
				'label'   => __( 'Select a form', 'qhost-core' ),
				'type'    => Controls_Manager::SELECT,
                'options' => kihost_addons_get_contact_form7_forms(),
                'default' => '1'

			]
		);


		$this->end_controls_section();


	}

	protected function render() {
		$settings = $this->get_settings();
		$title    = $settings['form_title'];
		$attrs    = '';
		if ( $settings['f_id'] ) {
			$attrs .= ' id="' . $settings['f_id'] . '"';
		} elseif ( $settings['f_title'] ) {
			$attrs .= ' title="' . $settings['f_title'] . '"';
		}

		$shortcode = do_shortcode( '[contact-form-7' . $attrs . ']' );
		?>
        <div class="contact-form contact-form-boxed">
			<?php if ( ! empty( $title ) ) : ?>
                <h3 class="contact-form-title"><?php echo $title; ?></h3>
			<?php endif;
			echo $shortcode;
			?>

        </div>
		<?php
	}

}

