<?php

namespace Elementor;

if (!defined('ABSPATH'))
	exit;

class Qhost_Contact_Info extends Widget_Base {

	public function get_name() {
		return 'tt-contact-info';
	}

	public function get_title()	{
		return esc_html__('Qhost Contact Info', 'qhost-core');
	}

	public function get_icon() {
		return 'eicon-icon-box';
	}

	public function get_categories() {
		return ['tt-elements'];
	}

	protected function _register_controls()	{
		$this->start_controls_section(
			'section_tab', [
				'label' => esc_html__('Contact Info', 'qhost-core'),
			]
		);

		$this->add_control(
			'title', [
				'label' => esc_html__('Title', 'qhost-core'),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__('Title', 'qhost-core'),
			]
		);

		$this->add_control(
			'description', [
				'label' => esc_html__('Description', 'qhost-core'),
				'type' => Controls_Manager::TEXTAREA,
				'label_block' => true,
				'placeholder' => esc_html__('Description', 'qhost-core'),
			]
		);


		$repeater = new \Elementor\Repeater();


		$repeater->add_control(
			'box_icon',
			[
				'label' => __( 'Icon', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'fas fa-star',
					'library' => 'solid',
				],
			]
		);

		$repeater->add_control(
			'box_title', [
				'label' => esc_html__('Box Title', 'qhost-core'),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__('Title', 'qhost-core'),
			]
		);
		


		$repeater->add_control(
			'info', [
				'label' => esc_html__('Description', 'qhost-core'),
				'type' => Controls_Manager::TEXTAREA,
				'label_block' => true,
				'placeholder' => esc_html__('Description', 'qhost-core'),				
				'separator' => 'none',			
			]
		);

		$repeater->add_responsive_control(
			'box_align', [
				'label' => esc_html__('Alignment', 'qhost-core'),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__('Left', 'qhost-core'),
						'icon' => 'fa fa-align-left',
					],
					'right' => [
						'title' => esc_html__('Right', 'qhost-core'),
						'icon' => 'fa fa-align-right',
					],
				],
                'default' => 'left',
				'toggle' => false,
			]
		);



		$this->add_control(
			'info_boxes',
			[
				'label' => __( 'Info List', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'box_title' => __( 'Company Location', 'qhost-core' ),
						'info' => __( '100 Yellow House, Mn Factory, United State, 13420', 'qhost-core' ),
                        'box_icon' => [
                            'value' => 'fas fa-location-arrow',
                            'library' => 'solid',
                        ]
					],
					[
						'box_title' => __( 'Email Address', 'qhost-core' ),
						'info' => __( 'hello@yourdomain.com', 'qhost-core' ),
                         'box_icon' => [
                            'value' => 'fas fa-envelope',
                            'library' => 'solid',
                        ]
					],
				],
				'title_field' => '{{{ box_title }}}',
			]
		);



		$this->end_controls_section();

		//Title Style Section
		$this->start_controls_section(
			'section_title_style', [
				'label' => esc_html__('Title', 'qhost-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_color_one', [
				'label' => esc_html__('Color', 'qhost-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-contact-info .box-title,
					{{WRAPPER}} .tt-contact-info .box-title a' => 'color: {{VALUE}};'
				],
			]
		);
		$this->add_control(
			'title_color_one_hover', [
				'label' => esc_html__('Hover Color', 'qhost-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-contact-info .box-title:hover,
					{{WRAPPER}} .tt-contact-info .box-title a:hover' => 'color: {{VALUE}};'
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(), [
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .tt-contact-info .box-title',
			]
		);

		$this->end_controls_section();

		//Subtitle Style Section
		$this->start_controls_section(
			'section_subtitle_style', [
				'label' => esc_html__('Description', 'qhost-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'subtitle_color', [
				'label' => esc_html__('color', 'qhost-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-contact-info .description' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(), [
				'name' => 'sdes_typography',
				'selector' => '{{WRAPPER}} .tt-contact-info .description',
			]
		);

		$this->end_controls_section();
	}

	protected function render()	{
		$settings = $this->get_settings_for_display();
		$info_boxes = $settings['info_boxes'];



		require __DIR__.'/templates/contact-info/layout1.php';
	}

	protected function _content_template() {}
}



