<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

class Qhost_Counter extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'tt-counter';
	}


	public function get_title() {
		return __( 'Counter', 'qhost-core' );
	}

	public function get_icon() {
		return 'eicon-counter';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return [ 'tt-elements' ];
	}

	public function get_script_depends() {
		return [
			'countUp',
			'appear-js'
		];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Qhost Counter', 'qhost-core' ),
			]
		);

		$this->add_control(
			'style',
			[
				'label'   => __( 'Style', 'qhost-core' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'default' => 'style-one',
				'options' => [
					'style-one'   => __( 'Style One', 'qhost-core' ),
					'style-two'   => __( 'Style Two', 'qhost-core' ),
					'style-three' => __( 'Style Three', 'qhost-core' ),
					'style-four'  => __( 'Style Four', 'qhost-core' ),
				],
			]
		);

		$this->add_control(
			'icon_switch',
			[
				'label'        => __( 'Show Icon', 'qhost-core' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'Show', 'qhost-core' ),
				'label_off'    => __( 'Hide', 'qhost-core' ),
				'return_value' => 'yes',
				'default'      => 'no',
			]
		);


		$repeater = new Repeater();

		$repeater->add_control(
			'counter_icon',
			[
				'label' => __( 'Icon', 'qhost-core' ),
				'type'  => \Elementor\Controls_Manager::ICONS,
			]
		);

		$repeater->add_control(
			'count_title', [
				'label'       => __( 'Title', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'List Title', 'qhost-core' ),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'count_number', [
				'label'       => __( 'Counting Number', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => __( '692', 'qhost-core' ),
				'label_block' => true,
			]
		);


		$this->add_control(
			'count_items',
			[
				'label'       => __( 'Repeater List', 'qhost-core' ),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'counter_icon' => [
							'value'   => 'fas fa-users',
							'library' => 'solid'
						],
						'count_title'  => __( 'Customers', 'qhost-core' ),
						'count_number' => '21023'
					],
					[
						'counter_icon' => [
							'value'   => 'fas fa-cloud-download-alt',
							'library' => 'solid',
						],
						'count_title'  => __( 'Downloads', 'qhost-core' ),
						'count_number' => '44023'

					],
					[
						'counter_icon' => [
							'value'   => 'fas fa-smile',
							'library' => 'solid',
						],
						'count_title'  => __( 'Satisfied', 'qhost-core' ),
						'count_number' => '35023'
					],
					[
						'counter_icon' => [
							'value'   => 'fas fa-mug-hot',
							'library' => 'solid',
						],
						'count_title'  => __( 'Cup of Coffee', 'qhost-core' ),
						'count_number' => '2323'
					],
				],
				'title_field' => '{{{ count_title }}}',
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => __( 'Alignment', 'qhost-core' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left'   => [
						'title' => __( 'Left', 'qhost-core' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'qhost-core' ),
						'icon'  => 'fa fa-align-center',
					],
					'right'  => [
						'title' => __( 'Right', 'qhost-core' ),
						'icon'  => 'fa fa-align-right',
					]
				],
				'default' => 'center',

			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'animated_element',
			[
				'label' => __( 'Animated Shape', 'qhost-core' ),
			]
		);

		$this->add_control(
			'show_shape',
			[
				'label'        => __( 'Show Shape', 'qhost-core' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'Show', 'qhost-core' ),
				'label_off'    => __( 'Hide', 'qhost-core' ),
				'return_value' => 'yes',
				'default'      => 'yes',
			]
		);

		$this->add_control(
			'sgape_image',
			[
				'label'   => __( 'Choose Image', 'qhost-core' ),
				'type'    => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => plugins_url( 'images/testimonial_icon_3.png', __FILE__ )
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'cstylet_section',
			[
				'label' => __( 'Countdown Style', 'qhost-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'counter_typography',
				'label'    => __( 'Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .tt-countdown-wrapper .dt-countdown .counter',
			]
		);

		$this->add_control(
			'counter_icon_color', [
				'label'     => esc_html__( 'Icon Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-countdown-wrapper .tt-countdown .counter-icon' => 'color: {{VALUE}};',
				],
			]
		);


		$this->add_control(
			'subtitle_color', [
				'label'     => esc_html__( 'Counter Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-countdown-wrapper .tt-countdown .counter' => 'color: {{VALUE}};',
				],
			]
		);


		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'counter_title_typography',
				'label'    => __( 'Title Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .tt-countdown-wrapper .tt-countdown .counter-title',
			]
		);

		$this->add_control(
			'counter_title_color', [
				'label'     => esc_html__( 'Title Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-countdown-wrapper .tt-countdown .counter-title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		$align    = $settings['align'];
		$style    = $settings['style'];

		$this->add_render_attribute( 'countdown', 'class', [ 'tt-countdown-wrapper ' . $style ] );
		$this->add_render_attribute( 'count', 'class', [ 'tt-countdown', 'text-' . $align ] );

		?>

        <div class="countdown-container">
			<?php if ( $settings['count_items'] ) { ?>
                <div <?php echo $this->get_render_attribute_string( 'countdown' ); ?>>
					<?php foreach ( $settings['count_items'] as $item ) { ?>

                        <div <?php echo $this->get_render_attribute_string( 'count' ); ?>>

							<?php if ( $settings['icon_switch'] == 'yes' ) : ?>
								<?php if ( ! empty( $item['counter_icon'] ) ) : ?>
                                    <div class="counter-icon">
										<?php \Elementor\Icons_Manager::render_icon( $item['counter_icon'], [ 'aria-hidden' => 'true' ] ); ?>
                                    </div>
								<?php endif; ?>
							<?php endif; ?>
                            <p class="counter" data-counter="<?php echo esc_attr( $item['count_number'] ) ?>">
								<?php echo $item['count_number']; ?>
                            </p>
                            <h4 class="counter-title"><?php echo $item['count_title']; ?></h4>
                        </div>

					<?php } ?>
                </div>
			<?php } ?>

        </div>
        <!-- /.countdown-ccontainer -->
		<?php

	}

}

