<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Qhost_Domain_Box extends Widget_Base {

	public function get_name() {
		return 'tt-domain-box';
	}

	public function get_title() {
		return esc_html__( 'Qhost Domain Box', 'qhost-core' );
	}

	public function get_icon() {
		return 'eicon-icon-box';
	}

	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_tab', [
				'label' => esc_html__( 'Domain Box', 'qhost-core' ),
			]
		);

		$this->add_control(
			'icon_image',
			[
				'label'       => esc_html__( 'Image', 'irecco-core' ),
				'type'        => Controls_Manager::MEDIA,
				'label_block' => true,
				'default'     => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'popular', [
				'label'       => esc_html__( 'Popular Text', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => false,
				'placeholder' => esc_html__( 'popular', 'qhost-core' ),
				'default'     => __( 'Popular', 'qhost-core' ),
				'separator'   => 'none',
			]
		);


		$this->add_control(
			'description', [
				'label'       => esc_html__( 'Description', 'qhost-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'label_block' => true,
				'placeholder' => esc_html__( 'Description', 'qhost-core' ),
				'default'     => __( 'Holisticly parallel task team building results and bleeding-edge.', 'qhost-core' ),
				'separator'   => 'none',
			]
		);

		$this->add_control(
			'reg_price', [
				'label'       => esc_html__( 'Regular Price', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => false,
				'placeholder' => esc_html__( 'Price', 'qhost-core' ),
				'default'     => __( '$10.99', 'qhost-core' ),
				'separator'   => 'none',
			]
		);

		$this->add_control(
			'sell_price', [
				'label'       => esc_html__( 'Offer Price', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => false,
				'placeholder' => esc_html__( 'Price', 'qhost-core' ),
				'default'     => __( '$8.99', 'qhost-core' ),
				'separator'   => 'none',
			]
		);

		/*
		* Button One
		*/
		$this->add_control(
			'button_text', [
				'label'       => esc_html__( 'Button Text One', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'Button Text', 'qhost-core' ),
				'default'     => __( 'Register', 'qhost-core' ),
				'separator'   => 'before',
			]
		);

		$this->add_control(
			'btn_link',
			[
				'label'         => __( 'Button Link One', 'qhost-core' ),
				'type'          => \Elementor\Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'qhost-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '#',
					'is_external' => true,
					'nofollow'    => true,
				],
			]
		);

		/*
		 * Bitton Two
		 */

		$this->add_control(
			'button_text_two', [
				'label'       => esc_html__( 'Button Text Two', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'Button Text', 'qhost-core' ),
				'default'     => __( 'Transfer', 'qhost-core' ),
				'separator'   => 'before',
			]
		);

		$this->add_control(
			'btn_link_two',
			[
				'label'         => __( 'Button Link Two', 'qhost-core' ),
				'type'          => \Elementor\Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'qhost-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '#',
					'is_external' => true,
					'nofollow'    => true,
				],
			]
		);

		$this->add_responsive_control(
			'title_align', [
				'label'     => esc_html__( 'Alignment', 'qhost-core' ),
				'type'      => Controls_Manager::CHOOSE,
				'options'   => [

					'left'    => [
						'title' => esc_html__( 'Left', 'qhost-core' ),
						'icon'  => 'fa fa-align-left',
					],
					'center'  => [
						'title' => esc_html__( 'Center', 'qhost-core' ),
						'icon'  => 'fa fa-align-center',
					],
					'right'   => [
						'title' => esc_html__( 'Right', 'qhost-core' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'qhost-core' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .tt-domain-box' => 'text-align: {{VALUE}};'
				],
			]
		);

		$this->end_controls_section();

		//Description Style Section
		$this->start_controls_section(
			'section_subtitle_style', [
				'label' => esc_html__( 'Description', 'qhost-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'subtitle_color', [
				'label'     => esc_html__( 'color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-domain-box .description' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(), [
				'name'     => 'subtitle_typography',
				'selector' => '{{WRAPPER}} .tt-domain-box .description',
			]
		);

		$this->end_controls_section();

		//Regular Price Style Section
		$this->start_controls_section(
			'section_price_style', [
				'label' => esc_html__( 'Regular Price', 'qhost-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'price_color', [
				'label'     => esc_html__( 'Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-domain-box .price .regular-price' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(), [
				'name'     => 'price_typography',
				'selector' => '{{WRAPPER}} .tt-domain-box .price .regular-price',
			]
		);

		$this->end_controls_section();


		// Sell Price Style Section
		$this->start_controls_section(
			'section_offer_style', [
				'label' => esc_html__( 'Offer Price', 'qhost-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'offer_color', [
				'label'     => esc_html__( 'Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-domain-box .price .sell-price' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(), [
				'name'     => 'offer_typography',
				'selector' => '{{WRAPPER}} .tt-domain-box .price .sell-price',
			]
		);

		$this->end_controls_section();


		//Icon Style
		$this->start_controls_section(
			'section_service_style', [
				'label' => esc_html__( 'Background', 'qhost-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'service_bg_color', [
				'label'     => esc_html__( 'Background Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-domain-box' => 'background: {{VALUE}};'
				],
			]
		);

		$this->add_control(
			'service_border_color', [
				'label'     => esc_html__( 'Border Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-domain-box' => 'border-color: {{VALUE}};'
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'box_shadow',
				'label' => __( 'Box Shadow', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .tt-domain-box',
			]
		);


		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		$btn_target   = $settings['btn_link']['is_external'] ? ' target="_blank"' : '';
		$btn_nofollow = $settings['btn_link']['nofollow'] ? ' rel="nofollow"' : '';

		$btn_target_two   = $settings['btn_link_two']['is_external'] ? ' target="_blank"' : '';
		$btn_nofollow_two = $settings['btn_link_two']['nofollow'] ? ' rel="nofollow"' : '';

		require __DIR__ . '/templates/domain/layout-1.php';
	}

	protected function _content_template() {
	}
}



