<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

class Qhost_Domain_Form extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'tt-domain-form';
	}


	public function get_title() {
		return __( 'Qhost Domain Search Form', 'qhost-core' );
	}

	public function get_icon() {
		// Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
		return 'eicon-form-horizontal';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'qhost-core' ),
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Search your Domain Name', 'qhost-core' ),
				'label_block' => true
			]
		);
	
		$this->add_control(
			'description',
			[
				'label'       => __( 'Description', 'qhost-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'     => __( 'So I said he lost his bottle boot drop.', 'qhost-core' ),
				'label_block' => true
			]
		);

		$this->add_control(
			'placeholder_input',
			[
				'label'       => __( 'Placeholder Input Text', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Domain.com', 'qhost-core' ),
				'label_block' => true
			]
		);

		$this->add_control(
			'show_button',
			[
				'label'        => __( 'Extension Show/Hide', 'qhost-core' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'Show', 'your-plugin' ),
				'label_off'    => __( 'Hide', 'your-plugin' ),
				'return_value' => 'yes',
				'default'      => 'yes',
			]
		);


		$this->add_control(
			'whmcs_url',
			[
				'label'         => __( 'Link', 'qhost-core' ),
				'type'          => \Elementor\Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'qhost-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '#',
					'is_external' => true,
					'nofollow'    => true,
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'extension__section',
			[
				'label' => __( 'Domain Extension and Price', 'qhost-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'extension_list_show',
			[
				'label'        => __( 'Extension List Show/Hide', 'qhost-core' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'Show', 'your-plugin' ),
				'label_off'    => __( 'Hide', 'your-plugin' ),
				'return_value' => 'yes',
				'default'      => 'yes',
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'extension_domain', [
				'label'       => __( 'Extension', 'qhost-core' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => __( '.com', 'qhost-core' ),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'ext_color',
			[
				'label' => __( 'Extension Color', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .ext-name' => 'color: {{VALUE}}'
				],
			]
		);

		$repeater->add_control(
			'price',
			[
				'label'   => __( 'Price', 'qhost-core' ),
				'type'    => \Elementor\Controls_Manager::NUMBER,
				'min'     => 0,
				'max'     => 2000,
				'step'    => 1,
				'default' => 10,
			]
		);

		$repeater->add_control(
			'currency_symbol',
			[
				'label'   => __( 'Select Currency', 'qhost-core' ),
				'type'    => Controls_Manager::SELECT,
//                'options' => wdes_get_currency_symbol(),
				'default' => '1'

			]
		);


		$this->add_control(
			'extension_list',
			[
				'label'       => __( 'Extension List', 'qhost-core' ),
				'type'        => \Elementor\Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'extension_domain' => __( '.com', 'qhost-core' ),
						'price'            => __( '12.95', 'qhost-core' ),
						'currency_symbol'  => "$",
					],
					[
						'extension_domain' => __( '.net', 'qhost-core' ),
						'price'            => __( '8.75', 'qhost-core' ),
						'currency_symbol'  => "$",
					],
					[
						'extension_domain' => __( '.org', 'qhost-core' ),
						'price'            => __( '2.32', 'qhost-core' ),
						'currency_symbol'  => "$",
					],
					[
						'extension_domain' => __( '.online', 'qhost-core' ),
						'price'            => __( '7.57', 'qhost-core' ),
						'currency_symbol'  => "$",
					],
				],
				'title_field' => '{{{ extension_domain }}}',
			]
		);

		$this->end_controls_section();


		# Style Section
		/*=====================*/

		# Heading Style
		/*======================*/

		$this->start_controls_section(
			'title_style_section',
			[
				'label' => __( 'Title', 'qhost-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'     => __( 'Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .domain-element .title' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'title_typography',
				'label'    => __( 'Extension Typography', 'qhost-core' ),
				1,
				'selector' => '{{WRAPPER}} .domain-element .title',
			]
		);


		$this->end_controls_section();

		# Sub Title Style
		/*======================*/

		$this->start_controls_section(
			'subtitle_style_section',
			[
				'label' => __( 'Sub Title', 'qhost-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'subtitle_color',
			[
				'label'     => __( 'Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .domain-element .sub_title' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'subtitle_bg_color',
			[
				'label'     => __( 'Background Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .domain-element .sub_title' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'subtitle_typography',
				'label'    => __( 'Extension Typography', 'qhost-core' ),
				1,
				'selector' => '{{WRAPPER}} .domain-element .sub_title',
			]
		);

		$this->end_controls_section();


		# Description Style
		/*======================*/
		$this->start_controls_section(
			'des_style_section',
			[
				'label' => __( 'Description', 'qhost-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'des_color',
			[
				'label'     => __( 'Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .domain-element .description' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'des_bg_color',
			[
				'label'     => __( 'Background Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .domain-element .description' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'des_typography',
				'label'    => __( 'Extension Typography', 'qhost-core' ),
				1,
				'selector' => '{{WRAPPER}} .domain-element .description',
			]
		);

		$this->end_controls_section();


		# Button Style
		/*======================*/
		$this->start_controls_section(
			'button_style_section',
			[
				'label' => __( 'Search Form', 'qhost-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'spinner_color',
			[
				'label'     => __( 'Spinner Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .spinner' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'btn_color',
			[
				'label'     => __( 'Button Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} #tt-domain-search .tt-input-inner .tt-btn' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'btn_bg_color',
			[
				'label'     => __( 'Button BG Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} #tt-domain-search .tt-input-inner .tt-btn' => 'background-color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'box_shadow',
				'label' => __( 'Form Shadow', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .domain-wrapper .tt-input-inner',
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'form_border',
				'label' => __( 'Border', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .domain-wrapper .tt-input-inner',
			]
		);


		$this->add_control(
			'more_options',
			[
				'label'     => __( 'Hover Style', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'btn_color_hover',
			[
				'label'     => __( 'Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} #tt-domain-search .tt-input-inner .tt-btn:hover' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'btn_bg_color_hover',
			[
				'label'     => __( 'BG Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} #tt-domain-search .tt-input-inner .tt-btn:hover' => 'background-color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'btn_typography',
				'label'    => __( 'Typography', 'qhost-core' ),
				1,
				'selector' => '{{WRAPPER}} .ext-name',
			]
		);	

		$this->add_control(
			'form_bg_color',
			[
				'label'     => __( 'Form BG Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} #tt-domain-search .tt-input-inner' => 'background: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();

		# Extension Style
		/*======================*/

		$this->start_controls_section(
			'extension_style_section',
			[
				'label' => __( 'Extension', 'qhost-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'ext_color',
			[
				'label'     => __( 'Extension Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ext-name' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'ext_typography',
				'label'    => __( 'Extension Typography', 'qhost-core' ),
				1,
				'selector' => '{{WRAPPER}} .ext-name',
			]
		);

		$this->add_control(
			'price_color',
			[
				'label'     => __( 'Price Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .price' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'price_typography',
				'label'    => __( 'Price Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .ext-name',
			]
		);

		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings();

		?>
        <div class="domain-element">
            <div class="section-heading text-center">		

				<?php if ( ! empty( $settings['title'] ) ) : ?>
                    <h2 class="title text-center"><?php echo $settings['title']; ?></h2>
				<?php endif; ?>

				<?php if ( ! empty( $settings['description'] ) ) : ?>
                    <p class="description text-center"><?php echo $settings['description']; ?></p>
				<?php endif; ?>
            </div>

            <div id="tt-domain-search" class="domain-wrapper">
                <form class="domain-search" method="post">

					<?php if ( ! empty( $settings['whmcs_url']['url'] ) ) { ?>
                        <input type="hidden" name="whmcs_url" value="<?php echo $settings['whmcs_url']['url']; ?>">
					<?php }
					?>

					<?php do_action( 'wdes_domain_verify_code' ); ?>


                    <div class="tt-input-inner">
                        <input id="tt-domain" class="sea-dom" type="text"
                               placeholder="<?php echo esc_attr( ( $settings['placeholder_input'] ) ? $settings['placeholder_input'] : '' ); ?>">

						<?php if ( $settings['show_button'] === 'yes' ) { ?>
                            <select id="domainext" class="form-control">
                                <option value="com" selected="">.com</option>
                                <option value="net">.net</option>
                                <option value="io">.io</option>
                                <option value="info">.info</option>
                                <option value="store">.store</option>
                                <option value="org">.org</option>
                            </select>
						<?php } ?>

                        <input id="tt-search" class="reg-dom tt-btn" type="submit"
                               value="<?php echo esc_attr( ! empty( $settings['check_button_text'] ) ? $settings['check_button_text'] : 'Check' ) ?>">
						<?php wp_nonce_field( 'check-domain-nonce', 'security', true, false ); ?>
                    </div>
                </form>
                <div id="tt-domain-results" class="domain-results-box"></div>

            </div>
			<?php if ( $settings['extension_list_show'] == 'yes' ) : ?>
                <div class="extensions-block">
					<?php foreach ( $settings['extension_list'] as $item ): ?>
                        <div class="ext-item elementor-repeater-item-<?php echo esc_attr($item['_id']) ?>">
							<?php if ( ! empty( $item['extension_domain'] ) ) : ?>
                                <span class="ext-name"><?php echo $item['extension_domain'] ?></span>
							<?php endif; ?>

							<?php if ( ! empty( $item['price'] ) ) : ?>
                                <span class="price">
                                    <?php echo $item['currency_symbol'] ?><?php echo $item['price'] ?>
                                </span>
							<?php endif; ?>
                        </div>
					<?php endforeach; ?>
                </div>
			<?php endif; ?>
        </div>
		<?php
	}


	/**
	 * The bridge Page Id.
	 */
	public function get_bridge_page_id( $type = 'string' ) {
		$bridge_page_id = get_option( 'cc_whmcs_bridge_pages' );

		if ( isset( $bridge_page_id ) ) {
			if ( $type === 'int' ) {
				return intval( $bridge_page_id );
			}

			return $bridge_page_id;

		} else {
			return false;
		}
	}

	/**
	 * Bridge page exists.
	 */
	public function wdes_bridge_page_exists() {
		if ( $this->get_bridge_page_id() ) {
			return true;
		}

		return false;
	}

	/**
	 * Bridge Checker.
	 */
	public function wdes_bridge_checker() {
		if ( $this->wdes_bridge_page_exists() ) {
			$output = get_permalink( $this->get_bridge_page_id() ) . '?ccce=domainchecker';

			return $output;
		}

		return false;
	}

	/**
	 * Domain Action Url.
	 */
	public function wdes_domain_action_url( $default ) {

		if ( $this->wdes_bridge_checker() ) {
			$output = $this->wdes_bridge_checker();
		} else {
			if ( ! empty( $default ) ) {
				$output = $default;
			} else {
				$output = '#';
			}
		}

		return $output;
	}
}

