<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Qhost_Download_Button extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve button widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'tt-download-button';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve button widget title.
	 *
	 * @return string Widget title.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_title() {
		return __( 'Qhost Download Button', 'qhost-core' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve button widget icon.
	 *
	 * @return string Widget icon.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_icon() {
		return 'eicon-button';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the icon box widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return [ 'tt-elements' ];
	}

	/**
	 * Get button sizes.
	 *
	 * Retrieve an array of button sizes for the button widget.
	 *
	 * @return array An array containing button sizes.
	 * @since 1.0.0
	 * @access public
	 * @static
	 *
	 */
	public static function get_button_sizes() {
		return [
			'xs' => __( 'Extra Small', 'qhost-core' ),
			'sm' => __( 'Small', 'qhost-core' ),
			'md' => __( 'Medium', 'qhost-core' ),
			'lg' => __( 'Large', 'qhost-core' ),
			'xl' => __( 'Extra Large', 'qhost-core' ),
		];
	}


	/**
	 * Register button widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'buttons_sec',
			[
				'label' => __( 'Buttons', 'qhost-core' ),
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'btn_text', [
				'label'       => __( 'Create buttons', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'default'     => 'Play Store'
			]
		);

		$repeater->add_control(
			'btn_text_top', [
				'label'       => __( 'Button Sub Text', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'default'     => 'Get on the',
			]
		);


		$repeater->add_control(
			'btn_link', [
				'label'   => __( 'Button URL', 'qhost-core' ),
				'type'    => Controls_Manager::URL,
				'default' => [
					'url' => '#'
				]
			]
		);
		$repeater->add_control(
			'icon',
			[
				'label' => __( 'Icon', 'text-domain' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'fab fa-google-play',
					'library' => 'brands',
				],
			]
		);

		$repeater->add_control(
			'button_shape',
			[
				'label'   => __( 'Shape', 'qhost-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'btn-round',
				'options' => [
					'btn-square' => __( 'Default', 'qhost-core' ),
					'btn-round'  => __( 'Round', 'qhost-core' ),
					'btn-circle' => __( 'Circle', 'qhost-core' ),
				],
			]
		);
		$repeater->add_control(
			'button_style',
			[
				'label'   => __( 'Button Status', 'qhost-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'btn-active',
				'options' => [
					'btn-active'  => __( 'Fill', 'qhost-core' ),
					'btn-outline' => __( 'Outline', 'qhost-core' ),
				],
			]
		);

		$this->add_control(
			'buttons',
			[
				'label'       => __( 'Repeater List', 'qhost-core' ),
				'type'        => \Elementor\Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'btn_text' => __( 'Get app now', 'qhost-core' ),

					],

				],
				'title_field' => '{{{ btn_text }}}',
			]
		);


		$this->end_controls_section(); // End Buttons


		$this->start_controls_section(
			'section_button',
			[
				'label' => __( 'Button', 'qhost-core' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'        => __( 'Alignment', 'qhost-core' ),
				'type'         => Controls_Manager::CHOOSE,
				'options'      => [
					'left'    => [
						'title' => __( 'Left', 'qhost-core' ),
						'icon'  => 'fa fa-align-left',
					],
					'center'  => [
						'title' => __( 'Center', 'qhost-core' ),
						'icon'  => 'fa fa-align-center',
					],
					'right'   => [
						'title' => __( 'Right', 'qhost-core' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => __( 'Justified', 'qhost-core' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'default'      => '',
			]
		);



		$this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Button', 'qhost-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'typography',
				'label'    => __( 'Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} a.tt-app-btn, {{WRAPPER}} .app-btn',
			]
		);

		$this->start_controls_tabs( 'tabs_button_style' );

		$this->start_controls_tab(
			'tab_button_normal',
			[
				'label' => __( 'Normal', 'qhost-core' ),
			]
		);

		$this->add_control(
			'button_text_color',
			[
				'label'     => __( 'Text Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => [
					'{{WRAPPER}} a.tt-app-btn, {{WRAPPER}} .tt-app-btn i' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'background_color',
			[
				'label'     => __( 'Background Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} a.tt-app-btn, {{WRAPPER}} .tt-app-btn' => 'background: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'dbtn_box_shadow',
				'label'    => __( 'Box Shadow', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .tt-app-btn',
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_button_hover',
			[
				'label' => __( 'Hover', 'qhost-core' ),
			]
		);

		$this->add_control(
			'hover_color',
			[
				'label'     => __( 'Text Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-app-btn:hover, {{WRAPPER}} .tt-app-btn:hover i' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_background_hover_color',
			[
				'label'     => __( 'Background Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} a.tt-app-btn:hover, {{WRAPPER}} .tt-app-btn:hover' => 'background: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_hover_border_color',
			[
				'label'     => __( 'Border Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'condition' => [
					'border_border!' => '',
				],
				'selectors' => [
					'{{WRAPPER}} a.tt-app-btn:hover, {{WRAPPER}} .tt-app-btn:hover' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'dbtn_box_shadow_hover',
				'label'    => __( 'Box Shadow', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .tt-app-btn:hover',
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'        => 'border',
				'label'       => __( 'Border', 'qhost-core' ),
				'placeholder' => '1px',
				'default'     => '1px',
				'selector'    => '{{WRAPPER}} .tt-app-btn',
				'separator'   => 'before',
			]
		);

		$this->add_control(
			'border_radius',
			[
				'label'      => __( 'Border Radius', 'qhost-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} a.tt-app-btn, {{WRAPPER}} .tt-app-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'      => 'button_box_shadow',
				'selector'  => '{{WRAPPER}} .tt-app-btn',
				'condition' => [
					'button_style' => 'btn-active',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'label'    => __( 'Active Btn Box Shadow', 'qhost-core' ),
				'name'     => 'button_box_shadow_outline',
				'selector' => '{{WRAPPER}} .tt-app-btn.btn-active',
			]
		);

		$this->add_control(
			'text_padding',
			[
				'label'      => __( 'Text Padding', 'qhost-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors'  => [
					'{{WRAPPER}} a.tt-app-btn, {{WRAPPER}} .tt-app-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'separator'  => 'before',
			]
		);

		$this->add_responsive_control(
			'dbtn_margin',
			[
				'label'      => __( 'Margin', 'qhost-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .tt-app-btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render button widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
		$buttons  = $settings['buttons'];

		$this->add_render_attribute( 'wrapper', 'class', 'button-wrapper' );

		if ( ! empty( $settings['align'] ) ) {
			$this->add_render_attribute( 'wrapper', 'class', 'text-' . $settings['align'] );
		}

		?>

        <div <?php echo $this->get_render_attribute_string( 'wrapper' ); ?>>
			<?php
			if ( ! empty( $buttons ) ) {
				$keys = array();
				foreach ( $buttons as $key => $button ) {

					$this->add_render_attribute( 'button', 'class', "tt-app-btn" );


					if ( ! empty( $button['button_shape'] ) ) {
						$this->add_render_attribute( 'button', 'class', $button['button_shape'] );
					}

					if ( ! empty( $button['button_style'] ) ) {
						$this->add_render_attribute( 'button', 'class', $button['button_style'] );
					}
					?>

                    <a class="tt-app-btn btn-fill wow fadeInUp <?php echo $button['button_shape']; ?> <?php echo $button['button_style']; ?>"
                       href="<?php echo esc_url( $button['btn_link']['url'] ); ?>" data-wow-delay="0.3s">
	                    <span class="btn-icon">
                            <?php \Elementor\Icons_Manager::render_icon( $button['icon'], [ 'aria-hidden' => 'true' ] ); ?>
	                    </span>

                        <span class="btn-lebels">
							<span class="sub"><?php echo esc_html( $button['btn_text_top'] ); ?></span>
							<span><?php echo esc_html( $button['btn_text'] ); ?></span>
						</span>

                    </a>
					<?php
				}
				//print_r($keys);

			} ?>
        </div>
		<?PHP
	}

	/**
	 * Render button widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _content_template() {
	}

}