<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Qhost_Map_Widget extends Widget_Base {

    /**
    * Get widget name.
    *
    * Retrieve alert widget name.
    *
    * @since 1.0.0
    * @access public
    *
    * @return string Widget name.
    */
    public function get_name() {
        return 'tt-google-map';
    }


    public function get_title() {
        return __( 'Qhost Google Map', 'qhost-core' );
    }

    public function get_icon() {
        // Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
        return 'eicon-google-maps';
    }

    /**
    * Get widget categories.
    *
    * Retrieve the widget categories.
    *
    * @since 1.0.0
    * @access public
    *
    * @return array Widget categories.
    */
    public function get_categories() {
        return [ 'tt-elements' ];
    }

    /**
	 * Retrieve the list of scripts the image widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.3.0
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'gmap3' ];
	}

    protected function _register_controls() {

        $this->start_controls_section(
            'section_content',
            [
                'label' => __( 'Google Map', 'qhost-core' ),
            ]
        );

        $this->add_control(
            'map_api',
            [
                'label'       => __( 'Map API', 'qhost-core' ),
                'type'        => Controls_Manager::TEXT, 
                'label_block' => true
            ]
        );

        $this->add_control(
            'map_api_region',
            [
                'label'       => __( 'Map API region', 'qhost-core' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true
            ]
        );
        

        $this->add_control(
            'latitude',
            [
                'label'       => __( 'Latitude', 'qhost-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => '40.712776',
                'description' => __( 'Type your google map latitude.', 'qhost-core' ),
                'label_block' => true
            ]
        );
        
        $this->add_control(
            'longitude',
            [
                'label'       => __( 'Longitude', 'qhost-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => '-74.005974',
                'description' => __( 'Type your google map longitude.', 'qhost-core' ),
                'label_block' => true
            ]
        );
        $this->add_control(
            'zoom',
            [
                'label'     => __( 'Zoom', 'qhost-core' ),
                'type'      => Controls_Manager::NUMBER,
				'min'       => 5,
				'max'       => 20,
				'step'      => 1,
				'default'   => 8,
            ]
        );
        $this->add_control(
            'marker',
			[
				'label' => __( 'Choose Map Marker', 'qhost-core' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => plugins_url('images/map-marker.png', __FILE__)
				],
			]
        );

        $this->add_responsive_control(
			'map-height',
			[
				'label' => __( 'Map Height', 'qhost-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', 'vh' ],
				'range' => [
					'px' => [
						'min' => 200,
						'max' => 1000,
						'step' => 5,
					],
					'vh' => [
						'min' => 10,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 600,
				],
				'selectors' => [
					'{{WRAPPER}} .gmap3-area' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
        );
        
        $this->add_control(
			'scroll_wheel',
			[
				'label' => __( 'Scroll Wheel', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'your-plugin' ),
				'label_off' => __( 'Hide', 'your-plugin' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);           

        $this->end_controls_section();        

    }

    protected function render( ) {
        $settings = $this->get_settings(); 
        $lat = $settings['latitude'];
        $lng = $settings['longitude'];
        $zoom = $settings['zoom'];
        $mker = $settings['marker'];
        $while = $settings['scroll_wheel'];

        $data_attr = "";
        
        if(! empty($lat)) {
            $data_attr .= ' data-lat="'.$lat.'"';
        }

        if(! empty($lng)) {
            $data_attr .= ' data-lng="'.$lng.'"';
        }

        if(! empty($zoom)) {
            $data_attr .= ' data-zoom="'.$zoom.'"';
        }        if(! empty($mker['url'])) {
            $data_attr .= ' data-mrkr="'.$mker['url'].'"';
        }        if(isset($while)) {
            $data_attr .= ' data-scrollwheel="'.$while.'"';
        }
     
        ?>
        <div id="google-maps">
            <div class="google-map">
                <?php 
                echo '<div class="gmap3-area" '.$data_attr.'>

                </div>';
                ?>
            </div><!-- /.google-map -->
        </div><!-- /#google-maps -->

       
        <?php

        $map_api = $settings['map_api'];
        $map_api_region = $settings['map_api_region'];

        $query_args = array(
            'key' => $map_api,
            'region' => $map_api_region,
        );

        $map_url = add_query_arg( $query_args, 'https://maps.googleapis.com/maps/api/js' );

        wp_enqueue_script('gmap-api', $map_url, array(), null,true);
           
        
    }

    protected function _content_template() {}    

}

