<?php

namespace Elementor;

if (!defined('ABSPATH'))
	exit;

class Qhost_Heading extends Widget_Base {

	public function get_name() {
		return 'apdash-heading';
	}

	public function get_title()	{
		return esc_html__('Qhost Heading', 'qhost-core');
	}

	public function get_icon() {
		return 'eicon-heading';
	}

	public function get_categories() {
		return ['tt-elements'];
	}

	protected function _register_controls()	{
		$this->start_controls_section(
			'section_tab', [
				'label' => esc_html__('Heading', 'qhost-core'),
			]
		);

		$this->add_control(
			'subtitle_text', [
				'label' => esc_html__('Sub Title', 'qhost-core'),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__('Sub Title', 'qhost-core'),
				'default' => esc_html__('Sub Title', 'qhost-core'),
			]
		);	

		$this->add_control(
			'title_text', [
				'label' => esc_html__('Title', 'qhost-core'),
				'type' => Controls_Manager::TEXTAREA,
				'label_block' => true,
				'placeholder' => esc_html__('Title', 'qhost-core'),
				'default' => esc_html__('Section Title', 'qhost-core'),
			]
		);	

		$this->add_control(
			'description_text',
			[
				'label' => __('Description', 'qhost-core'),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'placeholder' => __('Type section description here', 'qhost-core'),
			]
		);


		$this->add_responsive_control(
			'title_align', [
				'label' => esc_html__('Alignment', 'qhost-core'),
				'type' => Controls_Manager::CHOOSE,
				'options' => [

					'left' => [
						'title' => esc_html__('Left', 'qhost-core'),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__('Center', 'qhost-core'),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__('Right', 'qhost-core'),
						'icon' => 'fa fa-align-right',
					],
				],
				'default' => 'center',
				'selectors' => [
					'{{WRAPPER}} .section-heading' => 'text-align: {{VALUE}};'
				],
			]
		);


		$this->add_responsive_control(
			'space_between',
			[
				'label' => __('Spacing', 'qhost-core'),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'devices' => ['desktop', 'tablet', 'mobile'],
				'desktop_default' => [
					'size' => 36,
					'unit' => 'px',
				],
				'tablet_default' => [
					'size' => 20,
					'unit' => 'px',
				],
				'mobile_default' => [
					'size' => 20,
					'unit' => 'px',
				],
				'selectors' => [
					'{{WRAPPER}} .section-heading' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'space_between_title',
			[
				'label' => __('Spacing Title', 'qhost-core'),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 150,
					],
				],
				'devices' => ['desktop', 'tablet', 'mobile'],
				'desktop_default' => [
					'size' => 23,
					'unit' => 'px',
                ],
                'tablet_default' => [
					'size' => 20,
					'unit' => 'px',
				],
				'mobile_default' => [
					'size' => 15,
					'unit' => 'px',
				],
				'selectors' => [
					'{{WRAPPER}} .section-heading .section-title, {{WRAPPER}} .section-subhead .title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		//Title Style Section
		$this->start_controls_section(
			'section_title_style', [
				'label' => esc_html__('Title', 'qhost-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_color_one', [
				'label' => esc_html__('Color', 'qhost-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .section-heading .section-title' => 'color: {{VALUE}};'
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(), [
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .section-heading .section-title',
			]
		);

		$this->end_controls_section();

		//SubTitle Style Section
		$this->start_controls_section(
			'section_subtitle_style', [
				'label' => esc_html__('Sub Title', 'qhost-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'subtitle_color_one', [
				'label' => esc_html__('Color', 'qhost-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .section-heading .subtitle' => 'color: {{VALUE}};'
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(), [
				'name' => 'subtitle_typography',
				'selector' => '{{WRAPPER}} .section-heading .subtitle',
			]
		);

		$this->end_controls_section();

		//Description Style Section
		$this->start_controls_section(
			'section_des_style', [
				'label' => esc_html__('Description', 'qhost-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);


		$this->add_control(
			'des_color', [
				'label' => esc_html__('color', 'qhost-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .section-heading .description' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(), [
				'name' => 'des_typography',
				'selector' => '{{WRAPPER}} .section-heading .description',
			]
		);


		$this->end_controls_section();

	}

	protected function render()	{
		$settings = $this->get_settings_for_display();

		$title = $settings['title_text'];
		$subtitle = $settings['subtitle_text'];
		$description_text = $settings['description_text'];

		$this->add_render_attribute('title_text', [
			'class'=> 'section-title wow fadeInUp', 
			'data-wow-delay' => '0.4s'
			]
		);

		$this->add_render_attribute('subtitle_text', [
			'class'=> 'subtitle wow fadeInUp', 
			'data-wow-delay' => '0.3s'
			]
		);

		$this->add_inline_editing_attributes('title_text');
	
		$this->add_render_attribute('description_text', [
			'class'=> 'description wow fadeInUp', 
			'data-wow-delay' => '0.5s'
			]
		);
		$this->add_inline_editing_attributes('description_text');


		?>

        <div class="section-heading">

			<?php if ( !empty($subtitle) ): ?>
                <h3 <?php echo $this->get_render_attribute_string('subtitle_text'); ?>><?php echo $subtitle; ?></h3>
			<?php endif; ?>
			
			<?php if ( !empty($title) ): ?>
                <h2 <?php echo $this->get_render_attribute_string('title_text'); ?>><?php echo $title; ?></h2>
			<?php endif; ?>

			<?php if (!empty($description_text)): ?>
                <div <?php echo $this->get_render_attribute_string('description_text'); ?>><?php echo $description_text; ?></div>
			<?php endif; ?>
        </div>

		<?php
	}

	protected function _content_template() { ?>
        <#
        view.addRenderAttribute( 'subtitle_text', 'class', 'subtitle' );
        view.addInlineEditingAttributes( 'subtitle_text', 'none' );

        view.addRenderAttribute( 'title_text', 'class', 'section-title' );
        view.addInlineEditingAttributes( 'title_text', 'none' );

        view.addRenderAttribute( 'description_text', 'class', 'description' );
        view.addInlineEditingAttributes( 'description_text', 'none' );

        #>
        <div class="section-heading">

        	<# if(settings.subtitle_text) { #>
                <h3 {{{ view.getRenderAttributeString( 'subtitle_text' ) }}}>{{{ settings.subtitle_text }}}</h3>
            <# } #>

            <# if(settings.title_text) { #>
                <h2 {{{ view.getRenderAttributeString( 'title_text' ) }}}>{{{ settings.title_text }}}</h2>
            <# } #>

            <# if(settings.description_text) { #>
                <div {{{ view.getRenderAttributeString( 'description_text' ) }}}>{{{ settings.description_text }}}</p>
            <# } #>
        </div>
		<?php
	}
}



