<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

class Qhost_Hero_Static extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'tt-hero-static';
	}

	public function get_title() {
		return __( 'Qhost Hero', 'qhost-core' );
	}

	public function get_icon() {
		// Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
		return 'eicon-photo-library';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_hero',
			[
				'label' => __( 'Qhost Hero', 'qhost-core' ),
			]
		);

		// Layout
		// =====================
		$this->add_control( 'layout', [
			'label'   => esc_html__( 'Layout', 'qhost-core' ),
			'type'    => Controls_Manager::SELECT,
			'options' => [
				'1' => esc_html__( 'Layout 1(Main)', 'qhost-core' ),
				'2' => esc_html__( 'Layout 2', 'qhost-core' ),
				'3' => esc_html__( 'Layout 3', 'qhost-core' ),
				'4' => esc_html__( 'Layout 4', 'qhost-core' ),				
				'5' => esc_html__( 'Layout 5', 'qhost-core' ),				
			],
			'default' => '1',
		] );


		$this->end_controls_section();


		$this->start_controls_section( 'section_content', [
			'label' => esc_html__( 'Contents', 'qhost-core' ),
		] );

		$this->add_control(
			'sub_title',
			[
				'label'       => __( 'Sub Title', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Qhost Kubernetes', 'qhost-core' ),
				'label_block' => true,
				'description' => __( "Type your title here.", 'qhost-core' ),
				'condition'   => [
					'layout' => [ '1', '2' ]
				]
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Shared web hosting Done right', 'qhost-core' ),
				'label_block' => true,
				'description' => __( "Type your title here.", 'qhost-core' ),
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'list_title', [
				'label'       => __( 'Title', 'qhost-core' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => __( 'List Title', 'qhost-core' ),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'list_icon',
			[
				'label'   => __( 'Icon', 'qhost-core' ),
				'type'    => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value'   => 'fas fa-star',
					'library' => 'solid',
				],
			]
		);

		$this->add_control(
			'feature_list',
			[
				'label'       => __( 'Feature List', 'qhost-core' ),
				'type'        => \Elementor\Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'list_title' => __( 'Unmetered  Sub Domains, Accounts', 'qhost-core' ),
					],
					[
						'list_title' => __( '99%  Uptime Guarantee', 'qhost-core' ),
					],
					[
						'list_title' => __( '45 Day  Money-Back Guarantee', 'qhost-core' ),
					],
				],
				'title_field' => '{{{ list_title }}}',
				'condition'   => [
					'layout' => [ '4' ]
				]
			]
		);

		$this->add_control(
			'description',
			[
				'label'       => __( 'Description', 'qhost-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'     => __( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt', 'qhost-core' ),
				'label_block' => true,
			]
		);

		$this->end_controls_section();

		// Buttons
		// =====================
		$this->start_controls_section( 'settings_button', [
			'label'     => esc_html__( 'Button', 'qhost-core' ),
			'condition' => [
				'layout!' => '2'
			]
		] );

		$this->add_control(
			'btn_text',
			[
				'label'       => __( 'Button Label', 'qhost-core' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'placeholder' => __( 'Type your button title here', 'qhost-core' ),
				'default'     => __( 'Get Started', 'qhost-core' ),
			]
		);

		$this->add_control(
			'btn_link',
			[
				'label'         => __( 'Button Link', 'qhost-core' ),
				'type'          => \Elementor\Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'qhost-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '#',
					'is_external' => true,
					'nofollow'    => true,
				],
			]
		);

		// $this->add_control(
		// 	'btn_text_two',
		// 	[
		// 		'label'       => __( 'Button Label Two', 'qhost-core' ),
		// 		'type'        => \Elementor\Controls_Manager::TEXT,
		// 		'placeholder' => __( 'Type your button title here', 'qhost-core' ),
		// 		'default'     => __( 'Know More', 'qhost-core' ),
		// 		'condition'   => [
		// 			'layout' => ['2', '4']
		// 		]
		// 	]
		// );

		// $this->add_control(
		// 	'btn_link_two',
		// 	[
		// 		'label'         => __( 'Button Link Two', 'qhost-core' ),
		// 		'type'          => \Elementor\Controls_Manager::URL,
		// 		'placeholder'   => __( 'https://your-link.com', 'qhost-core' ),
		// 		'show_external' => true,
		// 		'default'       => [
		// 			'url'         => '#',
		// 			'is_external' => true,
		// 			'nofollow'    => true,
		// 		],
		// 		'layout' => ['2', '4']
		// 	]
		// );

		$this->end_controls_section();

		// Feature Image
		// =====================
		$this->start_controls_section(
			'feature_image_section',
			[
				'label'     => __( 'Feature Image', 'qhost-core' ),
				'tab'       => \Elementor\Controls_Manager::TAB_CONTENT,
				'condition' => [
					'layout!' => [ '6' ]
				]
			]
		);

		$this->add_control(
			'feature_image',
			[
				'label'   => __( 'Choose Image', 'qhost-core' ),
				'type'    => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => plugins_url( 'images/banner_feature_image.svg', __FILE__ )
				],
			]
		);

		$this->add_responsive_control(
			'margin',
			[
				'label'      => __( 'Margin', 'qhost-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .banner__feature-image' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'image_padding',
			[
				'label'      => __( 'Padding', 'qhost-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .banner__feature-image' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();



		# Domain Form
		/*=================*/
		$this->start_controls_section( 'section_domain', [
			'label'     => esc_html__( 'Domain Form', 'qhost-core' ),
			'condition' => [
				'layout' => [ '2', '5' ]
			]
		] );

		$this->add_control(
			'show_button',
			[
				'label'        => __( 'Extension Show/Hide', 'qhost-core' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'Show', 'your-plugin' ),
				'label_off'    => __( 'Hide', 'your-plugin' ),
				'return_value' => 'yes',
				'default'      => 'yes',
			]
		);


		$this->add_control(
			'placeholder_input',
			[
				'label'       => __( 'Placeholder Input Text', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Find your new domain name', 'qhost-core' ),
				'label_block' => true
			]
		);

		$this->add_control(
			'whmcs_url',
			[
				'label'         => __( 'Link', 'qhost-core' ),
				'type'          => \Elementor\Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'qhost-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '#',
					'is_external' => true,
					'nofollow'    => true,
				],
			]
		);

		$this->end_controls_section();

		# Domain Extension
		/*=================*/
		$this->start_controls_section(
			'extension__section',
			[
				'label' => __( 'Domain Extension and Price', 'qhost-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
				'condition' => [
					'layout' => [ '2', '5' ]
				]
			]
		);

		$this->add_control(
			'extension_list_show',
			[
				'label'        => __( 'Extension List Show/Hide', 'qhost-core' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'Show', 'your-plugin' ),
				'label_off'    => __( 'Hide', 'your-plugin' ),
				'return_value' => 'yes',
				'default'      => 'yes',
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'extension_domain', [
				'label'       => __( 'Extension', 'qhost-core' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => __( '.com', 'qhost-core' ),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'price',
			[
				'label'   => __( 'Price', 'qhost-core' ),
				'type'    => \Elementor\Controls_Manager::NUMBER,
				'min'     => 0,
				'max'     => 2000,
				'step'    => 1,
				'default' => 10,
			]
		);

		$repeater->add_control(
			'ext_color',
			[
				'label' => __( 'Extension Color', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .ext-name' => 'color: {{VALUE}}'
				],
			]
		);

		$repeater->add_control(
			'currency_symbol',
			[
				'label'   => __( 'Select Currency', 'qhost-core' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'&#36;'   => '&#36;',
					'&#128;'  => '&#128;',
					'&#8355;' => '&#8355;',
					'&#163;'  => '&#163;',
					'&#8381;' => '&#8381;',
					'&#8362;' => '&#8362;',
					'&#3647;' => '&#3647;',
					'&#165;'  => '&#165;',
					'&#8361;' => '&#8361;',
					'&fnof;'  => '&fnof;',
					'&#8369;' => '&#8369;',
					'&#8359'  => '&#8359',
					'&#8356;' => '&#8356;',
					'&#8360;' => '&#8360;',
					'&#8377;' => '&#8377;',
					'R$'      => 'R$',
					'kr'      => 'kr',
				],
				'default' => '&#36;'

			]
		);

		$this->add_control(
			'extension_list',
			[
				'label'       => __( 'Extension List', 'qhost-core' ),
				'type'        => \Elementor\Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'extension_domain' => __( '.com', 'qhost-core' ),
						'price'            => __( '10', 'qhost-core' ),
						'currency_symbol'  => "$",
					],
					[
						'extension_domain' => __( '.net', 'qhost-core' ),
						'price'            => __( '10', 'qhost-core' ),
						'currency_symbol'  => "$",
					],
					[
						'extension_domain' => __( '.org', 'qhost-core' ),
						'price'            => __( '10', 'qhost-core' ),
						'currency_symbol'  => "$",
					],
					[
						'extension_domain' => __( '.online', 'qhost-core' ),
						'price'            => __( '10', 'qhost-core' ),
						'currency_symbol'  => "$",
					],
				],
				'title_field' => '{{{ extension_domain }}}',
			]
		);

		$this->end_controls_section();

		// Style Settings
		// =====================

		$this->start_controls_section(
			'style',
			[
				'label' => __( 'Title', 'qhost-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'title_typography',
				'label'    => __( 'Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .banner__title',
			]
		);


		$this->add_control(
			'title_color',
			[
				'label'     => __( 'Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .banner__title' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'desi_color',
			[
				'label'     => __( 'Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .profile_info.style_4 .profile_info_iner h3' => 'color: {{VALUE}}',
				],
				'condition' => [
					'layout' => '7'
				]
			]
		);

		$this->add_control(
			'heading_color_type',
			array(
				'label'        => __( 'Color Type', 'qhost-core' ),
				'type'         => Controls_Manager::SELECT,
				'options'      => array(
					'color'    => __( 'Color', 'qhost-core' ),
					'gradient' => __( 'Background', 'qhost-core' ),
				),
				'default'      => 'color',
				'prefix_class' => 'dt-heading-fill-',
				'condition'    => [
					'layout' => '5'
				]
			)
		);
		$this->add_control(
			'heading_color',
			array(
				'label'     => __( 'Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .typed-title, {{WRAPPER}} .typed-cursor' => 'color: {{VALUE}};',
				),
				'condition' => array(
					'heading_color_type' => 'color',
					'layout'             => '5'
				),
			)
		);

		$this->end_controls_section();


		// Subtitle Style
		// =====================
		$this->start_controls_section(
			'sub_title_style',
			[
				'label'     => __( 'Sub Title', 'qhost-core' ),
				'tab'       => \Elementor\Controls_Manager::TAB_STYLE,
				'condition' => [
					'layout' => [ '4', '5', '9' ]
				]
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'title_sub_typography',
				'label'    => __( 'Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .banner-sub-title',
			]
		);

		$this->add_control(
			'sub_title_color',
			[
				'label'     => __( 'Title Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .banner-sub-title' => 'color: {{VALUE}}',
				],

			]
		);

		$this->end_controls_section();

		// Description
		// =====================
		$this->start_controls_section(
			'description_section',
			[
				'label' => __( 'Description', 'qhost-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,

			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'desc_typography',
				'label'    => __( 'Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .banner__description',
			]
		);

		$this->add_control(
			'des_color',
			[
				'label'     => __( 'Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .banner__description' => 'color: {{VALUE}}',
				],

			]
		);

		$this->end_controls_section();


		// Button Fill Style
		// =====================
		$this->start_controls_section(
			'style_button',
			[
				'label' => __( 'Button', 'qhost-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,

			]
		);

		$this->start_controls_tabs( 'tabs_button_style' );

		$this->start_controls_tab(
			'tab_button_normal_fill',
			[
				'label' => __( 'Normal', 'qhost-core' ),
			]
		);

		$this->add_control(
			'button_text_color',
			[
				'label'     => __( 'Text Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => [
					'{{WRAPPER}} .tt-btn' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_bg_color',
			[
				'label'     => __( 'Background Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => [
					'{{WRAPPER}} .tt-btn' => 'background: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'border_color',
			[
				'label'     => __( 'Border Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-btn' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_button_hover',
			[
				'label' => __( 'Hover', 'qhost-core' ),
			]
		);

		$this->add_control(
			'hover_color',
			[
				'label'     => __( 'Text Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-btn:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_hover_bg_color',
			[
				'label'     => __( 'Background Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-btn:hover' => 'background: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_hover_border_color',
			[
				'label'     => __( 'Border Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-btn:hover' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();

		// Background Settings
		// =====================
		$this->start_controls_section(
			'style_background',
			[
				'label' => __( 'Background', 'qhost-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name'     => 'banner_background',
				'label'    => __( 'Background', 'qhost-core' ),
				'types'    => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .banner',
			]
		);

		$this->end_controls_section();

		// Background Settings
		// =====================
		$this->start_controls_section(
			'style_background_overlay',
			[
				'label' => __( 'Background Overlay', 'qhost-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name'         => 'background_overlay',
				'label'        => __( 'Background', 'qhost-core' ),
				'types'        => [ 'classic', 'gradient' ],
				'selector'     => '{{WRAPPER}} .banner:before',
				'prefix_class' => 'tt-bg-overlay-'
			]
		);

		$this->end_controls_section();

		// Background Settings
		// =====================
		$this->start_controls_section(
			'style_background_two',
			[
				'label'     => __( 'Background', 'qhost-core' ),
				'tab'       => \Elementor\Controls_Manager::TAB_STYLE,
				'condition' => [
					'layout' => '2'
				]
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name'         => 'background_two',
				'label'        => __( 'Background', 'qhost-core' ),
				'types'        => [ 'classic', 'gradient' ],
				'selector'     => '{{WRAPPER}} .banner--two',
				'prefix_class' => 'tt-bg-overlay-'
			]
		);

		$this->add_control(
			'shape_image',
			[
				'label'   => __( 'Choose Image', 'qhost-core' ),
				'type'    => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => plugins_url( 'images/banner-two/banner-two.png', __FILE__ ),
				],
			]
		);

		$this->end_controls_section();
	}


	protected function render() {
		$settings     = $this->get_settings_for_display();
		$layout       = $settings['layout'];
		$btn_link     = $settings['btn_link'];
		$btn_text     = $settings['btn_text'];
		// $btn_link_two = $settings['btn_link_two'];
		// $btn_text_two = $settings['btn_text_two'];

		$target       = $settings['btn_link']['is_external'] ? ' target="_blank"' : '';
		$nofollow     = $settings['btn_link']['nofollow'] ? ' rel="nofollow"' : '';
		// $target_two   = $settings['btn_link_two']['is_external'] ? ' target="_blank"' : '';
		// $nofollow_two = $settings['btn_link_two']['nofollow'] ? ' rel="nofollow"' : '';

		require __DIR__ . '/templates/hero/layout-' . $layout . '.php';

	}

	protected function _content_template() {
	}
}