<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

class Qhost_Hotspot extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'tt-hotspot';
	}


	public function get_title() {
		return __( 'Qhost Hotspot', 'qhost-core' );
	}

	public function get_icon() {
		return 'eicon-counter';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return [ 'tt-elements' ];
	}

//	public function get_script_depends() {
//		return [
//			'countUp',
//			'appear-js'
//		];
//	}

	protected function _register_controls() {




		$this->start_controls_section(
			'animated_element',
			[
				'label' => __( 'Image', 'qhost-core' ),
			]
		);


		$this->add_control(
		   'image',
			[
				'label'   => __( 'Choose Image', 'qhost-core' ),
				'type'    => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => plugins_url( 'images/testimonial_icon_3.png', __FILE__ )
				],
			]
		);

		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			array(
				'name'    => 'image',
				'label'   => __( 'Image Size', 'qhost-core' ),
				'default' => 'large',
			)
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Markers', 'qhost-core' ),
			]
		);

		$repeater = new Repeater();

		$repeater->start_controls_tabs( 'marker_repeater' );

		$repeater->start_controls_tab( 'general_tab', array( 'label' => __( 'General', 'uael' ) ) );

		$repeater->add_control(
			'hotspot_type',
			array(
				'label'   => __( 'Marker Type', 'uael' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'ripple',
				'options' => array(
					'ripple'  => __( 'Ripple', 'uael' ),
					'text'  => __( 'Text', 'uael' ),
					'icon'  => __( 'Icon', 'uael' ),
					'image' => __( 'Image', 'uael' ),
				),
			)
		);

		$repeater->add_control(
			'marker_text',
			array(
				'default'   => __( 'Marker Text', 'uael' ),
				'type'      => Controls_Manager::TEXT,
				'label'     => __( 'Title', 'uael' ),
				'separator' => 'none',
				'dynamic'   => array(
					'active' => true,
				),
			)
		);

        $repeater->add_control(
            'new_icon',
            array(
                'label'              => __( 'Marker Icon', 'uael' ),
                'label_block'        => true,
                'type'               => Controls_Manager::ICONS,
                'fa4compatibility'   => 'icon',
                'default'            => array(
                    'value'   => 'fa fa-dot-circle-o',
                    'library' => 'fa-solid',
                ),
                'frontend_available' => true,
            )
        );

        $repeater->add_control(
			'hotspot_image',
			array(
				'label'     => __( 'Choose Image', 'uael' ),
				'type'      => Controls_Manager::MEDIA,
				'default'   => array(
					'url' => Utils::get_placeholder_image_src(),
				),
				'dynamic'   => array(
					'active' => true,
				),
				'condition' => array(
					'hotspot_type' => 'image',
				),
			)
		);

		$repeater->add_responsive_control(
			'tooltip_pos_horizontal',
			array(
				'label'     => __( 'Horizontal position (%)', 'qhost-core' ),
				'type'      => Controls_Manager::SLIDER,
				'range'     => array(
					'px' => array(
						'min'  => 0,
						'max'  => 100,
						'step' => 0.1,
					),
				),
				'selectors' => array(
					'{{WRAPPER}} {{CURRENT_ITEM}}'      => 'left: {{SIZE}}%; transform: translate(-{{SIZE}}%, 0);','.rtl {{WRAPPER}} {{CURRENT_ITEM}}' => 'right: {{SIZE}}%; transform: translate(0, -{{SIZE}}%); left: unset;',
				),
			)
		);

		$repeater->add_responsive_control(
			'tooltip_pos_vertical',
			array(
				'label'     => __( 'Vertical position (%)', 'qhost-core' ),
				'type'      => Controls_Manager::SLIDER,
				'range'     => array(
					'px' => array(
						'min'  => 0,
						'max'  => 100,
						'step' => 0.1,
					),
				),
				'selectors' => array(
					'{{WRAPPER}} {{CURRENT_ITEM}}' => 'top: {{SIZE}}%; transform: translate(0, -{{SIZE}}%);',
				),
			)
		);

		$repeater->end_controls_tab();

		$repeater->start_controls_tab( 'content_tab', array( 'label' => __( 'Content', 'uael' ) ) );

		$repeater->add_control(
			'content',
			array(
				'label'   => __( 'Tooltip Content', 'uael' ),
				'type'    => Controls_Manager::TEXTAREA,
				'default' => __( 'This is a tooltip', 'uael' ),
				'dynamic' => array(
					'active' => true,
				),
			)
		);

		$repeater->add_control(
			'marker_link',
			array(
				'label'       => __( 'Marker Link', 'uael' ),
				'description' => __( 'Note: Applicable only when tooltips trigger is set to Hover. Also, when Hotspot Tour option is enabled link will not work', 'uael' ),
				'type'        => Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'uael' ),
				'default'     => array(
					'url' => '',
				),
				'dynamic'     => array(
					'active' => true,
				),
			)
		);

		$repeater->end_controls_tab();

		$repeater->start_controls_tab( 'style_tab', array( 'label' => __( 'Style', 'uael' ) ) );

		$repeater->add_control(
			'hotspot_marker_options',
			array(
				'label'        => __( 'Override Global Settings', 'uael' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => 'no',
				'label_on'     => __( 'Yes', 'uael' ),
				'label_off'    => __( 'No', 'uael' ),
				'return_value' => 'yes',
			)
		);

		$repeater->add_responsive_control(
			'hotspot_icon_size',
			array(
				'label'      => __( 'Icon Size', 'uael' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => array( 'px', 'em', 'rem' ),
				'range'      => array(
					'px' => array(
						'min' => 1,
						'max' => 100,
					),
				),
				'condition'  => array(
					'hotspot_marker_options' => 'yes',
					'hotspot'                => 'icon',
				),
				'selectors'  => array(
					'{{WRAPPER}} {{CURRENT_ITEM}} .uael-hotspot-content'     => 'font-size: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} {{CURRENT_ITEM}} .uael-hotspot-content svg' => 'height: {{SIZE}}{{UNIT}}; width: {{SIZE}}{{UNIT}};',
				),
			)
		);

		$repeater->add_control(
			'hotspot_icons_color',
			array(
				'label'     => __( 'Color', 'uael' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} {{CURRENT_ITEM}} .uael-hotspot-content, 
								{{WRAPPER}} {{CURRENT_ITEM}} .uael-hotspot-content.uael-hotspot-anim:before' => 'color: {{VALUE}};',
					'{{WRAPPER}} {{CURRENT_ITEM}} .uael-hotspot-content svg'                                 => 'fill: {{VALUE}};',
				),
				'condition' => array(
					'hotspot_marker_options' => 'yes',
					'hotspot'                => array( 'text', 'icon' ),
				),
			)
		);

		$repeater->add_control(
			'hotspot_marker_bgcolor',
			array(
				'label'     => __( 'Background Color', 'uael' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'condition' => array(
					'hotspot_marker_options' => 'yes',
				),
				'selectors' => array(
					'{{WRAPPER}} {{CURRENT_ITEM}} .uael-hotspot-content, 
								{{WRAPPER}} {{CURRENT_ITEM}} .uael-hotspot-content.uael-hotspot-anim:before' => 'background-color: {{VALUE}};',
				),
			)
		);

		$repeater->end_controls_tab();

		$repeater->end_controls_tabs();


		$this->add_control(
			'hotspots',
			[
				'label'       => __( 'Markers', 'qhost-core' ),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'counter_icon' => [
							'value'   => 'fas fa-users',
							'library' => 'solid'
						],
						'count_number' => '21023'
					],
					[
						'counter_icon' => [
							'value'   => 'fas fa-cloud-download-alt',
							'library' => 'solid',
						],
						'count_number' => '44023'

					],
					[
						'counter_icon' => [
							'value'   => 'fas fa-smile',
							'library' => 'solid',
						],
						'count_number' => '35023'
					],
					[
						'counter_icon' => [
							'value'   => 'fas fa-mug-hot',
							'library' => 'solid',
						],
						'count_number' => '2323'
					],
				],
				'title_field' => '{{{ content }}}',
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => __( 'Alignment', 'qhost-core' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left'   => [
						'title' => __( 'Left', 'qhost-core' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'qhost-core' ),
						'icon'  => 'fa fa-align-center',
					],
					'right'  => [
						'title' => __( 'Right', 'qhost-core' ),
						'icon'  => 'fa fa-align-right',
					]
				],
				'default' => 'center',

			]
		);

		  $this->end_controls_section();

		$this->start_controls_section(
			'cstyle_section',
			[
				'label' => __( 'Countdown Style', 'qhost-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'counter_typography',
				'label'    => __( 'Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .tt-countdown-wrapper .dt-countdown .counter',
			]
		);

		$this->add_control(
			'counter_icon_color', [
				'label'     => esc_html__( 'Icon Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-countdown-wrapper .tt-countdown .counter-icon' => 'color: {{VALUE}};',
				],
			]
		);


		$this->add_control(
			'subtitle_color', [
				'label'     => esc_html__( 'Counter Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-countdown-wrapper .tt-countdown .counter' => 'color: {{VALUE}};',
				],
			]
		);


		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'counter_title_typography',
				'label'    => __( 'Title Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .tt-countdown-wrapper .tt-countdown .counter-title',
			]
		);

		$this->add_control(
			'counter_title_color', [
				'label'     => esc_html__( 'Title Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-countdown-wrapper .tt-countdown .counter-title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		$hotspots    = $settings['hotspots'];


		?>

        <div class="tt-hotspot">
            <?php echo Group_Control_Image_Size::get_attachment_image_html( $settings, 'large', 'image' ); ?>

            <ul class="tt-hotspot-items">
                <?php foreach ( $hotspots as $item ) : ?>
                    <li class="tt-hotspots-item elementor-repeater-item-<?php echo $item['_id']; ?>">
                        <?php if( ! empty( $item['content'] ) ) : ?>
                            <span class="tooltips <?php echo  $item['hotspot_type'] == 'ripple' ? 'ripple' : ''; ?>" data-toggle="tooltip" data-placement="top" title="<?php echo $item['content']; ?>">
                                <?php //echo $item['content']; ?>
                            </span>
                        <?php endif; ?>

                        <?php if ( $item['hotspot_type'] == 'text') : ?>
                            <?php if ( ! empty($item['marker_text'] ) ) : ?>
                                <span class="marker_text"><?php echo $item['marker_text']; ?></span>
                            <?php endif; ?>

                        <?php elseif ( $item['hotspot_type'] == 'icon' ): ?>

                            <?php if ( ! empty($item['new_icon'] ) ) : ?>
                                <span class="marker_icon">
                                    <?php \Elementor\Icons_Manager::render_icon( $item['new_icon'], [ 'aria-hidden' => 'true' ] ); ?>
                                </span>
                            <?php endif; ?>

                        <?php elseif ( $item['hotspot_type'] == 'hotspot_image' ): ?>

                            <?php if ( ! empty($item['hotspot_image']['url'] ) ) : ?>
                                <span class="marker_image">
                                    <img src="<?php echo  esc_attr( $item['hotspot_image']['url'])?>" alt="<?php echo esc_attr( $item['content']); ?>">
                                </span>
                            <?php endif; ?>
<!--                        --><?php //else : ?>
<!--                            <span class="ripple"></span>-->
                        <?php endif; ?>


                    </li>
                <?php endforeach; ?>
            </ul>

        </div>
        <!-- /.countdown-ccontainer -->
		<?php

	}

}

