<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Qhost_Icon_Box extends Widget_Base {

	public function get_name() {
		return 'tt-icon-box';
	}

	public function get_title() {
		return esc_html__( 'Qhost Icon Box', 'qhost-core' );
	}

	public function get_icon() {
		return 'eicon-icon-box';
	}

	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_tab', [
				'label' => esc_html__( 'Icon Box', 'qhost-core' ),
			]
		);

		$this->add_control(
			'layout',
			[
				'label'   => __( 'Layout', 'qhost-core' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'default' => '1',
				'options' => [
					'1' => __( 'Layout One', 'qhost-core' ),
					'2' => __( 'Layout Two', 'qhost-core' ),
					'3' => __( 'Layout Three', 'qhost-core' ),
					'4' => __( 'Layout Four', 'qhost-core' ),
					'5' => __( 'Layout Five', 'qhost-core' ),
					'6' => __( 'Layout Six', 'qhost-core' ),
					'7' => __( 'Layout Seven', 'qhost-core' ),
					'8' => __( 'Layout Eight', 'qhost-core' ),
					'9' => __( 'Layout Nine', 'qhost-core' ),
				],
			]
		);

		$this->add_control(
			'active_item',
			[
				'label'        => __( 'Active Item', 'qhost-core' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'Show', 'your-plugin' ),
				'label_off'    => __( 'Hide', 'your-plugin' ),
				'return_value' => 'yes',
				'default'      => 'no',
				'condition'    => [
					'layout'   => '3'
				]
			]
		);


		$this->add_control(
			'icon_type',
			[
				'label'       => esc_html__( 'Add Icon/Image', 'irecco-core' ),
				'type'        => Controls_Manager::CHOOSE,
				'label_block' => false,
				'options'     => [
					''      => [
						'title' => esc_html__( 'None', 'irecco-core' ),
						'icon'  => 'fa fa-ban',
					],
					'font'  => [
						'title' => esc_html__( 'Icon', 'irecco-core' ),
						'icon'  => 'fa fa-smile-o',
					],
					'image' => [
						'title' => esc_html__( 'Image', 'irecco-core' ),
						'icon'  => 'fa fa-picture-o',
					]
				],
				'default'     => 'font',
			]
		);

		$this->add_control(
			'icon_pack',
			[
				'label'     => esc_html__( 'Icon Pack', 'irecco-core' ),
				'type'      => Controls_Manager::SELECT,
				'condition' => [
					'icon_type' => 'font',
				],
				'options'   => [
					'fontawesome' => esc_html__( 'Fontawesome', 'irecco-core' ),
					'themify'    => esc_html__( 'Themify', 'irecco-core' ),
				],
				'default'   => 'fontawesome',
			]
		);

		$this->add_control(
			'icon_themify',
			[
				'label'       => esc_html__( 'Icon', 'irecco-core' ),
				'type'      => Controls_Manager::ICON,
				'options'   => qhost_themify_icons(),
				'include'   => qhost_include_themify_icons(),
				'default'   => 'ti-ruler-alt-2',
				'label_block' => true,
				'condition'   => [
					'icon_pack' => 'themify',
					'icon_type' => 'font',
				],
			]
		);

		$this->add_control(
			'box_icon',
			[
				'label'       => esc_html__( 'Icon', 'irecco-core' ),
				'type'        => Controls_Manager::ICONS,
				'label_block' => true,
				'default'   => [
					'value'   => 'fas fa-star',
					'library' => 'solid',
				],
				'condition'   => [
					'icon_pack' => 'fontawesome',
					'icon_type' => 'font',
				],
				'description' => esc_html__( 'Select icon from Fontawesome library.', 'irecco-core' ),
			]
		);

		$this->add_control(
			'icon_image',
			[
				'label'       => esc_html__( 'Image', 'irecco-core' ),
				'type'        => Controls_Manager::MEDIA,
				'label_block' => true,
				'condition'   => [
					'icon_type' => 'image',
				],
				'default'     => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'box_title', [
				'label'       => esc_html__( 'Box Title', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'Title', 'qhost-core' ),
				'default'     => esc_html__( 'Feature Heading', 'qhost-core' ),
			]
		);


		$this->add_control(
			'link',
			[
				'label'         => __( 'Link', 'qhost-core' ),
				'type'          => \Elementor\Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'qhost-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '',
					'is_external' => true,
					'nofollow'    => true,
				],
			]
		);

		$this->add_control(
			'description', [
				'label'       => esc_html__( 'Description', 'qhost-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'label_block' => true,
				'placeholder' => esc_html__( 'Description', 'qhost-core' ),
				'default'     => __( 'I transform thorny problems into elegant Lorem ipsum dolor amet', 'qhost-core' ),
				'separator'   => 'none',
			]
		);

		$this->add_control(
			'button_text', [
				'label'       => esc_html__( 'Button Text', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'Button Text', 'qhost-core' ),
				'default'     => __( 'Learn More', 'qhost-core' ),
				'separator'   => 'before',
			]
		);

		$this->add_control(
			'btn_link',
			[
				'label'         => __( 'Link', 'qhost-core' ),
				'type'          => \Elementor\Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'qhost-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '#',
					'is_external' => true,
					'nofollow'    => true,
				],
			]
		);

		$this->add_responsive_control(
			'title_align', [
				'label'     => esc_html__( 'Alignment', 'qhost-core' ),
				'type'      => Controls_Manager::CHOOSE,
				'options'   => [

					'left'    => [
						'title' => esc_html__( 'Left', 'qhost-core' ),
						'icon'  => 'fa fa-align-left',
					],
					'center'  => [
						'title' => esc_html__( 'Center', 'qhost-core' ),
						'icon'  => 'fa fa-align-center',
					],
					'right'   => [
						'title' => esc_html__( 'Right', 'qhost-core' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'qhost-core' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .tt-icon-box' => 'text-align: {{VALUE}};'
				],
				'condition' => [
					'layout!' => [ '4', '5', '8' ]
				]
			]
		);

		$this->add_responsive_control(
			'box_align', [
				'label'     => esc_html__( 'Icon Position', 'qhost-core' ),
				'type'      => Controls_Manager::CHOOSE,
				'options'   => [
					'icon-left'  => [
						'title' => esc_html__( 'Left', 'qhost-core' ),
						'icon'  => 'fa fa-align-left',
					],
					'icon-right' => [
						'title' => esc_html__( 'Right', 'qhost-core' ),
						'icon'  => 'fa fa-align-right',
					],
				],
				'default'   => 'icon-left',
				'toggle'    => false,
				'condition' => [
					'layout' => [ '4', '5', '8' ]
				]
			]
		);

		$this->add_control(
			'more_options_heading',
			[
				'label' => __( 'Spacing', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_responsive_control(
			'box_padding',
			[
				'label' => __( 'Padding', 'qhost-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .tt-icon-box' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'box_margin',
			[
				'label' => __( 'Margin', 'qhost-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .tt-icon-box' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);


		$this->end_controls_section();

		//Icon Style
		$this->start_controls_section(
			'section_icon_style', [
				'label' => esc_html__( 'Icon', 'qhost-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_color_one', [
				'label'     => esc_html__( 'Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-icon-box .icon-container' => 'color: {{VALUE}};'
				],
			]
		);

		$this->add_control(
			'icon_box_bg_color', [
				'label'     => esc_html__( 'Bg Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-icon-box .icon-container' => 'background-color: {{VALUE}};'
				],
				'condition' => [
					'layout' => ['2', '7']
				]
			]
		);

//		$this->add_control(
//			'icon_border_color', [
//				'label'     => esc_html__( 'Border Color', 'qhost-core' ),
//				'type'      => Controls_Manager::COLOR,
//				'selectors' => [
//					'{{WRAPPER}} .tt-icon-box .icon-container' => 'border-color: {{VALUE}};'
//				],
//			]
//		);

		$this->add_control(
			'icon_bg_color', [
				'label'     => esc_html__( 'Hover Background', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-icon-box .icon-container' => 'background-color: {{VALUE}};'
				],
				'condition' => [
					'layout' => [ '2', ]
				]
			]
		);

		$this->end_controls_section();

		//Title Style Section
		$this->start_controls_section(
			'section_title_style', [
				'label' => esc_html__( 'Title', 'qhost-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_color_two', [
				'label'     => esc_html__( 'Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-icon-box .box-title,
					{{WRAPPER}} .tt-icon-box .box-title a' => 'color: {{VALUE}};'
				],
			]
		);
		$this->add_control(
			'title_color_two_hover', [
				'label'     => esc_html__( 'Hover Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-icon-box .box-title:hover,
					{{WRAPPER}} .tt-icon-box .box-title a:hover' => 'color: {{VALUE}};'
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(), [
				'name'     => 'title_typography',
				'selector' => '{{WRAPPER}} .tt-icon-box .box-title',
			]
		);

		$this->end_controls_section();

		//Subtitle Style Section
		$this->start_controls_section(
			'section_subtitle_style', [
				'label' => esc_html__( 'Description', 'qhost-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'subtitle_color', [
				'label'     => esc_html__( 'color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-icon-box .description' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(), [
				'name'     => 'subtitle_typography',
				'selector' => '{{WRAPPER}} .tt-icon-box .description',
			]
		);

		$this->end_controls_section();

		//Subtitle Style Section
		$this->start_controls_section(
			'section_box_style', [
				'label' => esc_html__( 'Box', 'qhost-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'border',
				'label' => __( 'Border', 'marco-core' ),
				'selector' => '{{WRAPPER}} .tt-icon-box',
			]
		);


		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'background',
				'label' => __( 'Background', 'marco-core' ),
				'types' => [ 'classic', 'gradient'],
				'selector' => '{{WRAPPER}} .tt-icon-box',
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'icon_box_box_shadow',
				'label' => __( 'Box Shadow', 'marco-core' ),
				'selector' => '{{WRAPPER}} .tt-icon-box',
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'icon_box_box_shadow_hover',
				'label' => __( 'Box Shadow', 'marco-core' ),
				'selector' => '{{WRAPPER}} .tt-icon-box:hover',
			]
		);

		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		$layout   = $settings['layout'];
		$target   = $settings['link']['is_external'] ? ' target="_blank"' : '';
		$nofollow = $settings['link']['nofollow'] ? ' rel="nofollow"' : '';

		$btn_target   = $settings['btn_link']['is_external'] ? ' target="_blank"' : '';
		$btn_nofollow = $settings['btn_link']['nofollow'] ? ' rel="nofollow"' : '';

		require __DIR__ . '/templates/icon-box/layout-' . $layout . '.php';
	}

	protected function _content_template() {
	}
}



