<?php

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Qhost_Image extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'tt_image';
	}

	public function get_title()	{
		return __('Qhost Image', 'qhost-core');
	}

	public function get_icon() {
		// Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
		return 'eicon-image';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return ['tt-elements'];
	}


	/**
	 * Retrieve the list of scripts the image widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @return array Widget scripts dependencies.
	 * @since 1.3.0
	 * @access public
	 *
	 */
	public function get_script_depends() {
		return ['jquery-magnific-popup'];
	}


	protected function _register_controls()	{

		$this->start_controls_section(
			'section_content',
			[
				'label' => __('Content', 'qhost-core'),
			]
		);
		$this->add_control(
			'image',
			[
				'label' => __('Choose Image', 'qhost-core'),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'border-radius',
			[
				'label' => __( 'Image Border Radius', 'qhost-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .image-wrapper .feature-image' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'show_btn_video',
			[
				'label' => __('Show video button', 'qhost-core'),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'no',
				'label_on' => __('Show', 'qhost-core'),
				'label_off' => __('Hide', 'qhost-core'),
				'return_value' => 'yes',
			]
		);

		$this->add_control(
			'link_video',
			[
				'label' => __('URL Video', 'qhost-core'),
				'type' => Controls_Manager::URL,
				'default' => [
					'url' => '#',
					'is_external' => '',
				],
				'condition' => [
					'show_btn_video' => 'yes',
				],
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label' => __('Alignment', 'elementor'),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __('Left', 'elementor'),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __('Center', 'elementor'),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __('Right', 'elementor'),
						'icon' => 'fa fa-align-right',
					],
				],
				'default' => 'center',
				'selectors' => [
					'{{WRAPPER}}' => 'text-align: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'show_title_image',
			[
				'label' => __('Show Image Title', 'qhost-core'),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'no',
				'label_on' => __('Show', 'qhost-core'),
				'label_off' => __('Hide', 'qhost-core'),
				'return_value' => 'yes',
			]
		);
		$this->add_control(
			'title',
			[
				'label' => __('Title', 'qhost-core'),
				'type' => Controls_Manager::TEXT,
				'default' => 'Demo',
				'condition' => [
					'show_title_image' => 'yes',
				],
			]
		);
		$this->add_control(
			'link',
			[
				'label' => __('URL', 'qhost-core'),
				'type' => Controls_Manager::URL,
				'default' => [
					'url' => '#',
					'is_external' => '',
				],
				'condition' => [
					'show_title_image' => 'yes',
				],
			]
		);

		$this->add_control(
			'is_external',
			[
				'label' => __('Is External Links', 'qhost-core'),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_on' => __('Show', 'qhost-core'),
				'label_off' => __('Hide', 'qhost-core'),
				'return_value' => 'yes',
				'condition' => [
					'show_title_image' => 'yes',
				],
			]
		);

		$this->end_controls_section();

	}

	protected function render()	{

		$settings = $this->get_settings();
		$image = $settings['image'];
		$title = $settings['title'];
		$link = $settings['link'];
		$link_video = $settings['link_video'];
		$target = $settings['is_external'] == 'yes' ? ' target="_blank"' : '';

		$css_wrap = "image-wrapper";
		$css_img = "";
		if ($settings['show_btn_video'] === 'yes') {
			$css_wrap .= " p-relative img-video";
			$css_img .= "feature-image";
		}
		if ($settings['show_title_image'] === 'yes') {
			$css_wrap .= " img-show-title";
			$css_img .= "title-bg";
		}
		if ($settings['show_btn_video'] === 'yes' && $settings['show_title_image'] === 'yes') {
			$css_wrap .= " p-relative img-show-title-video";
			$css_img .= "video-image";
		}

		?>
        <div class="<?php echo $css_wrap; ?>">
			<?php if ($settings['show_btn_video'] === 'yes'): ?>
                <img class="<?php echo $css_img; ?>" src="<?php if ($image['url'] != '') echo $image['url']; ?>" alt="">
			<?php else: ?>
                <a href="<?php if ($link['url'] != '') echo $link['url']; ?>" <?php echo $target; ?>>
                    <img class="<?php echo $css_img; ?>" src="<?php if ($image['url'] != '') echo $image['url']; ?>"
                         alt="">
                </a>
			<?php endif; ?>

			<?php if ($settings['show_btn_video'] === 'yes' || $settings['show_title_image'] === 'yes'): ?>
                <div class="content-inner">

					<?php if ($settings['show_btn_video'] === 'yes'): ?>
                        <a class="popup-play-btn popup-video"
                           href="<?php if ($link_video['url'] != '') echo $link_video['url']; ?>" <?php echo $target; ?>
                           data-lity=""><i class="fas fa-play"></i></a>
					<?php endif ?>

					<?php if ($settings['show_title_image'] === 'yes'):
                        if(!empty($settings['title'])) { ?>
                        <a class="image-title"  href="<?php if ($link['url'] != '') echo $link['url']; ?>" <?php echo $target; ?>>
                            <h6><?php echo $title; ?>
								<?php if (!empty($settings['title'])): ?>
                                    <span class="title"><?php echo $settings['title']; ?></span>
								<?php endif; ?>
                            </h6>
                        </a>
					<?php } endif; ?>

                </div>
			<?php endif; ?>
        </div>
		<?php

	}
}
