<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Qhost_Info_Box extends Widget_Base {

	public function get_name() {
		return 'tt-info-box';
	}

	public function get_title() {
		return esc_html__( 'Qhost Info Box', 'qhost-core' );
	}

	public function get_icon() {
		return 'eicon-icon-box';
	}

	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_tab', [
				'label' => esc_html__( 'Info Box', 'qhost-core' ),
			]
		);

		$this->add_control(
			'box_title', [
				'label'       => esc_html__( 'Title', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'Title', 'qhost-core' ),
				'default'     => esc_html__( 'Service Heading', 'qhost-core' ),
			]
		);

		$this->add_control(
			'description', [
				'label'       => esc_html__( 'Description', 'qhost-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'label_block' => true,
				'placeholder' => esc_html__( 'Description', 'qhost-core' ),
				'default'     => esc_html__( 'My lady bugger tomfoolery pardon you cor blimey guvnor harry blag.', 'qhost-core' ),
			]
		);

		$this->add_control(
			'button_text', [
				'label'       => esc_html__( 'Button Text', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'Button Text', 'qhost-core' ),
				'default'     => __( 'Learn More', 'qhost-core' ),
				'separator'   => 'before',
			]
		);

		$this->add_control(
			'btn_link',
			[
				'label'         => __( 'Link', 'qhost-core' ),
				'type'          => \Elementor\Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'qhost-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '#',
					'is_external' => true,
					'nofollow'    => true,
				],
			]
		);

		$this->add_responsive_control(
			'title_align', [
				'label'     => esc_html__( 'Alignment', 'qhost-core' ),
				'type'      => Controls_Manager::CHOOSE,
				'options'   => [

					'left'    => [
						'title' => esc_html__( 'Left', 'qhost-core' ),
						'icon'  => 'fa fa-align-left',
					],
					'center'  => [
						'title' => esc_html__( 'Center', 'qhost-core' ),
						'icon'  => 'fa fa-align-center',
					],
					'right'   => [
						'title' => esc_html__( 'Right', 'qhost-core' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'qhost-core' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .tt-info-box' => 'text-align: {{VALUE}};'
				],
			]
		);

		$this->end_controls_section();


		//Title Style Section
		$this->start_controls_section(
			'section_title_style', [
				'label' => esc_html__( 'Title', 'qhost-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_color_two', [
				'label'     => esc_html__( 'Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-info-box .box-title,
					{{WRAPPER}} .tt-info-box .box-title a' => 'color: {{VALUE}};'
				],
			]
		);
		$this->add_control(
			'title_color_two_hover', [
				'label'     => esc_html__( 'Hover Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-info-box .box-title:hover,
					{{WRAPPER}} .tt-info-box .box-title a:hover' => 'color: {{VALUE}};'
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(), [
				'name'     => 'title_typography',
				'selector' => '{{WRAPPER}} .tt-info-box .box-title',
			]
		);

		$this->end_controls_section();

		//Subtitle Style Section
		$this->start_controls_section(
			'section_subtitle_style', [
				'label' => esc_html__( 'Description', 'qhost-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'subtitle_color', [
				'label'     => esc_html__( 'color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-info-box .description' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(), [
				'name'     => 'subtitle_typography',
				'selector' => '{{WRAPPER}} .tt-info-box .description',
			]
		);

		$this->end_controls_section();

		//Icon Style
		$this->start_controls_section(
			'section_service_style', [
				'label' => esc_html__( 'Background', 'qhost-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'service_bg_color', [
				'label'     => esc_html__( 'Background Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-info-box' => 'background: {{VALUE}};'
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'service_bg_color',
				'label' => __( 'Background', 'qhost-core' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .tt-info-box',
			]
		);

		$this->add_control(
			'service_border_color', [
				'label'     => esc_html__( 'Border Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-info-box' => 'border-color: {{VALUE}};'
				],
			]
		);


		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		$btn_target   = $settings['btn_link']['is_external'] ? ' target="_blank"' : '';
		$btn_nofollow = $settings['btn_link']['nofollow'] ? ' rel="nofollow"' : '';

		require __DIR__ . '/templates/service/layout-2.php';
	}

	protected function _content_template() {
	}
}



