<?php

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Qhost_List extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name()
	{
		return 'tt-list';
	}


	public function get_title()
	{
		return __('Qhost List', 'qhost-core');
	}

	public function get_icon()
	{

		return 'eicon-editor-list-ul';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories()
	{
		return ['tt-elements'];
	}

	protected function _register_controls()
	{

		$this->start_controls_section(
			'section_content',
			[
				'label' => __('List', 'qhost-core'),
			]
        );
        
//        $this->add_control(
//			'list_inline',
//			[
//				'label' => __( 'Layout', 'qhost-core' ),
//				'type' => \Elementor\Controls_Manager::SELECT,
//				'label_on' => __( 'Inline', 'qhost-core' ),
//				'label_off' => __( 'Stack', 'qhost-core' ),
//				'return_value' => 'yes',
//				'default' => 'yes',
//			]
//        );

        $this->add_control(
			'list_inline',
			[
				'label' => __( 'Layout', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'block',
				'options' => [
					'block'  => __( 'Block', 'qhost-core' ),
					'inline' => __( 'Inline', 'qhost-core' ),
					'half' => __( 'Half', 'qhost-core' ),
				],
			]
		);
        
        $this->add_control(
			'icon_show',
			[
				'label' => __( 'Icon Show', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'qhost-core' ),
				'label_off' => __( 'No', 'qhost-core' ),
				'return_value' => 'yes',
				'default' => false,
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'list_title', [
				'label' => __('Title', 'qhost-core'),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __('List Title', 'qhost-core'),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'icon',
			[
				'label' => __( 'Icon', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'fas fa-star',
					'library' => 'solid',
				],
			]
		);

		$repeater->add_control(
			'link',
			[
				'label' => __('Link', 'qhost-core'),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __('https://your-link.com', 'qhost-core'),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);


		$this->add_control(
			'list',
			[
				'label' => __('Repeater List', 'qhost-core'),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'list_title' => __('List One', 'qhost-core'),
						'icon' => [
						        'value' => 'fas fa-check-circle'
                            ]
					],
					[
						'list_title' => __('List Two', 'qhost-core'),
						'icon' => [
						        'value' => 'fas fa-check-circle'
                            ]
					],
					[
						'list_title' => __('List Three', 'qhost-core'),
						'icon' => [
						        'value' => 'fas fa-check-circle'
                            ]
					],
				],
				'title_field' => '{{{ list_title }}}',
			]
        );        
  

		$this->add_responsive_control(
			'list_align', [
				'label' => esc_html__('Alignment', 'qhost-core'),
				'type' => Controls_Manager::CHOOSE,
				'options' => [

					'left' => [
						'title' => esc_html__('Left', 'qhost-core'),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__('Center', 'qhost-core'),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__('Right', 'qhost-core'),
						'icon' => 'fa fa-align-right',
					],
				
				],			
				'selectors' => [
					'{{WRAPPER}} .tt-list' => 'text-align: {{VALUE}};'
				]
			]
		);

        $this->end_controls_section();
        
        $this->start_controls_section(
			'list_style_section',
			[
				'label' => __( 'List Style', 'qhost-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
        );
        
        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'list_typography',
				'label' => __( 'Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .tt-list li',
			]
		);

		$this->add_control(
			'list_color',
			[
				'label' => __( 'Color', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
                    '{{WRAPPER}} .tt-list li,
                    {{WRAPPER}} .tt-list li a' => 'color: {{VALUE}}',
				],
			]
        );

		$this->add_control(
			'list_icon_color',
			[
				'label' => __( 'Icon Color', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
                    '{{WRAPPER}} .tt-list li i' => 'color: {{VALUE}}',
				],
			]
        );
        
        $this->add_control(
			'list_hover_color',
			[
				'label' => __( 'Hover Color', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
                    '{{WRAPPER}} .tt-list li:hover,
                    {{WRAPPER}} .tt-list li a:hover' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();

	}

	protected function render() {
        $settings = $this->get_settings_for_display();

        $list_icon_display = $settings[ 'icon_show' ] !== 'yes' ? 'list-dice' : 'list-icon';
        $layout = $settings[ 'list_inline' ];

        $this->add_render_attribute('list', 'class', 'tt-list '.$list_icon_display.' '.$layout .'');


		if ($settings['list']) { ?>
            <ul <?php echo $this->get_render_attribute_string('list'); ?>>
				<?php foreach ($settings['list'] as $item) {

					$target = $item['link']['is_external'] ? ' target="_blank"' : '';
					$nofollow = $item['link']['nofollow'] ? ' rel="nofollow"' : '';
					?>
                    <li>
						<?php if (!empty($item['link']['url'])) : ?>
                        <a href="<?php echo esc_attr($item['link']['url']); ?>" <?php echo $target, $nofollow ?>>
							<?php endif; ?>

                            <?php if ( 'yes' === $settings['icon_show']) : ?>
                                <?php \Elementor\Icons_Manager::render_icon( $item['icon'], [ 'aria-hidden' => 'true' ] ); ?>
                            <?php endif ?>

							<p><?php echo $item['list_title']; ?></p>

							<?php if (!empty($item['link']['url'])) : ?>
                        </a>
					<?php endif; ?>
                    </li>

				<?php } ?>
            </ul>
		<?php }

	}

}

