<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit;

class Qhost_Logo_Carousel extends Widget_Base {

    public function get_name() {
        return 'tt-logo-carousel';
    }

    public function get_title() {
        return esc_html__( 'Qhost Logo Carousel', 'qhost-core' );
    }

    public function get_icon() {
        return 'eicon-carousel';
    }

    public function get_categories() {
        return [ 'tt-elements' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_tab_style',
            [
                'label' => esc_html__('Logo Carousel', 'qhost-core'),
            ]
        );     

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
			'image',
			[
				'label' => __( 'Logo', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],

			]
		);

		$repeater->add_control(
			'link',
			[
				'label' => __( 'Link', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);


		$this->add_control(
			'logos',
			[
				'label' => __( 'Logo List', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'image' => [
                            'url' => \Elementor\Utils::get_placeholder_image_src(),
                        ],                       
					
					],
					[
						'image' =>  [
                            'url' => \Elementor\Utils::get_placeholder_image_src(),
                        ]
					],
					[
						'image' =>  [
                            'url' => \Elementor\Utils::get_placeholder_image_src(),
                        ]
					],
					[
						'image' =>  [
                            'url' => \Elementor\Utils::get_placeholder_image_src(),
                        ]
					],
					[
						'image' =>  [
                            'url' => \Elementor\Utils::get_placeholder_image_src(),
                        ]
					],
				],
				'title_field' => '{{{ name }}}',
			]
		);

		$this->end_controls_section();

   

        $this->end_controls_section();

        
		$this->start_controls_section( 'settingd_section', [
			'label' => esc_html__( 'Slider Control', 'qhost-core' ),
		] );

		$this->add_control(
			'perview',
			[
				'label' => __('Desktop Per View', 'qhost-core'),
				'type' => Controls_Manager::NUMBER,
                'default' => 5,
               
			]
        );
        
        $this->add_control(
			'perview_tablet',
			[
				'label' => __('Tablet Per View', 'qhost-core'),
				'type' => Controls_Manager::NUMBER,
                'default' => 3,                
			]
        );
        
        $this->add_control(
			'perview_mobile',
			[
				'label' => __('Mobile Per View', 'qhost-core'),
				'type' => Controls_Manager::NUMBER,
                'default' => 2,
			]
		);	

		$this->add_control(
			'loop',
			[
				'label' => esc_html__('Loop', 'qhost-core'),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('On', 'qhost-core'),
				'label_off' => esc_html__('Off', 'qhost-core'),
				'return_value' => 'true',
				'default' => 'yes'
			]
		);

		$this->add_control(
			'speed',
			[
				'label' => __('Speed', 'qhost-core'),
				'type' => Controls_Manager::NUMBER,
				'default' => 700,
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label' => esc_html__('Autoplay', 'qhost-core'),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('On', 'qhost-core'),
				'label_off' => esc_html__('Off', 'qhost-core'),
				'return_value' => 'true',
				'default' => 'yes'
			]
		);

		$this->add_control(
			'autoplay_time',
			[
				'label' => __('Autoplay Time', 'qhost-core'),
				'type' => Controls_Manager::NUMBER,
				'default' => 3000,
				// 'condition' => [
				// 	'autoplay' => 'yes'
				// ]
			]
		);

		$this->end_controls_section();

    }

    protected function render( ) {

        $settings = $this->get_settings_for_display();
        $logos = $settings['logos'];
   

        $this->add_render_attribute( 'wrapper', 'class', [		
			'swiper-container',
			'tt-client-logo',
		] );

       
		$slider_options = $this->get_slider_options( $settings );

		$this->add_render_attribute( 'wrapper', 'data-logo', wp_json_encode( $slider_options ) );
	

	   ?>
	   
			<div class="dt-logo-carousel">
				<div <?php $this->print_render_attribute_string( 'wrapper' ); ?>>
					<div class="swiper-wrapper">
						<?php if ( is_array( $logos )) :
							foreach( $logos as $logo ) : ?>
								<?php if( $logo[ 'image' ] != '' ){            
									$img = $logo[ 'image' ][ 'url' ];              
								} 
								?>
								<div class="swiper-slide">
									<div class="client-logo text-center">
										<?php if( !empty( $img ) ): ?>
											
											<img src="<?php echo esc_url($img) ?>"  alt="<?php echo esc_attr__( 'Brand logo', 'qhost-core' ) ?>">
										
										<?php endif; ?>                                    
									</div>
								</div>
								<!-- /.swiper-slide -->
								<?php 
							endforeach;                
						endif;
						?>
					</div>
					<!-- /.swiper-wrapper -->
				</div>
				<!-- /.swiper-container -->
			</div>
			<!-- /.dt-logo-carousel -->

	   <?php 

    }

    protected function _content_template() { }

    protected function get_slider_options( array $settings ) {

        // Per View.
   
		if ( ! empty( $settings['perview'] ) ) {
			$slider_options['breakpoints'] = [
				'992' => [
					'slidesPerView' => $settings['perview'],
					'spaceBetween' => '30'
				],

				'620' => [
					'slidesPerView' => $settings['perview_tablet'],
					'spaceBetween' => '30'
				],

				'320' => [
					'slidesPerView' => $settings['perview_mobile'],
					'spaceBetween' => '20'
				],
			];
		}   

		// Loop
		if ( $settings['loop'] ) {
			$slider_options['loop'] = (bool)$settings['loop'];
		}

		// Speed
		if ( ! empty( $settings['speed'] ) ) {
			$slider_options['speed'] = $settings['speed'];
		}
		if ( $settings['autoplay'] ) {
			$slider_options['autoplay'] = (bool)$settings['autoplay'];
		}

		if ( $settings['autoplay'] ) {			
			$slider_options['autoplay'] = [
				'delay' => $settings['autoplay_time']				
			];		
		}


		return $slider_options;
    }
}