<?php

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Qhost_Logo_List extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name()
	{
		return 'tt-logo-list';
	}


	public function get_title()
	{
		return __('Qhost Logo List', 'qhost-core');
	}

	public function get_icon()
	{

		return 'eicon-editor-list-ul';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories()
	{
		return ['tt-elements'];
	}

	protected function _register_controls()
	{

		$this->start_controls_section(
			'section_content',
			[
				'label' => __('Logos', 'qhost-core'),
			]
        );      


		$repeater = new Repeater();

		$repeater->add_control(
			'logo_title', [
				'label' => __('Company Name', 'qhost-core'),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __('Company Name', 'qhost-core'),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'logo_image',
			[
				'label' => __( 'Choose Image', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);
	

	
		$repeater->add_control(
			'link',
			[
				'label' => __('Link', 'qhost-core'),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __('https://your-link.com', 'qhost-core'),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);


		$this->add_control(
			'logo_lists',
			[
				'label' => __('Logo List', 'qhost-core'),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'logo_title' => __('List One', 'qhost-core'),
						'logo_image' =>  [
							'url' => \Elementor\Utils::get_placeholder_image_src(),
						],
					],
					[
						'logo_title' => __('List One', 'qhost-core'),
						'logo_image' =>  [
							'url' => \Elementor\Utils::get_placeholder_image_src(),
						],
					],
					[
						'logo_title' => __('List One', 'qhost-core'),
						'logo_image' =>  [
							'url' => \Elementor\Utils::get_placeholder_image_src(),
						],
					],
				],
				'title_field' => '{{{ logo_title }}}',
			]
        );

        $this->end_controls_section();
        
        $this->start_controls_section(
			'list_style_section',
			[
				'label' => __( 'List Style', 'qhost-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
        );
        
        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'list_typography',
				'label' => __( 'Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .tt-logo-list li',
			]
		);

		$this->add_control(
			'list_color',
			[
				'label' => __( 'Color', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
                    '{{WRAPPER}} .tt-logo-list li,
                    {{WRAPPER}} .tt-logo-list li a' => 'color: {{VALUE}}',
				],
			]
        );

		$this->add_control(
			'list_icon_color',
			[
				'label' => __( 'Icon Color', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
                    '{{WRAPPER}} .tt-logo-list li i' => 'color: {{VALUE}}',
				],
			]
        );
        
        $this->add_control(
			'list_hover_color',
			[
				'label' => __( 'Hover Color', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
                    '{{WRAPPER}} .tt-logo-list li:hover,
                    {{WRAPPER}} .tt-logo-list li a:hover' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();

	}

	protected function render() {
        $settings = $this->get_settings_for_display();


        $this->add_render_attribute('list', 'class', 'tt-logo-list');


		if ($settings['logo_lists']) { ?>
            <ul <?php echo $this->get_render_attribute_string('list'); ?>>
				<?php foreach ($settings['logo_lists'] as $item) {

					$target = $item['link']['is_external'] ? ' target="_blank"' : '';
					$nofollow = $item['link']['nofollow'] ? ' rel="nofollow"' : '';
					?>
                    <li>
						<?php if (!empty($item['link']['url'])) : ?>
                        	<a href="<?php echo esc_attr($item['link']['url']); ?>" <?php echo $target, $nofollow ?>>
						<?php endif; ?>

							<div class="logo-image">
								<img src="<?php echo esc_url( $item['logo_image']['url']) ?>" alt="<?php echo esc_attr($item['logo_title']) ?>">
							</div>

						<?php if (!empty($item['link']['url'])) : ?>
	                        </a>
						<?php endif; ?>
                    </li>

				<?php } ?>
            </ul>
		<?php }

	}

}

