<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Qhost_Newsletter extends Widget_Base {

    /**
    * Get widget name.
    *
    * Retrieve alert widget name.
    *
    * @since 1.0.0
    * @access public
    *
    * @return string Widget name.
    */
    public function get_name() {
        return 'tt-newsletter';
    }


    public function get_title() {
        return __( 'Qhost Newsletter', 'qhost-core' );
    }

    public function get_icon() {
        // Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
        return 'fas fa-paper-plane';
    }

    public function get_script_depends() {
		return [
			'qhost-form'
		];
	}

    /**
    * Get widget categories.
    *
    * Retrieve the widget categories.
    *
    * @since 1.0.0
    * @access public
    *
    * @return array Widget categories.
    */
    public function get_categories() {
        return [ 'tt-elements' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_content',
            [
                'label' => __( 'Newsletter', 'qhost-core' ),
            ]
        );

        $this->add_control(
			'title', [
				'label'			 => esc_html__( 'Title', 'qhost-core' ),
				'type'			 => Controls_Manager::TEXTAREA,
                'label_block'	 => true,
                'default'        => __('Subscribe our Newsletter', 'qhost-core'),
				'placeholder'	 => esc_html__( 'Title', 'qhost-core' ),
                'separator' => 'before',
			]
        );

        $this->add_control(
			'sub_title', [
				'label'			 => esc_html__( 'Sub Title', 'qhost-core' ),
                'type'			 => Controls_Manager::TEXT,
                'default'        => __('We’re a team of non-cynics who truly care for our work.', 'qhost-core'),
				'label_block'	 => true,
				'placeholder'	 => esc_html__( 'Subtitle', 'qhost-core' ),
			]
		);

        $this->end_controls_section();
 
  
        $this->start_controls_section(
            'content',
            [
                'label' => esc_html__('Content', 'qhost-core'),
                'tab'   => Controls_Manager::TAB_STYLE,               
            ]
        );


		$this->add_control(
			'title_color', [
				'label'		 => esc_html__( 'Title Color', 'qhost-core' ),
				'type'		 => Controls_Manager::COLOR,
				'selectors'	 => [
					'{{WRAPPER}} #newsletter .section-heading .section-title' => 'color: {{VALUE}}',
				],
			]
        );
        
        $this->add_group_control(
			Group_Control_Typography::get_type(), [
            'name'		 => 'title_typography',
            'selector' => '
                {{WRAPPER}} #newsletter .section-heading .section-title',        
            ]			
        );
        
        $this->add_control(
			'subtitle_color', [
				'label'		 => esc_html__( 'Subtitle Color', 'qhost-core' ),
				'type'		 => Controls_Manager::COLOR,
				'selectors'	 => [
					'{{WRAPPER}} #newsletter .section-heading .subtitle' => 'color: {{VALUE}};',
                ],
                'separator' => 'before',
			]
        );
        
        $this->add_group_control(
			Group_Control_Typography::get_type(), [
			'name'		 => 'subtitle_typography',
			'selector'	 => '{{WRAPPER}} #newsletter .section-heading .subtitle',
			]
        );
        
        $this->add_control(
			'button_color', [
				'label'		 => esc_html__( 'Button Color', 'qhost-core' ),
				'type'		 => Controls_Manager::COLOR,
				'selectors'	 => [
                    '{{WRAPPER}} .newsletter-submit' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
			]
        );

        $this->add_control(
			'button_bg_color', [
				'label'		 => esc_html__( 'Button Background Color', 'qhost-core' ),
				'type'		 => Controls_Manager::COLOR,
				'selectors'	 => [
					'{{WRAPPER}} .newsletter-submit' => 'background-color: {{VALUE}}',

                ],
            
			]
        );

        
        $this->add_control(
			'button_color_hover', [
				'label'		 => esc_html__( 'Button Hove Color', 'qhost-core' ),
				'type'		 => Controls_Manager::COLOR,
				'selectors'	 => [
					'{{WRAPPER}} .newsletter-submit:hover' => 'color: {{VALUE}}',
                ],
                'separator' => 'before',
			]
        );

        $this->add_control(
			'button_bg_color_hover', [
				'label'		 => esc_html__( 'Button Bover Background Color', 'qhost-core' ),
				'type'		 => Controls_Manager::COLOR,
				'selectors'	 => [
					'{{WRAPPER}} .newsletter-submit' => 'background-color: {{VALUE}}',

                ],
            
			]
        );
        
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_shape',
            [
                'label' => esc_html__('Background', 'qhost-core'),
                'tab'   => Controls_Manager::TAB_STYLE,               
            ]
        );

        $this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'background',
				'label' => __( 'Background', 'qhost-core' ),
				'types' => [ 'classic', 'gradient' ],
				'default' => [ '#000'],
				'selector' => '{{WRAPPER}} #newsletter'              
			]
        );

        $this->end_controls_section();
        
        $this->start_controls_section(
			'style_section',
			[
				'label' => __( 'Specing', 'qhost-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'title_padding',
			[
				'label' => __( 'Padding', 'qhost-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} #newsletter' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

        $this->end_controls_section();      

    }

    protected function render( ) {
        $settings = $this->get_settings_for_display(); 
        $sub_title = $settings[ 'sub_title' ];	
		$title = $settings[ 'title' ];
 

        $this->add_render_attribute( 'sub_title', 'class','subtitle');
        $this->add_inline_editing_attributes( 'sub_title', 'none' );
        
        $this->add_render_attribute( 'title', 'class','section-title');
		$this->add_inline_editing_attributes( 'title' );

       ?>

        <div class="newsletter" id="newsletter">
            <div class="container">
                <div class="row">
                    <div class="col-lg-7">
                        <div class="section-heading">
                            <?php if(!empty($title)): ?>
                                <h2 <?php echo $this->get_render_attribute_string( 'title' ); ?>>
                                    <?php echo $title; ?>
                                </h2>
                            <?php endif; ?>

                             <?php if(!empty($sub_title)): ?>
                                <h3 <?php echo $this->get_render_attribute_string( 'sub_title' ); ?>><?php echo $sub_title; ?></h3>
                            <?php endif; ?>
                        </div>
                        <!-- /.newsletter-content -->
                    </div>

                    <div class="col-lg-5">
                        <form action="<?php echo admin_url( 'admin-ajax.php' ); ?>" method="post" class="newsletter-form wow pixFadeUp" data-apdash-form="newsletter-subscribe">
                            <input type="hidden" name="action" value="apdash_mailchimp_subscribe">

                            <div class="newsletter-inner form-row justify-content-center">
                                <input type="email" name="email" class="form-control" id="newsletter-form-email"  placeholder="<?php echo esc_attr__( 'Enter Your Email*', 'qhost-core'); ?>" required>

                                <button type="submit" name="submit" id="newsletter-submit" class="newsletter-submit">
                                    <i class="fas fa-paper-plane"></i>
                                    <i class="fa fa-circle-o-notch fa-spin"></i>
                                </button>
                            </div>

                            <div class="form-result alert">
                                <div class="content"></div>
                            </div><!-- /.form-result-->
                        </form><!-- /.newsletter-form -->
                    </div>
                </div>
                <!-- /.row -->
            </div>
            <!-- /.container -->
        </div>
        <!-- /.newsletter -->
        <?php
    }
}

