<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Qhost_Popup_Video extends Widget_Base {

    /**
    * Get widget name.
    *
    * Retrieve alert widget name.
    *
    * @since 1.0.0
    * @access public
    *
    * @return string Widget name.
    */
    public function get_name() {
        return 'tt-popup-video';
    }


    public function get_title() {
        return __( 'Qhost Popup Video', 'qhost-core' );
    }

    public function get_icon() {
        // Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
        return 'eicon-google-maps';
    }

    /**
    * Get widget categories.
    *
    * Retrieve the widget categories.
    *
    * @since 1.0.0
    * @access public
    *
    * @return array Widget categories.
    */
    public function get_categories() {
        return [ 'tt-elements' ];
    }


    protected function _register_controls() {

        $this->start_controls_section(
            'section_content',
            [
                'label' => __( 'Qhost Popup Video', 'qhost-core' ),
            ]
        );

        $this->add_control(
            'video_link',
            [
                'label'       => __( 'Video Link', 'qhost-core' ),
                'type'        => Controls_Manager::TEXT, 
                'label_block' => true
            ]
        ); 

        $this->add_responsive_control(
			'text_align',
			[
				'label' => __( 'Alignment', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'plugin-domain' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'plugin-domain' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'plugin-domain' ),
						'icon' => 'fa fa-align-right',
					],
				],
                'default' => 'left',
                'selectors' => [
					'{{WRAPPER}} .play-button' => 'text-align: {{VALUE}};'
				],
				'toggle' => true,
			]
		);

        $this->end_controls_section();    
        
        // Style Section
        $this->start_controls_section(
			'play_section',
			[
				'label' => __( 'Play Button', 'qhost-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'icon_color',
			[
				'label' => __( 'Color', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,		
				'selectors' => [
					'{{WRAPPER}} .play-button .popup-play-btn' => 'color: {{VALUE}}',
				],
			]
        );
        
        
		$this->add_control(
			'icon_bg',
			[
				'label' => __( 'Background', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,		
				'selectors' => [
					'{{WRAPPER}} .play-button .popup-play-btn' => 'background: {{VALUE}}',
				],
			]
        );
        
        $this->add_control(
			'hover_options',
			[
				'label' => __( 'Hover', 'plugin-name' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
        );
        
        
		$this->add_control(
			'icon_color_hover',
			[
				'label' => __( 'Color', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,		
				'selectors' => [
					'{{WRAPPER}} .play-button .popup-play-btn:hover' => 'color: {{VALUE}}',
				],
			]
        );
        
        
		$this->add_control(
			'icon_bg_hover',
			[
				'label' => __( 'Background', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,		
				'selectors' => [
					'{{WRAPPER}} .play-button .popup-play-btn:hover' => 'background: {{VALUE}}',
				],
			]
        );

		$this->end_controls_section();

    }

    protected function render( ) {
        $settings = $this->get_settings(); 
        $link_video = $settings['video_link'];
     
        ?>
        <div class="play-button">
            <a class="popup-play-btn popup-video" href="<?php echo esc_url( $link_video ) ?>"><i class="fas fa-play"></i></a> 
        </div>

       
        <?php          
        
    }

    protected function _content_template() {}    

}

