<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit;

class Qhost_Pricing_Table_Cloud extends Widget_Base {

    public function get_name() {
        return 'tt-pricing-cloud';
    }

    public function get_title() {
        return esc_html__( 'Qhost Pricing Table Cloud', 'qhost-core' );
    }
 
    public function get_icon() {
        return 'eicon-price-table';
    }

    public function get_categories() {
        return [ 'tt-elements' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'pricing_plan',
            [
                'label' => esc_html__('Pricing Plans', 'qhost-core'),
            ]
        );

        $this->add_control(
			'price_image',
			[
				'label' => __( 'Left Image', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

        

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
			'featured',
			[
				'label' => esc_html__('Do you want use gap before it?', 'qhost-core'),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'qhost-core' ),
				'label_off' => __( 'No', 'qhost-core' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

		$repeater->add_control(
			'price_title', [
				'label' => __( 'Title', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Basic Plan' , 'qhost-core' ),
				'label_block' => true,
			]
		);

        $repeater->add_control(
			'currency', [
				'label' => __( 'Currency', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
                'default' => '$',		
				'label_block' => true,
			]
		);


        $repeater->add_control(
			'price_month', [
				'label' => __( 'Price', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
                'default' => '2.4',		
				'label_block' => true,
			]
		);

        $repeater->add_control(
			'preiod', [
				'label' => __( 'Preiod', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
                'default' => '/month',	
				'label_block' => true,
			]
		);


		$repeater->add_control(
			'price_description', [
				'label' => __( 'Description', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'default' => __( 'Here you can download various examples' , 'qhost-core' ),
				
                'rows' => 3
			]
		);

		$repeater->add_control(
			'btn_title', [
				'label' => __( 'Button Title', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('Choose Plan', 'qhost-core'),	
				'label_block' => true,
			]
		);

        $repeater->add_control(
			'btn_link',
			[
				'label' => __( 'Link', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'qhost-core' ),
				'show_external' => true,
				'default' => [
					'url' => '#',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);
        

		$this->add_control(
			'pricings',
			[
				'label' => __( 'Pricing Plan', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'price_title' => __( 'Basic Plan', 'qhost-core' ),
						'price_month' => '2.5',					
						'price_description' => __( 'Here you can download various examples', 'qhost-core' ),
					],
					[
						'price_title' => __( 'Pro', 'qhost-core' ),
                        'price_month' => '3.99',
						'price_description' => __( 'Here you can download various examples', 'qhost-core' ),
					],	
                    [
						'price_title' => __( 'Enterprise', 'qhost-core' ),
                        'price_month' => '5.99',
						'price_description' => __( 'Here you can download various examples', 'qhost-core' ),
					],
				],
				'title_field' => '{{{ price_title }}}',
			]
		);



        /**
         * Pricing Feature
         */

         
		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'feature_title', [
				'label' => __( 'Fearure Title', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( '24/7/365 Support' , 'qhost-core' ),
				'label_block' => true,
			]
		);
        /**
         * Feature One
         */
        $repeater->add_control(
			'feature_options',
			[
				'label' => __( 'Feature One', 'plugin-name' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

        $repeater->start_controls_tabs( 'marker_repeater' );

		$repeater->start_controls_tab( 'general_tab', array( 'label' => __( 'Icon', 'qhost-core' ) ) );

        $repeater->add_control(
			'avilable',
			[
				'label' => __( 'Feature Avilable Yes/No', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'qhost-core' ),
				'label_off' => __( 'No', 'qhost-core' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);	


        $repeater->end_controls_tab();

		$repeater->start_controls_tab( 'content_tab', array( 'label' => __( 'Content', 'qhost-core' ) ) );

        $repeater->add_control(
			'feature_one', [
				'label' => __( 'Content', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,			
				
			]
		);

        $repeater->end_controls_tab();

		$repeater->end_controls_tabs();

        /**
         * Feature Two
         */

        $repeater->add_control(
			'feature_options_two',
			[
				'label' => __( 'Feature Two', 'plugin-name' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

        $repeater->start_controls_tabs( 'feature_two_tab' );

		$repeater->start_controls_tab( 'icon_tab', array( 'label' => __( 'Icon', 'qhost-core' ) ) );

        $repeater->add_control(
			'avilable_two',
			[
				'label' => __( 'Feature Avilable Yes/No', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'qhost-core' ),
				'label_off' => __( 'No', 'qhost-core' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);	


        $repeater->end_controls_tab();

		$repeater->start_controls_tab( 'content_tab_two', array( 'label' => __( 'Content', 'qhost-core' ) ) );

        $repeater->add_control(
			'feature_two', [
				'label' => __( 'Content', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,			
				
			]
		);

        $repeater->end_controls_tab();

		$repeater->end_controls_tabs();

        /**
         * Feature Three
         */

        $repeater->add_control(
			'feature_options_three',
			[
				'label' => __( 'Feature Three', 'plugin-name' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

        $repeater->start_controls_tabs( 'feature_three_tab' );

		$repeater->start_controls_tab( 'icon_tab_three', array( 'label' => __( 'Icon', 'qhost-core' ) ) );

        $repeater->add_control(
			'avilable_three',
			[
				'label' => __( 'Feature Avilable Yes/No', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'qhost-core' ),
				'label_off' => __( 'No', 'qhost-core' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);	


        $repeater->end_controls_tab();

		$repeater->start_controls_tab( 'content_tab_three', array( 'label' => __( 'Content', 'qhost-core' ) ) );

        $repeater->add_control(
			'feature_three', [
				'label' => __( 'Content', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,			
				
			]
		);

        $repeater->end_controls_tab();

		$repeater->end_controls_tabs();

		$this->add_control(
			'pricing_features',
			[
				'label' => __( 'Pricing Features', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'feature_title' => __( '24/7/365 Support', 'qhost-core' ),						
					],
					[
						'feature_title' => __( 'Instant Backups', 'qhost-core' ),						
					],
                    [
						'feature_title' => __( 'No Contract', 'qhost-core' ),						
					],  
                    [
						'feature_title' => __( '99.9% Uptime guarantee', 'qhost-core' ),						
					],
				],
				'title_field' => '{{{ feature_title }}}',
			]
		);


        $this->end_controls_section();


        $this->start_controls_section(
            'section_title_style',
            [
                'label' 	=> esc_html__( 'Styles', 'qhost-core' ),
                'tab' 		=> Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'table_title_color',
            [
                'label'		=> esc_html__( 'Table Title Color', 'qhost-core' ),
                'type'		=> Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pricing-matrix-item .title' => 'color: {{VALUE}} !important;',
                ],
            ]
        );

        $this->add_control(
            'table_sub_title_color',
            [
                'label'		=> esc_html__( 'Table Sub Title Color', 'qhost-core' ),
                'type'		=> Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pricing-matrix-item .pricing-body > p' => 'color: {{VALUE}} !important;',
                ],
            ]
        );

        $this->add_control(
            'tab_price_color',
            [
                'label'		=> esc_html__( 'Price Color', 'qhost-core' ),
                'type'		=> Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pricing-matrix-item .pricing-body .pricing-price h2' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'tab_price_content_color',
            [
                'label'		=> esc_html__( 'Table Content Color', 'qhost-core' ),
                'type'		=> Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pricing-matrix-item .pricing-feature' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'tab_price_btn_color',
            [
                'label'		=> esc_html__( 'Button Color', 'qhost-core' ),
                'type'		=> Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .btn-primary' => 'color: {{VALUE}};',
                ]
            ]
        );

        $this->add_control(
            'tab_btn_hover_color',
            [
                'label'		=> esc_html__( 'Button Hover Color', 'qhost-core' ),
                'type'		=> Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .btn-primary:hover' => 'color: {{VALUE}};'
                ],
            ]
        );

        $this->add_control(
            'tab_price_btn_bg',
            [
                'label'		=> esc_html__( 'Button BG Color', 'qhost-core' ),
                'type'		=> Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .btn-primary' => 'background-color: {{VALUE}};'
                ],
            ]
        );

        $this->add_control(
            'tab_btn_hover_bg',
            [
                'label'		=> esc_html__( 'Button Hover BG Color', 'qhost-core' ),
                'type'		=> Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .btn-primary:hover::before ' => 'background-color: {{VALUE}} !important;;'
                ],
            ]
        );
        $this->add_control(
            'tab_btn_arrow_bg',
            [
                'label'		=> esc_html__( 'Button Arrow BG Color', 'qhost-core' ),
                'type'		=> Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .content-collapse-wraper .expand-btn > i ' => 'background-color: {{VALUE}} !important;;'
                ],
            ]
        );

        $this->end_controls_section();
 
    }

    protected function render( ) {
        $settings = $this->get_settings();
        // $pricing_image = $settings['pricing_image'];
        $pricing_items = $settings['pricings'];
        $feature_items = $settings['pricing_features']; 
        

        require __DIR__.'/templates/pricing/style3.php';
        

    }


    protected function _content_template() { }
}