<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit;
/**
 * Text Typing Effect
 *
 * Elementor widget for text typing effect.
 *
 * @since 1.7.0
 */
class Qhost_Pricing_Table_Advance extends Widget_Base {

    public function get_name() {
        return 'tt-pricing-table-advance';
    }

    public function get_title() {
        return __( 'Pricing Table Advance', 'qhost-core' );
    }

    public function get_icon() {
        return 'eicon-price-table';
    }

    public function get_categories() {
        return [ 'tt-elements' ];
    }


    protected function _register_controls() {

        // ------------------------------ Feature list ------------------------------
        $this->start_controls_section(
            'pricing_tab', [
                'label' => __( 'General', 'qhost-core' ),
            ]
        );

        $this->add_control(
			'pricing_style',
			[
				'label' => __( 'Style', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'style_one',
				'options' => [
					'style_one'  => __( 'Style One', 'qhost-core' ),
					'style_two' => __( 'Style Two', 'qhost-core' ),
				],
			]
		);

        $this->add_control(
			'show_tab',
			[
				'label' => __( 'Show tab', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'qhost-core' ),
				'label_off' => __( 'Hide', 'qhost-core' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

        $this->add_control(
			'more_options',
			[
				'label' => __( 'Pricing Tab Text', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => ['show_tab' => 'yes']
            ]


        );

        $this->add_control(
			'monthly_title',
			[
				'label' => __( 'Title Month', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Monthly', 'qhost-core' ),
                'placeholder' => __( 'Type your title here', 'qhost-core' ),
                 'condition' => ['show_tab' => 'yes']
			]
        );

        $this->add_control(
			'anual_title',
			[
				'label' => __( 'Title Annual', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Annual', 'qhost-core' ),
                'placeholder' => __( 'Type your title here', 'qhost-core' ),
                'condition' => ['show_tab' => 'yes']
			]
		);

        $this->end_controls_section(); // End Pricing Switcher


        $this->start_controls_section(
            'pricing_table', [
                'label' => __( 'Pricing Table', 'qhost-core' ),
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
			'popular',
			[
				'label' => __( 'Featured on/off', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'qhost-core' ),
				'label_off' => __( 'Hide', 'qhost-core' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

        $repeater->add_control(
			'feature_text', [
				'label' => __( 'Feature Text', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Featured' , 'qhost-core' ),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'title', [
				'label' => __( 'Pricing Name', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Basic Account' , 'qhost-core' ),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'price_image_month',
			[
				'label' => __( 'Choose Image', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);


		$repeater->add_control(
			'sub_title', [
				'label' => __( 'Pricing Subheading', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Medium traffic personal sites' , 'qhost-core' ),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'monthly_price', [
				'label' => __( 'Monthly Price', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => "39",
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'cent', [
				'label' => __( 'Cent', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => ".60",
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'offer_month', [
				'label' => __( 'Monthly Offer', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __('10%', 'qhost-core'),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'annual_price', [
				'label' => __( 'Yearly Price', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => "79",
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'cent_year', [
				'label' => __( 'Cent', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => ".60",
				'label_block' => true,
			]
		);


		$repeater->add_control(
			'offer_yearly', [
				'label' => __( 'Yearly Offer', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __('14%', 'qhost-core'),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'list_items', [
				'label' => __( 'Price Feature', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,				
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'purchase_btn_label', [
				'label' => __( 'Purchase Button Monthly Label', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __('Get Started Now', 'qhost-core'),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'purchase_btn_url',
			[
				'label' => __( 'Purchase Button Monthly URL', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'qhost-core' ),
				'show_external' => true,
				'default' => [
					'url' => '#',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);

		$repeater->add_control(
			'purchase_btn_label_annual', [
				'label' => __( 'Purchase Button Annual Label', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __('Get Started Now', 'qhost-core'),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'purchase_btn_url_annual',
			[
				'label' => __( 'Purchase Button Annual URL', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'qhost-core' ),
				'show_external' => true,
				'default' => [
					'url' => '#',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);



		$this->add_control(
			'tables',
			[
				'label' => __( 'Price Table  List', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'title' => __( 'Basic', 'qhost-core' ),						
						'price_image_month' => [
							'url' => \Elementor\Utils::get_placeholder_image_src()
						],					
						'offer_yearly' => __('Save 10%', 'qhost-core'),
						'offer_month' => __('Save 12%', 'qhost-core'),
						'monthly_price' => '$8',
						'annual_price' => '$14',
						'cent'	=> '.60',
						'cent_year'	=> '.80',
						'list_items' => '<li><span>10</span> GB Storage</li>
                              <li><span>99.95%</span> Uptime</li>
                              <li><span>200</span> GB Bandwidth</li>							                               
                              <li><span>1</span> Free Domain included</li>',
						'purchase_btn_label' => __( 'Get Started Now', 'qhost-core' ),
						'purchase_btn_label_annual' => __( 'Get Started Now', 'qhost-core' ),
					],
					[
						'title' => __( 'Business', 'qhost-core' ),
						'price_image_month' => [
							'url' => \Elementor\Utils::get_placeholder_image_src()
						],
						'sub_title' => __( 'High traffic corporate sites', 'qhost-core' ),
						'offer_yearly' => __('Save 14%', 'qhost-core'),
						'offer_month' => __('Save 16%', 'qhost-core'),
						'monthly_price' => '$29',
						'annual_price' => '$49',
						'cent'	=> '.60',
						'cent_year'	=> '.80',
						'list_items' => '<li><span>20</span> GB Storage</li>
                              <li><span>99.95%</span> Uptime</li>
                              <li><span>300</span> GB Bandwidth</li>							                               
                              <li><span>1</span> Free Domain included</li>',
						'purchase_btn_label' => __( 'Get Started Now', 'qhost-core' ),
						'purchase_btn_label_annual' => __( 'Get Started Now', 'qhost-core' ),
					],
                    [
                 		'title' => __( 'Professional', 'qhost-core' ),
                 		'price_image_month' => [
							'url' => \Elementor\Utils::get_placeholder_image_src()
						],
	                    'sub_title' => __( 'Enterprise content management', 'qhost-core' ),
	                    'offer_yearly' => __('Save 20%', 'qhost-core'),
						'offer_month' => __('Save 25%', 'qhost-core'),
						'monthly_price' => '$39',
						'annual_price' => '$69',
						'cent'	=> '.60',
						'cent_year'	=> '.80',
						'list_items' => '<li><span>30</span> GB Storage</li>
                              <li><span>99.95%</span> Uptime</li>
                              <li><span>Unlimited</span> Bandwidth</li>							                               
                              <li><span>1</span> Free Domain included</li>',
						'purchase_btn_label' => __( 'Get Started Now', 'qhost-core' ),
						'purchase_btn_label_annual' => __( 'Get Started Now', 'qhost-core' ),
					],
				],
				'title_field' => '{{{ title }}}',
			]
		);


        $this->end_controls_section(); // End Pricing Table

        $this->start_controls_section(
			'tab_switcher_button',
			[
				'label' => __( 'Switcher Tab Style', 'qhost-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
            'switcher_bg_color', [
                'label' => __( 'BG Color', 'qhost-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .form-switch .switch-icon' => 'background: {{VALUE}};',
                ]

            ]
        );

        $this->add_control(
            'color_btn_text', [
                'label' => __( 'Color', 'qhost-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .form-switch span.afterinput, .form-switch .switch-icon.yearly .beforeinput' => 'color: {{VALUE}};',
                ],

            ]
        );

        $this->add_control(
            'switcher_active', [
                'label' => __( 'Text Active Color', 'qhost-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
					'{{WRAPPER}} .form-switch .switch-icon.yearly .afterinput, 
					{{WRAPPER}} .form-switch .switch-icon.monthly .beforeinput' => 'color: {{VALUE}};',
                ]

            ]
		); 

        $this->add_control(
            'switcher_background', [
                'label' => __( 'Tab Active BG Color', 'qhost-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .form-switch .switch-icon:after' => 'background-color: {{VALUE}};',
                ]

            ]
        );

        $this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'switcher_shadow',
				'selector' => '{{WRAPPER}} .pricing-tab .pricing-tab-switcher:before',
			]
        );

        $this->end_controls_section(); // End Buttons

        /**
         * Style Tab
         * ------------------------------ Style Title ------------------------------
         *
         */
        $this->start_controls_section(
            'style_title', [
                'label' => __( 'Price', 'qhost-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'color_prefix', [
                'label' => __( 'Color', 'qhost-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pricing-table .pricing-header .price' => 'color: {{VALUE}};',
                ],

            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name' => 'typography_prefix',
                'selector' => '{{WRAPPER}} .pricing-table .pricing-header .price',
            ]
        );
        $this->end_controls_section();


        //------------------------------ Style subtitle ------------------------------
        $this->start_controls_section(
            'style_subtitle', [
                'label' => __( 'Title', 'qhost-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'color_subtitle', [
                'label' => __( 'Color', 'qhost-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pricing-table .pricing-header .price-title' => 'color: {{VALUE}};',
                ],

            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name' => 'typography_subtitle',
                'selector' => '{{WRAPPER}} .pricing-table .pricing-header .price-title',
            ]
        );
        $this->end_controls_section();

        //------------------------------ Style subtitle ------------------------------
        $this->start_controls_section(
            'button_style', [
                'label' => __( 'Button', 'qhost-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->start_controls_tabs(
			'style_tabs'
		);

		$this->start_controls_tab(
			'style_normal_tab',
			[
				'label' => __( 'Normal', 'qhost-core' ),
			]
		);

        $this->add_control(
            'text-color', [
                'label' => __( 'Text Color', 'qhost-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tt-btn.btn-outline' => 'color: {{VALUE}};',
                ],
            ]
        );


        $this->add_control(
            'button_background', [
                'label' => __( 'Background', 'qhost-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tt-btn.btn-outline' => 'background: {{VALUE}};',
                ]
            ]
        );


		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'button_box_shadow',
				'label' => __( 'Box Shadow', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .tt-btn.btn-outline',

			]
		);

		 $this->add_control(
            'border-color', [
                'label' => __( 'Border Color', 'qhost-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tt-btn.btn-outline' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name' => 'button_typography',
                'selector' => '{{WRAPPER}} .tt-btn.btn-outline',
            ]
        );

        $this->end_controls_tab();

		$this->start_controls_tab(
			'style_hover_tab',
			[
				'label' => __( 'Hover', 'qhost-core' ),
			]
        );

        $this->add_control(
            'text-color_hover', [
                'label' => __( 'Text Color', 'qhost-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tt-btn.btn-outline:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'button_background_hover', [
                'label' => __( 'Background', 'qhost-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tt-btn.btn-outline:hover' => 'background: {{VALUE}};',
                ]
            ]
        );


		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'button_box_shadow_hover',
				'label' => __( 'Box Shadow', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .tt-btn.btn-outline:hover',
			]
		);

		 $this->add_control(
            'border-color_hover', [
                'label' => __( 'Border Color', 'qhost-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pricing-table .pix-btn:hover, 
                    {{WRAPPER}} .tt-btn.btn-outline:hover' => 'border-color: {{VALUE}};',
                ],
            ]
        );



        $this->end_controls_tab();

		$this->end_controls_tabs();


        $this->end_controls_section();


        //------------------------------ Style Section ------------------------------
        $this->start_controls_section(
            'style_section', [
                'label' => __( 'More Option', 'qhost-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'table_bg', [
                'label' => __( 'Pricing Table Background', 'qhost-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pricing-table'  => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'table_bg_hover', [
                'label' => __( 'Pricing Table Background Hover', 'qhost-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pricing-table:hover'  => 'background: {{VALUE}};',
                ],

            ]
        );

        $this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'table_box_shadow',
				'label' => __( 'Pricing Table Box Shadow', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .pricing-table',
			]
        );

        $this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'table_box_shadow_hover',
				'label' => __( 'Pricing Table Box Shadow Hover', 'qhost-core' ),
                'selector' => '{{WRAPPER}} .pricing-table:hover',

            ]

        );

        $this->end_controls_section();
    }

    protected function render() {

        $settings = $this->get_settings();
        $id_int = 'pric-' . substr($this->get_id_int(), 0, 3);

        $tables = isset($settings['tables']) ? $settings['tables'] : '';

        require __DIR__.'/templates/pricing/style1.php';

    }

    protected function _content_template() {
    }

}