<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

class Qhost_Range_Slider extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'tt-pricing-slider';
	}


	public function get_title() {
		return __( 'Qhost Pricing Slider', 'qhost-core' );
	}

	public function get_icon() {
		// Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
		return 'eicon-form-horizontal';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'vps_section',
			[
				'label' => __( 'VPS Slider', 'plugin-name' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'core', [
				'label' => __( 'CPU', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( '1' , 'qhost-core' ),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'memory', [
				'label' => __( 'Memory', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( '2' , 'qhost-core' ),
				
			]
		);

		$repeater->add_control(
			'storage', [
				'label' => __( 'Storage', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( '10' , 'qhost-core' ),
				
			]
		);

		$repeater->add_control(
			'bandwidth', [
				'label' => __( 'Bandwidth', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( '1000' , 'qhost-core' ),
				
			]
		);

		$repeater->add_control(
			'price', [
				'label' => __( 'Price', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( '1000' , 'qhost-core' ),
				
			]
		);

		$repeater->add_control(
			'buy_link',
			[
				'label' => __( 'Link', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'qhost-core' ),
				'show_external' => true,
				'default' => [
					'url' => '#',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);


		$this->add_control(
			'price_items',
			[
				'label' => __( 'Pricing List', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'core' => '1',
						'memory' => '2',
						'storage' => '10',
						'bandwidth' => '1000',
						'price' => '20',
						'buy_link' => '#',
					],
					[
						'core' => '2',
						'memory' => '4',
						'storage' => '20',
						'bandwidth' => '2000',
						'price' => '40',
						'buy_link' => '#',
					],
					[
						'core' => '3',
						'memory' => '6',
						'storage' => '30',
						'bandwidth' => '3000',
						'price' => '60',
						'buy_link' => '#',
					],
					[
						'core' => '4',
						'memory' => '8',
						'storage' => '40',
						'bandwidth' => '4000',
						'price' => '80',
						'buy_link' => '#',
					],
					[
						'core' => '5',
						'memory' => '10',
						'storage' => '50',
						'bandwidth' => '5000',
						'price' => '100',
						'buy_link' => '#',
					],
				],
				'title_field' => '{{{ core }}}',
			]
		);

		$this->end_controls_section();

		
		$this->start_controls_section(
			'text_section',
			[
				'label' => __( 'Static Text', 'qhost-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'price_footer_text', [
				'label' => __( 'Price Footer Text', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,				
				
			]
		);

		$this->end_controls_section();


	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		
		$pricing_items = $settings['price_items'];


        foreach( $pricing_items as $price_item ){
			$vpsSingleItem = [];

            $vpsSingleItem['vpsCore'] = $price_item['core'];
            $vpsSingleItem['vpsMemory'] = $price_item['memory'];
            $vpsSingleItem['vpsStorage'] = $price_item['storage'];
            $vpsSingleItem['vpsBandwidth'] = $price_item['bandwidth'];
            $vpsSingleItem['vpsPrice'] = $price_item['price'];
			$vpsSingleItem['vpsWHmcsUrl'] = $price_item['buy_link']['url'];       
			
			$vpsPriceInfo[] = $vpsSingleItem;
        }
		?>

	
		<div id="custom-plan">
			<div class="vps-switch-wrap">
				<div class="row justify-content-around gutter-10">
					<div class="col-md-8">
						<div class="tt-plan-box">
							<input id="c-plan" type="text" data-slider-min="1" data-slider-max="<?php echo count($vpsPriceInfo) ?>" data-slider-step="1" data-slider-value="2" data-currency="$" data-unit="GB">
						</div>
					</div>
					<div class="col-md-4 text-center">
						<a href="#" class="tt-btn vpsWHmcsUrl">Order Now</a>
					</div>
				</div>
			</div>
			<div class="row mt-4 gutter-10">
				<div class="col-md-12 col-lg-8">
					<div class="vps-pricing-wrap">
						<ul class="tt-vps-list text-center">
							<li>
								<div class="tt-vps-item text-center d-flex align-items-center">
									<div class="icon">
									<svg version="1.1" id="Capa_133gg" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 512 512" style="enable-background:new 0 0 512 512;" xml:space="preserve">
										<style type="text/css">
											.st0{fill:#5974FF;}
										</style>
										<g>
											<g>
												<path class="st0" d="M91.5,56.3h-0.1c-18.5,0.3-33.6,15.6-33.6,34.1v48.7H7.5c-4.2,0-7.5,3.4-7.5,7.5s3.4,7.5,7.5,7.5h50.3v39.6
													H7.5c-4.2,0-7.5,3.4-7.5,7.5s3.4,7.5,7.5,7.5h50.3v39.6H7.5c-4.2,0-7.5,3.4-7.5,7.5c0,4.2,3.4,7.5,7.5,7.5h50.3v39.6H7.5
													c-4.2,0-7.5,3.4-7.5,7.5s3.4,7.5,7.5,7.5h50.3v39.6H7.5c-4.2,0-7.5,3.4-7.5,7.5s3.4,7.5,7.5,7.5h50.3v25.8c0,4.2,3.4,7.5,7.5,7.5
													s7.5-3.4,7.5-7.5V90.4c0-10.3,8.4-18.9,18.7-19c4.2-0.1,7.5-3.5,7.4-7.6C99,59.6,95.6,56.3,91.5,56.3z"/>
											</g>
										</g>
										<g>
											<g>
												<path class="st0" d="M410.2,437.5H91.9c-7.8,0-14.7-4.6-17.6-11.8c-1.6-3.9-6-5.7-9.8-4.1c-3.9,1.6-5.7,6-4.1,9.8
													c5.3,12.9,17.7,21.2,31.6,21.2h47.2v51.8c0,4.2,3.4,7.5,7.5,7.5s7.5-3.4,7.5-7.5v-51.8h39.6v51.8c0,4.2,3.4,7.5,7.5,7.5
													s7.5-3.4,7.5-7.5v-51.8h39.6v51.8c0,4.2,3.4,7.5,7.5,7.5s7.5-3.4,7.5-7.5v-51.8h39.6v51.8c0,4.2,3.4,7.5,7.5,7.5s7.5-3.4,7.5-7.5
													v-51.8h39.6v51.8c0,4.2,3.4,7.5,7.5,7.5s7.5-3.4,7.5-7.5v-51.8h37.2c4.2,0,7.5-3.4,7.5-7.5C417.7,440.9,414.3,437.5,410.2,437.5z"
													/>
											</g>
										</g>
										<g>
											<g>
												<path class="st0" d="M358.2,128.1H153.8c-13.3,0-24.1,10.8-24.1,24.1v204.4c0,13.3,10.8,24.1,24.1,24.1h204.4
													c13.3,0,24.1-10.8,24.1-24.1V152.2C382.3,138.9,371.5,128.1,358.2,128.1z M144.8,152.2c0-5,4-9,9-9h155.9v78.7
													c-13.6,2.9-24.4,13.7-27.3,27.3h-55.5v-38.6c14.2-2.8,25-15.4,25-30.4c0-17.1-13.9-31-31-31c-15,0-27.6,10.8-30.4,25h-45.7
													L144.8,152.2L144.8,152.2z M317.2,236.2c11.4,0,20.6,9.2,20.6,20.6c0,11.4-9.2,20.6-20.6,20.6c-11.4,0-20.6-9.3-20.6-20.6
													C296.6,245.5,305.8,236.2,317.2,236.2z M220.8,196.1c-8.7,0-15.9-7.1-15.9-15.9c0-8.8,7.1-15.9,15.9-15.9s15.9,7.1,15.9,15.9
													C236.7,189.1,229.5,196.1,220.8,196.1z M188.3,319.3c-4.4-2.5-7.3-7.1-7.3-12.5c0-7.9,6.4-14.3,14.3-14.3s14.3,6.4,14.3,14.3
													C209.7,317.7,197.8,324.7,188.3,319.3z M249.2,365.7h-50.6V336c14.6-1.7,26-14.1,26-29.2c0-16.2-13.2-29.4-29.4-29.4
													c-16.2,0-29.4,13.2-29.4,29.4c0,12.1,7.3,22.5,17.7,27v31.9h-29.8c-5,0-9-4-9-9V189.3h46.5c0.1,0.1,4.1,15.5,20.5,20.5v47
													c0,4.2,3.4,7.5,7.5,7.5h30L249.2,365.7L249.2,365.7z M367.2,356.7c0,5-4,9-9,9h-93.9v-32.6h102.9V356.7z M367.2,318H264.3v-53.7
													h18c3.5,16.1,17.8,28.1,34.9,28.1c19.7,0,35.7-16,35.7-35.7c0-17.1-12.1-31.4-28.1-34.9c0,0,0,0,0,0v-78.7h33.5c5,0,9,4,9,9
													L367.2,318L367.2,318z"/>
											</g>
										</g>
										<g>
											<g>
												<path class="st0" d="M504.5,208.8c4.2,0,7.5-3.4,7.5-7.5s-3.4-7.5-7.5-7.5h-50.3v-39.6h50.3c4.2,0,7.5-3.4,7.5-7.5
													s-3.4-7.5-7.5-7.5h-50.3V90.4c0-18.8-15.3-34.1-34.1-34.1h-47.2V7.5c0-4.2-3.4-7.5-7.5-7.5s-7.5,3.4-7.5,7.5v48.7h-39.6V7.5
													c0-4.2-3.4-7.5-7.5-7.5s-7.5,3.4-7.5,7.5v48.7h-39.6V7.5c0-4.2-3.4-7.5-7.5-7.5s-7.5,3.4-7.5,7.5v48.7h-39.6V7.5
													c0-4.2-3.4-7.5-7.5-7.5s-7.5,3.4-7.5,7.5v48.7h-39.6V7.5c0-4.2-3.4-7.5-7.5-7.5s-7.5,3.4-7.5,7.5v48.7h-17.4
													c-4.2,0-7.5,3.4-7.5,7.5s3.4,7.5,7.5,7.5c39.5,0,266.8,0,298.4,0c10.5,0,19,8.5,19,19v328.2c0,5.3-2.1,10.1-5.9,13.8
													c-3,2.9-3.1,7.6-0.3,10.7c1.5,1.6,3.5,2.3,5.5,2.3c1.9,0,3.7-0.7,5.2-2.1c6.8-6.5,10.6-15.3,10.6-24.7v-45.6h50.3
													c4.2,0,7.5-3.4,7.5-7.5s-3.4-7.5-7.5-7.5h-50.3v-39.6h50.3c4.2,0,7.5-3.4,7.5-7.5s-3.4-7.5-7.5-7.5h-50.3v-39.6h50.3
													c4.2,0,7.5-3.4,7.5-7.5s-3.4-7.5-7.5-7.5h-50.3v-39.6L504.5,208.8L504.5,208.8z"/>
											</g>
										</g>
										</svg>

									</div>
									<div class="vps-item-info">
										<h6 class="title">CPU</h6>
										<h3 class="feature vpsCore"><span>1</span> Core's</h3>
									</div>
								</div>
							</li>
							<li>
								<div class="tt-vps-item text-center d-flex align-items-center">
									<div class="icon">
										<svg version="1.1" id="Capa_133" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 512 512" style="enable-background:new 0 0 512 512;" xml:space="preserve">
										<style type="text/css">
											.st0{fill:#5974FF;}
										</style>
										<g>
											<g>
												<path class="st0" d="M425.8,242.5h11.6c11.9,0,21.5-9.7,21.5-21.5v-41.2c0-8-4.4-15.3-11.5-19l-40.6-21.4
													c-2.1-1.1-3.5-3.3-3.5-5.8V99.9c0-4.1-3.4-7.5-7.5-7.5s-7.5,3.4-7.5,7.5v33.6c0,8,4.4,15.3,11.5,19l40.6,21.4
													c2.1,1.1,3.5,3.3,3.5,5.8V221c0,3.6-2.9,6.5-6.5,6.5h-11.6c-10.5,0-19,8.5-19,19v41.2c0,7.2,4.2,13.9,10.7,17.1l22.8,11.1
													c2.2,1.1,3.7,3.4,3.7,5.9v145.4c0,16.5-13.4,29.9-29.9,29.9H97.9C81.4,497,68,483.6,68,467.1V44.9C68,28.4,81.4,15,97.9,15h260.7
													c16.5,0,29.9,13.4,29.9,29.9v20c0,4.1,3.4,7.5,7.5,7.5s7.5-3.4,7.5-7.5v-20c0-24.7-20.1-44.9-44.9-44.9H97.9
													C73.1,0,53,20.1,53,44.9v422.3c0,24.7,20.1,44.9,44.9,44.9h316.2c24.7,0,44.9-20.1,44.9-44.9V321.8c0-8.2-4.8-15.8-12.1-19.4
													l-22.8-11.1c-1.4-0.7-2.3-2.1-2.3-3.6v-41.3C421.8,244.3,423.6,242.5,425.8,242.5L425.8,242.5z"/>
												<path class="st0" d="M130.3,469.7h251.4c12.4,0,22.5-10.1,22.5-22.5V336c0-12.4-10.1-22.5-22.5-22.5H130.3
													c-12.4,0-22.5,10.1-22.5,22.5v38.1c0,4.1,3.4,7.5,7.5,7.5s7.5-3.4,7.5-7.5V336c0-4.1,3.3-7.5,7.5-7.5h251.4c4.1,0,7.5,3.3,7.5,7.5
													v111.3c0,4.1-3.3,7.5-7.5,7.5H130.3c-4.1,0-7.5-3.3-7.5-7.5v-38.1c0-4.1-3.4-7.5-7.5-7.5s-7.5,3.4-7.5,7.5v38.1
													C107.8,459.6,117.9,469.7,130.3,469.7L130.3,469.7z"/>
												<path class="st0" d="M140.1,126.3c6.9,0,12.5-5.6,12.5-12.5V50.9c0-6.9-5.6-12.5-12.5-12.5h-29.5c-6.9,0-12.5,5.6-12.5,12.5v62.9
													c0,6.9,5.6,12.5,12.5,12.5H140.1z M113.1,53.5h24.5v57.9h-24.5L113.1,53.5z"/>
												<path class="st0" d="M210.8,126.3c6.9,0,12.5-5.6,12.5-12.5V50.9c0-6.9-5.6-12.5-12.5-12.5h-29.5c-6.9,0-12.5,5.6-12.5,12.5v62.9
													c0,6.9,5.6,12.5,12.5,12.5H210.8z M183.8,53.5h24.5v57.9h-24.5V53.5z"/>
												<path class="st0" d="M281.4,126.3c6.9,0,12.5-5.6,12.5-12.5V50.9c0-6.9-5.6-12.5-12.5-12.5h-29.5c-6.9,0-12.5,5.6-12.5,12.5v62.9
													c0,6.9,5.6,12.5,12.5,12.5H281.4z M254.4,53.5h24.5v57.9h-24.5L254.4,53.5z"/>
												<path class="st0" d="M352,126.3c6.9,0,12.5-5.6,12.5-12.5V50.9c0-6.9-5.6-12.5-12.5-12.5h-29.5c-6.9,0-12.5,5.6-12.5,12.5v62.9
													c0,6.9,5.6,12.5,12.5,12.5H352z M325,53.5h24.5v57.9H325V53.5z"/>
											</g>
										</g>
										</svg>

									</div>
									<div class="vps-item-info">
										<h6 class="title">Memory</h6>
										<h3 class="feature vpsMemory"><span>2</span> GB</h3>
									</div>
								</div>
							</li>
							<li>
								<div class="tt-vps-item text-center d-flex align-items-center">
									<div class="icon">
										<svg version="1.1" id="Layer_1sdfsd" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 512 512" style="enable-background:new 0 0 512 512;" xml:space="preserve">
											<style type="text/css">
												.st0{fill:#5974FF;}
											</style>
											<path class="st0" d="M256,237.8c-10.1,0-18.3,8.2-18.3,18.3s8.2,18.3,18.3,18.3s18.3-8.2,18.3-18.3
												C274.2,245.9,266.1,237.8,256,237.8z M256,262.3c-3.5,0-6.3-2.8-6.3-6.3s2.8-6.3,6.3-6.3s6.3,2.8,6.3,6.3
												C262.2,259.5,259.5,262.2,256,262.3z"/>
											<path class="st0" d="M390.8,5H121.3c-30.4,0-55,24.6-55,55v392c0,30.4,24.6,55,55,55h269.5c30.4,0,55-24.6,55-55V60
												C445.7,29.6,421.1,5,390.8,5z M433.8,452c0,23.7-19.3,43-43,43H121.3c-23.7,0-43-19.3-43-43V60c0-23.7,19.3-43,43-43h269.5
												c23.7,0,43,19.3,43,43V452z"/>
											<path class="st0" d="M122.7,81.1c10.1,0,18.2-8.2,18.2-18.3s-8.2-18.3-18.2-18.3s-18.3,8.2-18.3,18.3l0,0
												C104.4,72.9,112.6,81.1,122.7,81.1z M122.7,56.6c3.5,0,6.2,2.8,6.2,6.3c0,3.5-2.8,6.3-6.2,6.3s-6.3-2.8-6.3-6.3l0,0
												C116.4,59.4,119.2,56.6,122.7,56.6z"/>
											<path class="st0" d="M389.3,44.6c-10.1,0-18.3,8.2-18.3,18.3s8.2,18.3,18.3,18.3s18.3-8.2,18.3-18.3l0,0
												C407.6,52.8,399.4,44.6,389.3,44.6z M389.3,69.1c-3.5,0-6.3-2.8-6.3-6.3c0-3.5,2.8-6.3,6.3-6.3s6.3,2.8,6.3,6.3l0,0
												C395.6,66.3,392.8,69.1,389.3,69.1z"/>
											<path class="st0" d="M122.7,435.8c-10.1,0-18.3,8.2-18.3,18.3s8.2,18.3,18.2,18.3s18.3-8.2,18.3-18.3l0,0
												C140.9,444,132.8,435.8,122.7,435.8z M122.7,460.3c-3.5,0-6.3-2.8-6.3-6.3s2.8-6.3,6.2-6.3s6.3,2.8,6.3,6.3l0,0
												C128.9,457.5,126.1,460.3,122.7,460.3z"/>
											<path class="st0" d="M380.3,362.1l-28.1-20.9c21.5-24.1,33-55.5,32.3-87.8c-1.3-69.6-58.7-125.8-128.3-126
												c-35.1-0.1-68.7,14.3-93,39.7c-2.4,2.3-2.4,6.1,0,8.5c2.3,2.4,6.1,2.4,8.5,0c0.1-0.1,0.2-0.2,0.2-0.2c21.9-23,52.3-35.9,84.1-35.9
												c64.2,0,116.6,52.5,116.5,116.7c0,28.8-10.7,56.5-30,77.9l-20-14.8c34.7-36.7,33.2-94.5-3.5-129.3s-94.5-33.2-129.3,3.5
												s-33.2,94.5,3.5,129.3c24.6,23.3,60,31.1,92,20.3l7.6,23.6c-11.3,3.8-23.1,5.8-35,5.9c-63.6,1-116.6-49.8-118.3-113.3
												c-0.5-18,3.2-35.9,10.8-52.2c1.3-2.7,0.4-5.9-2.1-7.6c-2.8-1.8-6.5-1.1-8.3,1.7c-0.2,0.2-0.3,0.5-0.4,0.8
												c-8.7,18.7-12.8,39.2-11.9,59.7c2.9,69.2,61,124,130.3,123c13.1-0.2,26.1-2.4,38.6-6.5l11.6,35.9c7.9,24.5,34.2,38,58.7,30.1
												s38-34.2,30.1-58.7C393.9,375.9,388.1,367.9,380.3,362.1L380.3,362.1z M269.2,293.2l12.4,38.4c-41.7,14.2-87.1-8.2-101.2-49.9
												c-14.2-41.7,8.2-87.1,49.9-101.2c41.7-14.2,87.1,8.2,101.2,49.9c9.7,28.6,2.4,60.2-18.7,81.7l-34.3-25.5c-2.7-2-6.4-1.4-8.4,1.2
												C268.9,289.3,268.6,291.3,269.2,293.2L269.2,293.2z M386.6,405.1c-3.1,18.9-20.9,31.6-39.8,28.5c-12.8-2.1-23.4-11.2-27.3-23.5
												l-33.2-102.8l86.8,64.4C383.6,379.4,388.8,392.3,386.6,405.1z"/>
											<path class="st0" d="M345,389.1c-6.4,4.6-7.8,13.4-3.3,19.8c4.6,6.4,13.4,7.8,19.8,3.3c6.4-4.6,7.8-13.4,3.3-19.8c0,0,0,0,0,0
												C360.2,386,351.4,384.6,345,389.1z M354.6,402.4c-1,0.7-2.3,0.5-3-0.5c-0.7-1-0.5-2.3,0.5-3c1-0.7,2.3-0.5,3,0.5
												C355.8,400.3,355.5,401.7,354.6,402.4z"/>
											<path class="st0" d="M105.1,141.6c3.3,0,6-2.7,6-6v-12.3c0-3.3-2.7-6-6-6s-6,2.7-6,6v12.3C99.1,138.9,101.8,141.6,105.1,141.6z"/>
											<path class="st0" d="M111.1,237.1v-80.9c0-3.3-2.7-6-6-6s-6,2.7-6,6v80.9c0,3.3,2.7,6,6,6S111.1,240.4,111.1,237.1z"/>
										</svg>

									</div>
									<div class="vps-item-info">
										<h6 class="title">Storage</h6>
										<h3 class="feature vpsStorage"><span>10</span> GB</h3>
									</div>
								</div>
							</li>
							<li>
								<div class="tt-vps-item text-center d-flex align-items-center">
								<div class="icon">
								
										<svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 512 512" style="enable-background:new 0 0 512 512;" xml:space="preserve">
										<style type="text/css">
											.st0{fill:#5974FF;}
										</style>
										<g>
											<g>
												<path class="st0" d="M437,90.9c-48.4-48.4-112.6-75-181-75s-132.7,26.6-181,75S0,203.5,0,271.9c0,73.3,31.5,143.2,86.5,191.8
													c3.1,2.8,8,2.5,10.7-0.7s2.5-8-0.7-10.7c-51.7-45.7-81.4-111.5-81.4-180.4c0-64.3,25-124.8,70.5-170.3S191.7,31.1,256,31.1
													s124.8,25,170.3,70.5s70.5,105.9,70.5,170.3c0,69-29.7,134.7-81.4,180.4c-3.1,2.8-3.4,7.6-0.7,10.7c1.5,1.7,3.6,2.6,5.7,2.6
													c1.8,0,3.6-0.6,5-1.9c55-48.6,86.5-118.5,86.5-191.8C512,203.5,485.4,139.2,437,90.9z"/>
											</g>
										</g>
										<g>
											<g>
												<path class="st0" d="M357.7,426.9H187.2c-4.2,0-7.6,3.4-7.6,7.6s3.4,7.6,7.6,7.6h170.5c6,0,10.9,4.9,10.9,10.9v17
													c0,6-4.9,10.9-10.9,10.9H154.3c-6,0-10.9-4.9-10.9-10.9v-17c0-6,4.9-10.9,10.9-10.9h7.5c4.2,0,7.6-3.4,7.6-7.6s-3.4-7.6-7.6-7.6
													h-7.5c-14.4,0-26.1,11.7-26.1,26.1v17c0,14.4,11.7,26.1,26.1,26.1h203.3c14.4,0,26.1-11.7,26.1-26.1v-17
													C383.7,438.6,372,426.9,357.7,426.9z"/>
											</g>
										</g>
										<g>
											<g>
												<path class="st0" d="M385,99.5c-37.5-28.1-82.1-42.9-129-42.9c-86.6,0-164.5,51.5-198.3,131.3c-1.5,3.6-0.1,7.8,3.4,9.7
													c1.1,0.6,2.4,0.9,3.6,0.9c2.5,0,4.9-1.2,6.3-3.4c32.8-49.2,87.7-78.5,146.7-78.5c43,0,84.4,15.6,116.6,44c3.1,2.8,8,2.5,10.7-0.7
													c2.8-3.1,2.5-8-0.7-10.7c-35-30.9-79.9-47.9-126.6-47.9c-38.5,0-75.4,11.5-106.5,32.3c37.1-38.8,89-61.8,144.8-61.8
													c43.6,0,85.1,13.8,119.9,39.9c3.4,2.5,8.1,1.8,10.6-1.5C389,106.8,388.4,102,385,99.5z"/>
											</g>
										</g>
										<g>
											<g>
												<path class="st0" d="M424.5,137.8c-2.6-3.3-7.4-3.8-10.7-1.2c-3.3,2.6-3.8,7.4-1.2,10.7c26.9,33.7,41.8,74.1,43.4,117h-48.9
													c-3.2-21.5-10-42.1-20.2-61.3c-2-3.7-6.6-5.1-10.3-3.1c-3.7,2-5.1,6.6-3.1,10.3c10.4,19.5,16.9,40.6,19.4,62.6
													c0.4,3.8,3.7,6.7,7.6,6.7h63.3c4.2,0,7.6-3.4,7.6-7.6C471.3,222.6,455.1,176.3,424.5,137.8z"/>
											</g>
										</g>
										<g>
											<g>
												<path class="st0" d="M411.9,103.5c-3.3-2.2-7.7-1.5-10.1,1.6l-132,166.7c-2.6,3.3-2.1,8.1,1.2,10.7s8.1,2,10.7-1.2l78.7-99.4
													l-89,165.7c-0.7,1.1-1.8,2.9-2.4,3.6c-2.8,3.5-6.8,5.7-11.2,6.2c-4.4,0.5-8.8-0.8-12.3-3.5c-3.5-2.8-5.7-6.8-6.2-11.2
													c-0.5-4.4,0.8-8.8,3.5-12.3l23.8-30c2.6-3.3,2-8.1-1.2-10.7c-3.3-2.6-8.1-2-10.7,1.2l-23.8,30c-5.3,6.7-7.7,15-6.7,23.5
													c1,8.5,5.2,16.1,11.8,21.4c5.7,4.5,12.6,7,19.8,7c1.2,0,2.4-0.1,3.7-0.2c8.5-1,16.1-5.2,21.4-11.8c1.4-1.8,3.2-4.8,3.6-5.4
													c0.1-0.1,0.1-0.2,0.2-0.3l129.6-241.4C416.3,109.9,415.2,105.6,411.9,103.5z"/>
											</g>
										</g>
										<g>
											<g>
												<path class="st0" d="M263.3,334.9c-3.7-5.7-12.9-3.6-13.8,3.1c-0.5,3.2,1.2,6.5,4.1,7.9c2.8,1.4,6.3,0.9,8.6-1.2
													C264.9,342.2,265.4,337.9,263.3,334.9z"/>
											</g>
										</g>
										</svg>

									</div>
									<div class="vps-item-info">
										<h6 class="title">Bandwidth</h6>
										<h3 class="feature vpsBandwidth"><span>1000</span> TB</h3>
									</div>
								</div>
							</li>
						</ul>
					</div>
				</div>
				<div class="col-sm-12 col-lg-4">
					<div class="tt-plan-info-box text-center">
						<h3 class="price-title">Price</h3>
						<div class="price">
							<span class="vpsPrice">$20</span>
							<span class="period ss">/month</span>
						</div>

						<p>* 1 Month free if you pay for 1 Year</p>
					</div>
				</div>
			</div>

			<div class="price-footer-text text-center">
				<p>
					<?php echo $settings['price_footer_text'] ?>
				</p>
			</div>
		</div>

		<?php

		 // Register the script
		 wp_register_script( 'qhost-vps-slider', QHOST_SCRIPTS . '/vps-slider.js' );

		 wp_localize_script( 'qhost-vps-slider', 'vpsPriceInfo', $vpsPriceInfo );

		
 
		 // Enqueued script with localized data.
		 wp_enqueue_script( 'qhost-vps-slider' );
	}

}
