<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Qhost_Pricing_Table extends Widget_Base {

	public function get_name() {
		return 'tt-pricing-table';
	}

	public function get_title() {
		return __( 'Qhost Pricing Table', 'qhost-core' );
	}

	public function get_icon() {
		return 'eicon-price-table';
	}

	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'pricing',
			[
				'label' => __( 'Pricing', 'qhost-core' ),
			]
		);

		$this->add_control(
			'layout', [
				'type'    => Controls_Manager::SELECT,
				'label'   => __( 'Layout', 'qhost-core' ),
				'default' => 'style-one',
				'options' => [
					'style-one' => __( 'Style One', 'qhost-core' ),
					'style-two' => __( 'Style Two', 'qhost-core' ),
				],
			]
		);

		$this->add_control(
			'columns', [
				'type'    => Controls_Manager::SELECT,
				'label'   => __( 'Number of columns', 'qhost-core' ),
				'default' => '3',
				'options' => [
					'2' => __( '2', 'qhost-core' ),
					'3' => __( '3', 'qhost-core' ),
					'4' => __( '4', 'qhost-core' ),
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'pricing_title_sec',
			[
				'label' => __( 'Pricing Title', 'qhost-core' ),
			]
		);


		$this->add_control(
			'price_title',
			[
				'label'       => __( 'Title', 'qhost-core' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => __( 'Default title', 'qhost-core' ),
				'placeholder' => __( 'Type your title here', 'qhost-core' ),
				'label_block' => true
			]
		);

		$this->add_control(
			'price_des',
			[
				'label'       => __( 'Description', 'qhost-core' ),
				'type'        => \Elementor\Controls_Manager::TEXTAREA,
				'default'     => __( 'Default title', 'qhost-core' ),
				'placeholder' => __( 'Type your title here', 'qhost-core' ),
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'pricing_plane',
			[
				'label' => __( 'Pricing Plans', 'qhost-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);


		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'featured_table',
			[
				'label'        => __( 'Do you want to feature it?', 'qhost-core' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => __( 'Yes', 'your-plugin' ),
				'label_off'    => __( 'No', 'your-plugin' ),
				'return_value' => 'yes',
				'default'      => 'no',
			]
		);


		$repeater->add_control(
			'feature_text',
			[
				'label'     => __( 'Feature Text', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'featured_table' => 'yes'
				]

			]
		);

		$repeater->add_control(
			'title_icon',
			[
				'label'   => __( 'Choose Image', 'qhost-core' ),
				'type'    => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);


		$repeater->add_control(
			'table_title',
			[
				'label'       => __( 'Table Title', 'qhost-core' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => __( 'For personal use', 'qhost-core' ),
				'label_block' => true,
			]
		);


		$repeater->add_control(
			'table_content',
			[
				'label'       => __( 'Table Content', 'qhost-core' ),
				'type'        => \Elementor\Controls_Manager::TEXTAREA,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'pricing_feature', [
				'label'       => __( 'Price Feature', 'qhost-core' ),
				'type'        => \Elementor\Controls_Manager::TEXTAREA,
				'default'     => 'Limited Acess Library
                              Single User
                              Hotline Support 24/7
                              No Updates',
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'table_start',
			[
				'label'       => __( 'Package Start title', 'qhost-core' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'table_price',
			[
				'label'       => __( 'Price', 'qhost-core' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => __( '$8.99', 'qhost-core' ),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'table_period',
			[
				'label'       => __( 'Period', 'qhost-core' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => __( '/mo', 'qhost-core' ),
				'label_block' => true,
			]
		);


		$repeater->add_control(
			'button_text',
			[
				'label'       => __( 'Button Text', 'qhost-core' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => __( 'Buy Package', 'qhost-core' ),
				'label_block' => true,
			]
		);


		$repeater->add_control(
			'btn_url',
			[
				'label'         => __( 'Button URL', 'qhost-core' ),
				'type'          => \Elementor\Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'qhost-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '#',
					'is_external' => true,
					'nofollow'    => true,
				],
			]
		);


		$repeater->add_control(
			'list_color',
			[
				'label'     => __( 'Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}}' => 'color: {{VALUE}}'
				],
			]
		);

		$this->add_control(
			'pricing_table',
			[
				'label'       => __( 'Table List', 'qhost-core' ),
				'type'        => \Elementor\Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'table_title'     => __( 'Web Hosting', 'qhost-core' ),
						'table_content'   => __( 'For small business', 'qhost-core' ),
						'table_start'     => __( 'Starting at', 'qhost-core' ),
						'table_price'     => __( '$8.99', 'qhost-core' ),
						'table_period'    => __( '/mo', 'qhost-core' ),
						'pricing_feature' => 'Limited Acess Library
                              Single User
                              Hotline Support 24/7
                              No Updates',
						'button_text'     => __( 'Get Started Now', 'qhost-core' ),
						'btn_url'         => '#',
					],
					[
						'table_title'     => __( 'VPS Hosting', 'qhost-core' ),
						'table_content'   => __( 'For medium business.', 'qhost-core' ),
						'table_start'     => __( 'Starting at', 'qhost-core' ),
						'table_price'     => __( '$8.99', 'qhost-core' ),
						'table_period'    => __( '/mo', 'qhost-core' ),
						'pricing_feature' => 'Limited Acess Library
                              Single User
                              Hotline Support 24/7
                              No Updates',
						'button_text'     => __( 'Get Started Now', 'qhost-core' ),
						'btn_url'         => '#',
					],
					[
						'table_title'     => __( 'Cloud Hosting', 'qhost-core' ),
						'table_content'   => __( 'Large and enterprise business.', 'qhost-core' ),
						'table_start'     => __( 'Starting at', 'qhost-core' ),
						'table_price'     => __( '$8.99', 'qhost-core' ),
						'table_period'    => __( '/mo', 'qhost-core' ),
						'pricing_feature' => 'Limited Acess Library
                              Single User
                              Hotline Support 24/7
                              No Updates',
						'button_text'     => __( 'Get Started Now', 'qhost-core' ),
						'btn_url'         => '#',
					],
				],
				'title_field' => '{{{ table_title }}}',
			]
		);


		$this->end_controls_section();


		/**
		 * Heading Style
		 */
		$this->start_controls_section(
			'heading_section',
			[
				'label'     => __( 'Content', 'plugin-name' ),
				'tab'       => \Elementor\Controls_Manager::TAB_STYLE,
				'condition' => [
					'layout' => '3'
				]
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'title_typography',
				'label'    => __( 'Title Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .single_pricing_tittle h2',
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'     => __( 'Title Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .single_pricing_tittle h2' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'des_options',
			[
				'label'     => __( 'Description', 'plugin-name' ),
				'type'      => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name'     => 'des_typography',
				'label'    => __( 'Description Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .single_pricing_tittle p',
			]
		);

		$this->add_control(
			'des_color',
			[
				'label'     => __( 'Description Color', 'qhost-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .single_pricing_tittle p' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();

		/**
		 * Pricing Style
		 */
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => __( 'Pricing', 'qhost-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'tab_price_color',
			[
				'label'     => __( 'Price Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .single_pricing_plan h2' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'table_title_color',
			[
				'label'     => __( 'Table Title Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .single_pricing_plan h5' => 'color: {{VALUE}} !important;',
				],
			]
		);

		$this->add_control(
			'tab_price_fea_color',
			[
				'label'     => __( 'Table Feature Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .single_pricing_plan p' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'tab_price_btn_color',
			[
				'label'     => __( 'Button Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .single_pricing_plan .cu_btn.btn_2' => 'color: {{VALUE}};',
				]
			]
		);

		$this->add_control(
			'tab_btn_hover_color',
			[
				'label'     => __( 'Button Hover Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .single_pricing_plan .cu_btn.btn_2:hover' => 'color: {{VALUE}};'
				],
			]
		);

		$this->add_control(
			'tab_price_btn_bg',
			[
				'label'     => __( 'Button BG Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .single_pricing_plan .cu_btn.btn_2' => 'background-color: {{VALUE}};'
				],
			]
		);

		$this->add_control(
			'tab_btn_hover_bg',
			[
				'label'     => __( 'Button Hover BG Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .single_pricing_plan .cu_btn.btn_2:hover ' => 'background-color: {{VALUE}} !important;;'
				],
			]
		);
		$this->add_control(
			'tab_btn_hover_border_color',
			[
				'label'     => __( 'Button Hover Boreder Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .single_pricing_plan .cu_btn.btn_2:hover ' => 'border-color: {{VALUE}} !important;;'
				],
			]
		);
		$this->add_control(
			'btn_border_color_title',
			[
				'label'     => __( 'Border', 'qhost-core' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'btn_border_color',
				'label'    => __( 'Button Border', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .single_pricing_plan .cu_btn.btn_2',
			]
		);
		$this->add_control(
			'btn_border_color_title_hover',
			[
				'label'     => __( 'Hover Border', 'qhost-core' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'btn_border_color_hover',
				'label'    => __( 'Button Hover Border', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .single_pricing_plan .cu_btn.btn_2',
			]
		);

		$this->add_control(
			'tab_price_body_bg',
			[
				'label'     => __( 'Table Background Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .single_pricing_plan' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'table_box_shadow',
				'label'    => __( 'Box Shadow Hover', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .single_pricing_plan:hover',
			]
		);

		$this->end_controls_section();


		/**
		 * Feature Pricing Table Style
		 */
		$this->start_controls_section(
			'section_fea_style',
			[
				'label' => __( 'Feature Pricing', 'qhost-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'tab_price_color_fea',
			[
				'label'     => __( 'Price Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .single_pricing_plan.active h2' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'table_title_color_fea',
			[
				'label'     => __( 'Table Title Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .single_pricing_plan.active h5' => 'color: {{VALUE}} !important;',
				],
			]
		);

		$this->add_control(
			'tab_price_fea_color_fea',
			[
				'label'     => __( 'Table Feature Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .single_pricing_plan.active p' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'tab_price_btn_color_fea',
			[
				'label'     => __( 'Button Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .single_pricing_plan.active .cu_btn.btn_2' => 'color: {{VALUE}};',
				]
			]
		);

		$this->add_control(
			'tab_btn_hover_color_fea',
			[
				'label'     => __( 'Button Hover Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .single_pricing_plan.active .cu_btn.btn_2:hover' => 'color: {{VALUE}};'
				],
			]
		);

		$this->add_control(
			'tab_price_btn_bg_fea',
			[
				'label'     => __( 'Button BG Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .single_pricing_plan.active .cu_btn.btn_2' => 'background-color: {{VALUE}};'
				],
			]
		);

		$this->add_control(
			'tab_btn_hover_bg_fea',
			[
				'label'     => __( 'Button Hover BG Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .single_pricing_plan.active .cu_btn.btn_2:hover ' => 'background-color: {{VALUE}} !important;;'
				],
			]
		);
		$this->add_control(
			'tab_btn_hover_border_color_fea',
			[
				'label'     => __( 'Button Hover Boreder Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .single_pricing_plan.active .cu_btn.btn_2:hover ' => 'border-color: {{VALUE}} !important;;'
				],
			]
		);
		$this->add_control(
			'btn_border_color_title_fea',
			[
				'label'     => __( 'Border', 'qhost-core' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'btn_border_color_fea',
				'label'    => __( 'Button Border', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .single_pricing_plan.active .cu_btn.btn_2',
			]
		);
		$this->add_control(
			'btn_border_color_title_hover_fea',
			[
				'label'     => __( 'Hover Border', 'qhost-core' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'btn_border_color_hover_fea',
				'label'    => __( 'Button Hover Border', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .single_pricing_plan.active .cu_btn.btn_2',
			]
		);

		$this->add_control(
			'tab_price_body_bg_fea',
			[
				'label'     => __( 'Table Background Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .single_pricing_plan.active' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'table_box_shadow_fea',
				'label'    => __( 'Box Shadow Hover', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .single_pricing_plan.active:hover',
			]
		);

		$this->end_controls_section();


	}

	protected function render() {
		$settings = $this->get_settings();
		$columns  = $settings['columns'];
		$tables   = $settings['pricing_table'];
		$style    = $settings['layout'];


		if ( $columns == '4' ) {
			$grid = 'grid col-lg-3';
		} elseif ( $columns == '3' ) {
			$grid = 'grid col-lg-4';
		} else {
			$grid = 'grid col-lg-6';
		}


		require __DIR__ . '/templates/pricing/style2.php';


	}


	protected function _content_template() {
	}
}