<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Qhost_Service_Box extends Widget_Base {

	public function get_name() {
		return 'tt-service-box';
	}

	public function get_title() {
		return esc_html__( 'Qhost Service Box', 'qhost-core' );
	}

	public function get_icon() {
		return 'eicon-icon-box';
	}

	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_tab', [
				'label' => esc_html__( 'Icon Box', 'qhost-core' ),
			]
		);

		$this->add_control(
			'icon_type',
			[
				'label'       => esc_html__( 'Add Icon/Image', 'irecco-core' ),
				'type'        => Controls_Manager::CHOOSE,
				'label_block' => false,
				'options'     => [
					''      => [
						'title' => esc_html__( 'None', 'irecco-core' ),
						'icon'  => 'fa fa-ban',
					],
					'font'  => [
						'title' => esc_html__( 'Icon', 'irecco-core' ),
						'icon'  => 'fa fa-smile-o',
					],
					'image' => [
						'title' => esc_html__( 'Image', 'irecco-core' ),
						'icon'  => 'fa fa-picture-o',
					]
				],
				'default'     => 'font',
			]
		);

		$this->add_control(
			'icon_pack',
			[
				'label'     => esc_html__( 'Icon Pack', 'irecco-core' ),
				'type'      => Controls_Manager::SELECT,
				'condition' => [
					'icon_type' => 'font',
				],
				'options'   => [
					'fontawesome' => esc_html__( 'Fontawesome', 'irecco-core' ),
					'themify'    => esc_html__( 'Themify', 'irecco-core' ),
				],
				'default'   => 'fontawesome',
			]
		);

		$this->add_control(
			'icon_themify',
			[
				'label'       => esc_html__( 'Icon', 'irecco-core' ),
				'type'      => Controls_Manager::ICON,
				'options'   => qhost_themify_icons(),
				'include'   => qhost_include_themify_icons(),
				'default'   => 'ti-ruler-alt-2',
				'label_block' => true,
				'condition'   => [
					'icon_pack' => 'themify',
					'icon_type' => 'font',
				],
			]
		);

		$this->add_control(
			'box_icon',
			[
				'label'       => esc_html__( 'Icon', 'irecco-core' ),
				'type'        => Controls_Manager::ICONS,
				'label_block' => true,
				'default'   => [
					'value'   => 'fas fa-star',
					'library' => 'solid',
				],
				'condition'   => [
					'icon_pack' => 'fontawesome',
					'icon_type' => 'font',
				],
				'description' => esc_html__( 'Select icon from Fontawesome library.', 'irecco-core' ),
			]
		);

		$this->add_control(
			'icon_image',
			[
				'label'       => esc_html__( 'Image', 'irecco-core' ),
				'type'        => Controls_Manager::MEDIA,
				'label_block' => true,
				'condition'   => [
					'icon_type' => 'image',
				],
				'default'     => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'box_sub_title', [
				'label'       => esc_html__( 'Box Title', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'Sub Title', 'qhost-core' ),
				'default'     => esc_html__( 'EASY & FIRST', 'qhost-core' ),
			]
		);

		$this->add_control(
			'box_title', [
				'label'       => esc_html__( 'Box Title', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'Title', 'qhost-core' ),
				'default'     => esc_html__( 'Service Heading', 'qhost-core' ),
			]
		);


		$this->add_control(
			'link',
			[
				'label'         => __( 'Link', 'qhost-core' ),
				'type'          => \Elementor\Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'qhost-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '',
					'is_external' => true,
					'nofollow'    => true,
				],
			]
		);

		$this->add_control(
			'description', [
				'label'       => esc_html__( 'Description', 'qhost-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'label_block' => true,
				'placeholder' => esc_html__( 'Description', 'qhost-core' ),
				'default'     => __( 'Jolly good tomfoolery starkers tinkety tonk old fruit some dodgy chav crikey blatant is bubble.', 'qhost-core' ),
				'separator'   => 'none',
			]
		);

		$this->add_control(
			'button_text', [
				'label'       => esc_html__( 'Button Text', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'Button Text', 'qhost-core' ),
				'default'     => __( 'Learn More', 'qhost-core' ),
				'separator'   => 'before',
			]
		);

		$this->add_control(
			'btn_link',
			[
				'label'         => __( 'Link', 'qhost-core' ),
				'type'          => \Elementor\Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'qhost-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '#',
					'is_external' => true,
					'nofollow'    => true,
				],
			]
		);

		$this->add_responsive_control(
			'title_align', [
				'label'     => esc_html__( 'Alignment', 'qhost-core' ),
				'type'      => Controls_Manager::CHOOSE,
				'options'   => [

					'left'    => [
						'title' => esc_html__( 'Left', 'qhost-core' ),
						'icon'  => 'fa fa-align-left',
					],
					'center'  => [
						'title' => esc_html__( 'Center', 'qhost-core' ),
						'icon'  => 'fa fa-align-center',
					],
					'right'   => [
						'title' => esc_html__( 'Right', 'qhost-core' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'qhost-core' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .tt-service-box' => 'text-align: {{VALUE}};'
				],
			]
		);

		$this->add_responsive_control(
			'box_align', [
				'label'     => esc_html__( 'Icon Position', 'qhost-core' ),
				'type'      => Controls_Manager::CHOOSE,
				'options'   => [
					'icon-left'  => [
						'title' => esc_html__( 'Left', 'qhost-core' ),
						'icon'  => 'fa fa-align-left',
					],
					'icon-right' => [
						'title' => esc_html__( 'Right', 'qhost-core' ),
						'icon'  => 'fa fa-align-right',
					],
				],
				'default'   => 'icon-left',
				'toggle'    => false,
			]
		);


		$this->end_controls_section();

		//Icon Style
		$this->start_controls_section(
			'section_icon_style', [
				'label' => esc_html__( 'Icon', 'qhost-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_color_one', [
				'label'     => esc_html__( 'Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-service-box .icon-container' => 'color: {{VALUE}};'
				],
			]
		);

		$this->add_control(
			'icon_border_color', [
				'label'     => esc_html__( 'Border Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-service-box .icon-container' => 'border-color: {{VALUE}};'
				],
			]
		);

		$this->end_controls_section();

		//Title Style Section
		$this->start_controls_section(
			'section_title_style', [
				'label' => esc_html__( 'Title', 'qhost-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_color_two', [
				'label'     => esc_html__( 'Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-service-box .box-title,
					{{WRAPPER}} .tt-service-box .box-title a' => 'color: {{VALUE}};'
				],
			]
		);
		$this->add_control(
			'title_color_two_hover', [
				'label'     => esc_html__( 'Hover Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-service-box .box-title:hover,
					{{WRAPPER}} .tt-service-box .box-title a:hover' => 'color: {{VALUE}};'
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(), [
				'name'     => 'title_typography',
				'selector' => '{{WRAPPER}} .tt-service-box .box-title',
			]
		);

		$this->end_controls_section();

		//Subtitle Style Section
		$this->start_controls_section(
			'section_subtitle_style', [
				'label' => esc_html__( 'Description', 'qhost-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'subtitle_color', [
				'label'     => esc_html__( 'color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-service-box .description' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(), [
				'name'     => 'subtitle_typography',
				'selector' => '{{WRAPPER}} .tt-service-box .description',
			]
		);

		$this->end_controls_section();

		//Icon Style
		$this->start_controls_section(
			'section_service_style', [
				'label' => esc_html__( 'Background', 'qhost-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'service_bg_color', [
				'label'     => esc_html__( 'Background Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-service-box' => 'background: {{VALUE}};'
				],
			]
		);

		$this->add_control(
			'service_border_color', [
				'label'     => esc_html__( 'Border Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-service-box' => 'border-color: {{VALUE}};'
				],
			]
		);


		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();
//		$layout   = $settings['layout'];
		$target   = $settings['link']['is_external'] ? ' target="_blank"' : '';
		$nofollow = $settings['link']['nofollow'] ? ' rel="nofollow"' : '';

		$btn_target   = $settings['btn_link']['is_external'] ? ' target="_blank"' : '';
		$btn_nofollow = $settings['btn_link']['nofollow'] ? ' rel="nofollow"' : '';

		require __DIR__ . '/templates/service/layout-1.php';
	}

	protected function _content_template() {
	}
}



