<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit;

class Qhost_Service_slider extends Widget_Base {

    public function get_name() {
        return 'tt-service-slider';
    }

    public function get_title() {
        return esc_html__( 'Qhost Service Slider', 'qhost-core' );
    }

    public function get_icon() {
        return 'eicon-testimonial';
    }

    public function get_categories() {
        return [ 'tt-elements' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_tab_style',
            [
                'label' => esc_html__('Service', 'qhost-core'),
            ]
        );


        $repeater = new \Elementor\Repeater();


		$repeater->add_control(
			'icon_type',
			[
				'label'       => esc_html__( 'Add Icon/Image', 'irecco-core' ),
				'type'        => Controls_Manager::CHOOSE,
				'label_block' => false,
				'options'     => [
					''      => [
						'title' => esc_html__( 'None', 'irecco-core' ),
						'icon'  => 'fa fa-ban',
					],
					'font'  => [
						'title' => esc_html__( 'Icon', 'irecco-core' ),
						'icon'  => 'fa fa-smile-o',
					],
					'image' => [
						'title' => esc_html__( 'Image', 'irecco-core' ),
						'icon'  => 'fa fa-picture-o',
					]
				],
				'default'     => 'font',
			]
		);

		$repeater->add_control(
			'icon_pack',
			[
				'label'     => esc_html__( 'Icon Pack', 'irecco-core' ),
				'type'      => Controls_Manager::SELECT,
				'condition' => [
					'icon_type' => 'font',
				],
				'options'   => [
					'fontawesome' => esc_html__( 'Fontawesome', 'irecco-core' ),
					'themify'    => esc_html__( 'Themify', 'irecco-core' ),
				],
				'default'   => 'fontawesome',
			]
		);

		$repeater->add_control(
			'icon_themify',
			[
				'label'       => esc_html__( 'Icon', 'irecco-core' ),
				'type'      => Controls_Manager::ICON,
				'options'   => qhost_themify_icons(),
				'include'   => qhost_include_themify_icons(),
				'default'   => 'ti-ruler-alt-2',
				'label_block' => true,
				'condition'   => [
					'icon_pack' => 'themify',
					'icon_type' => 'font',
				],
			]
		);

		$repeater->add_control(
			'box_icon',
			[
				'label'       => esc_html__( 'Icon', 'irecco-core' ),
				'type'        => Controls_Manager::ICONS,
				'label_block' => true,
				'default'   => [
					'value'   => 'fas fa-star',
					'library' => 'solid',
				],
				'condition'   => [
					'icon_pack' => 'fontawesome',
					'icon_type' => 'font',
				],
				'description' => esc_html__( 'Select icon from Fontawesome library.', 'irecco-core' ),
			]
		);

		$repeater->add_control(
			'icon_image',
			[
				'label'       => esc_html__( 'Image', 'irecco-core' ),
				'type'        => Controls_Manager::MEDIA,
				'label_block' => true,
				'condition'   => [
					'icon_type' => 'image',
				],
				'default'     => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);


		$repeater->add_control(
			'title', [
				'label' => __( 'Title', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Mominul' , 'qhost-core' ),
				'label_block' => true,
			]
        );       
 
		$repeater->add_control(
			'description', [
				'label' => __( 'Description', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'default' => __( 'Morish quaint porkies lavatory tosser burke boot victoria.' , 'qhost-core' ),
				'show_label' => false,
			]
		);

		$repeater->add_control(
			'button_text', [
				'label'       => esc_html__( 'Button Text', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'Button Text', 'qhost-core' ),
				'default'     => __( 'Learn More', 'qhost-core' ),
				'separator'   => 'before',
			]
		);

		$repeater->add_control(
			'btn_link',
			[
				'label'         => __( 'Link', 'qhost-core' ),
				'type'          => \Elementor\Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'qhost-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '#',
					'is_external' => true,
					'nofollow'    => true,
				],
			]
		);


		$this->add_control(
			'services',
			[
				'label' => __( 'Service Items', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'icon_image' => [
                            'url' => \Elementor\Utils::get_placeholder_image_src(),
                        ],
						'title' => __( 'Shared Hosting', 'qhost-core' ),				
						'description' => __( 'Morish quaint porkies lavatory tosser burke boot victoria.', 'qhost-core' ),
						'button_text' => __( 'Learn More', 'qhost-core' ),
						'btn_link' => [
							'url'  => '#',
						]
					],
					[
						'icon_image' =>  [
                            'url' => Utils::get_placeholder_image_src('saaspik_testimonial_three'),
                        ],					
						'title' => __( 'Reseller Hosting', 'qhost-core' ),					
						'description' => __( 'Morish quaint porkies lavatory tosser burke boot victoria.', 'qhost-core' ),
						'button_text' => __( 'Learn More', 'qhost-core' ),
						'btn_link' => [
							'url'  => '#',
						]
					],
					[
						'icon_image' =>  [
                            'url' => Utils::get_placeholder_image_src('saaspik_testimonial_three'),
                        ],					
						'title' => __( 'VPS Hosting', 'qhost-core' ),
						'description' => __( 'Morish quaint porkies lavatory tosser burke boot victoria.', 'qhost-core' ),
						'button_text' => __( 'Learn More', 'qhost-core' ),
						'btn_link' => [
							'url'  => '#',
						]
					],
					[
						'icon_image' =>  [
                            'url' => Utils::get_placeholder_image_src('saaspik_testimonial_three'),
                        ],					
						'title' => __( 'Cloud Hosting', 'qhost-core' ),
						'description' => __( 'Morish quaint porkies lavatory tosser burke boot victoria.', 'qhost-core' ),
						'button_text' => __( 'Learn More', 'qhost-core' ),
						'btn_link' => [
							'url'  => '#',
						]
					],
				],
				'title_field' => '{{{ title }}}',
			]
		);

		
		$this->add_responsive_control(
			'title_align', [
				'label'     => esc_html__( 'Alignment', 'qhost-core' ),
				'type'      => Controls_Manager::CHOOSE,
				'options'   => [

					'left'    => [
						'title' => esc_html__( 'Left', 'qhost-core' ),
						'icon'  => 'fa fa-align-left',
					],
					'center'  => [
						'title' => esc_html__( 'Center', 'qhost-core' ),
						'icon'  => 'fa fa-align-center',
					],
					'right'   => [
						'title' => esc_html__( 'Right', 'qhost-core' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'qhost-core' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .tt-icon-box' => 'text-align: {{VALUE}};'
				],			
			]
		);

		$this->end_controls_section();

		$this->start_controls_section( 'settingd_section', [
			'label' => esc_html__( 'Slider Control', 'qhost-core' ),
		] );

		$this->add_control(
			'slide_view',
			[
				'label' => __( 'Slide Per View', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => '3',
				'options' => [
					'2'  => __( '2', 'qhost-core' ),
					'3' => __( '3', 'qhost-core' ),
				],
			]
		);
		
		$this->add_control(
			'pagination',
			[
				'label' => esc_html__('Pagination on/off', 'qhost-core'),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('Show', 'qhost-core'),
				'label_off' => esc_html__('Hide', 'qhost-core'),
				'return_value' => 'yes',
				'default' => 'yes'
			]
		);
	

		$this->add_control(
			'loop',
			[
				'label' => esc_html__('Loop', 'qhost-core'),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('On', 'qhost-core'),
				'label_off' => esc_html__('Off', 'qhost-core'),
				'return_value' => 'true',
				'default' => 'yes'
			]
		);

		$this->add_control(
			'speed',
			[
				'label' => __('Speed', 'qhost-core'),
				'type' => Controls_Manager::NUMBER,
				'default' => 700,
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label' => esc_html__('Autoplay', 'qhost-core'),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('On', 'qhost-core'),
				'label_off' => esc_html__('Off', 'qhost-core'),
				'return_value' => 'true',
				'default' => 'yes'
			]
		);

		$this->add_control(
			'autoplay_time',
			[
				'label' => __('Autoplay Time', 'qhost-core'),
				'type' => Controls_Manager::NUMBER,
				'default' => 3000,
			]
		);

		$this->add_control(
			'slider_gap',
			[
				'label' => __('Slider Gap', 'qhost-core'),
				'type' => Controls_Manager::NUMBER,
				'default' => 30,
			]
		);

		$this->end_controls_section();


        // Style Sections

		$this->start_controls_section(
			'name_section',
			[
				'label' => __( 'Name', 'qhost-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'name_typography',
				'label' => __( 'Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .tt-testimonial .testimonial h4',
			]
		);

		$this->add_control(
			'name_color',
			[
				'label' => __( 'Color', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::COLOR,				
				'selectors' => [
					'{{WRAPPER}} .tt-testimonial .testimonial h4' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();

		
		$this->start_controls_section(
			'designation_section',
			[
				'label' => __( 'Designation', 'qhost-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'desi_typography',
				'label' => __( 'Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .tt-testimonial .testimonial span',
			]
		);

		$this->add_control(
			'desi_color',
			[
				'label' => __( 'Color', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::COLOR,				
				'selectors' => [
					'{{WRAPPER}} .tt-testimonial .testimonial span' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'review_section',
			[
				'label' => __( 'Review Content', 'qhost-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'review_typography',
				'label' => __( 'Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .tt-testimonial .testimonial p',
			]
		);

		$this->add_control(
			'review_color',
			[
				'label' => __( 'Color', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,				
				'selectors' => [
					'{{WRAPPER}} .tt-testimonial .testimonial p' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'bg_section',
			[
				'label' => __( 'Background', 'qhost-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'background',
				'label' => __( 'Background', 'qhost-core' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .tt-testimonial .testimonial',
			]
		);

		$this->add_control(
			'bg_shape_color',
			[
				'label' => __( 'BG Shape Color', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .testimonial-wrapper:before' => 'background: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();
    }

    protected function render( ) {

        $settings = $this->get_settings_for_display();
        $services = $settings['services'];    

        $this->add_render_attribute( 'wrapper', 'class', [		
			'swiper-container',
			'service-slider',
		] );

      
			$slider_options = $this->get_slider_options( $settings );

			$this->add_render_attribute( 'wrapper', 'data-service', wp_json_encode( $slider_options ) );
	

			require __DIR__.'/templates/icon-box/layout-slider.php';
			

        

    }

    protected function _content_template() { }

    protected function get_slider_options( array $settings ) {

		$slider_options['breakpoints'] = [
		    '992' => [
			    'slidesPerView' => (int)$settings['slide_view'],
		    ],

		    '576' => [
				'slidesPerView' => 2,
				'slidesPerGroup' => (int)'1',
		    ],

		    '320' => [
			    'slidesPerView' => 1,
		    ],
	    ];

		// Loop
		if ( $settings['loop'] ) {
			$slider_options['loop'] = (bool)$settings['loop'];
			// $slider_options['slidesPerGroup'] = (int)'2';

		}


		// Speed
		if ( ! empty( $settings['speed'] ) ) {
			$slider_options['speed'] = $settings['speed'];
		}	
		
		if ( ! empty( $settings['slider_gap'] ) ) {
			$slider_options['spaceBetween'] = $settings['slider_gap'];
		}
		if ( $settings['autoplay'] ) {
			$slider_options['autoplay'] = (bool)$settings['autoplay'];
		}

		if ( $settings['autoplay'] ) {			
			$slider_options['autoplay'] = [
				'delay' => $settings['autoplay_time']				
			];		
		}

		if ( $settings['pagination'] ) {
			$slider_options['pagination'] = [
				'el' => '.swiper-pagination-three',
                'clickable' => true
			];
		}		


		return $slider_options;
    }  


}