<?php

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Qhost_Social_Link extends Widget_Base
{

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name()
	{
		return 'tt-social-link';
	}


	public function get_title()
	{
		return __('Social Link', 'qhost-core');
	}

	public function get_icon()
	{

		return 'eicon-social-icons';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories()
	{
		return ['tt-elements'];
	}

	protected function _register_controls()
	{

		$this->start_controls_section(
			'section_content',
			[
				'label' => __('List', 'qhost-core'),
			]
        );
        


		$repeater = new Repeater();

		$repeater->add_control(
			'social_title', [
				'label' => __('Title', 'qhost-core'),
				'type' => Controls_Manager::TEXT,
				'plaseholder' => __('Social link name', 'qhost-core'),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'icon', [
				'label' => __('Choose Icon', 'qhost-core'),
				'type' => Controls_Manager::ICON,
                'options' => qhost_elegant_icons(),
                'include' => qhost_include_elegant_icons(), 
			]
		);

		$repeater->add_control(
			'link',
			[
				'label' => __('Link', 'qhost-core'),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __('https://your-link.com', 'qhost-core'),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
			]
        );

        $repeater->add_control(
			'icon_bg_color',
			[
				'label' => __( 'Background Color', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,			
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} a' => 'background-color: {{VALUE}}',
				],
			]
		);
        
        $repeater->add_control(
			'icon_color',
			[
				'label' => __( 'Icon Color', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,			
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} a' => 'color: {{VALUE}}',
				],
			]
        );
        
        $repeater->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'hover_box_shadow',
				'label' => __( 'Box Shadow', 'qhost-core' ),
				'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} a:hover',
			]
		);



		$this->add_control(
			'social_link',
			[
				'label' => __('Social List', 'qhost-core'),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [				
					[						
						'icon' => 'ti-facebook',
						'social_title' => __('FaceBook', 'qhost-core'),
					],
					[						
						'icon' => 'ti-twitter-alt',
						'social_title' => __('Twitter', 'qhost-core'),
                    ],
                    [						
						'icon' => 'ti-dribbble',
						'social_title' => __('Dribbble', 'qhost-core'),
					],
				],
				'title_field' => '{{{ social_title }}}',
			]
        );        


		$this->add_responsive_control(
			'social_align', [
				'label' => esc_html__('Alignment', 'qhost-core'),
				'type' => Controls_Manager::CHOOSE,
				'options' => [

					'left' => [
						'title' => esc_html__('Left', 'qhost-core'),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__('Center', 'qhost-core'),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__('Right', 'qhost-core'),
						'icon' => 'fa fa-align-right',
					],
				
				],			
				'selectors' => [
					'{{WRAPPER}} .dt-social-link' => 'text-align: {{VALUE}};'
				],
			
			]
		);

        $this->end_controls_section();
        
        $this->start_controls_section(
			'social_style_section',
			[
				'label' => __( 'Social Style', 'qhost-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'link_size',
			[
				'label' => __( 'Font Size', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 10,
				'max' => 50,
				'step' => 1,
                'default' => 15,
                'selectors' => [
                    '{{WRAPPER}} .tt-social-link li a' => 'font-size: {{VALUE}}px',
				], 	
			]
		);
        

		$this->add_control(
			'list_color',
			[
				'label' => __( 'Color', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} a' => 'color: {{VALUE}}',
				],
			]
        );
        
        $this->add_control(
			'list_hover_color',
			[
				'label' => __( 'Hover Color', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} a:hover' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();

	}

	protected function render()
	{
        $settings = $this->get_settings_for_display();

        $this->add_render_attribute('social', 'class', ['tt-social-link', 'list-unstyled' ]);


		if ($settings['social_link']) { ?>
            <ul <?php echo $this->get_render_attribute_string('social'); ?>>
				<?php foreach ($settings['social_link'] as $item) {

					$target = $item['link']['is_external'] ? ' target="_blank"' : '';
					$nofollow = $item['link']['nofollow'] ? ' rel="nofollow"' : '';
					?>
                    <li class="elementor-repeater-item-<?php echo esc_attr( $item['_id'] ); ?>">						
                        <a href="<?php echo esc_attr($item['link']['url']); ?>" <?php echo $target, $nofollow ?> title="<?php echo $item['social_title']; ?>">						
                            <i class="<?php echo esc_attr($item['icon']); ?>"></i>					 
						</a>
                    </li>

				<?php } ?>

			</ul>			
		<?php }

	}

}

