<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


class Qhost_Team extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * @since 1.0.0
	 */
	public function get_name() {
		return 'tt-team';
	}

	/**
	 * Get widget title.
	 *
	 * @since 1.0.0
	 */
	public function get_title() {
		return __( 'Qhost Team', 'qhost-core' );
	}

	/**
	 * Get widget icon.
	 *
	 * @since 1.0.0
	 */
	public function get_icon() {
		return 'eicon-person';
	}

	/**
	 * Get widget categories.
	 *
	 * @since 1.0.0
	 */
	public function get_categories() {
		return [ 'tt-elements' ];
	}

	/**
	 * Register widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

		//============================================
		// START TEAME CONTENT
		//============================================
		$this->start_controls_section(
			'team_content',
			[
				'label' => __( 'Qhost Team Member', 'qhost-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);


		$this->add_control(
			'name',
			[
				'label'       => __( 'Name', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter Name', 'qhost-core' ),
				'default'     => __( 'Robert Statham', 'qhost-core'),
			]
		);
		$this->add_control(
			'position',
			[
				'label'       => __( 'Position', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter Position', 'qhost-core' ),
				'default'     => 'Web Developer',
			]
		);

		$this->add_control(
			'image',
			[
				'label'   => __( 'Choose Image', 'qhost-core' ),
				'type'    => Controls_Manager::MEDIA,
				'default' => [
					'url' => plugins_url( 'images/team1.png', __FILE__ )
				],
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'icon',
			[
				'label' => __( 'Icon', 'text-domain' ),
				'type' => \Elementor\Controls_Manager::ICONS,
			]
		);

		$repeater->add_control(
			'link',
			[
				'label'       => __( 'Link', 'qhost-core' ),
				'type'        => Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'qhost-core' ),
			]
		);
		$repeater->add_control(
			'social_name',
			[
				'label'       => __( 'Name', 'qhost-core' ),
				'description' => __( 'This name will be show in the item header', 'qhost-core' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => 'Facebook',
			]
		);



		$this->add_control(
			'social_icons',
			[
				'label'       => __( 'Add Social Icon', 'qhost-core' ),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'icon'        => [
						    'value' => 'fab fa-facebook-f',
                            'library' => 'solid',
                        ],
						'link'        => [
							'url' => '#',
						],
						'social_name' => 'Facebook',
					],
					[
						'icon'        => [
						    'value' => 'fab fa-twitter',
                            'library' => 'solid',
                        ],
						'link'        => [
							'url' => '#',
						],
						'social_name' => 'Twitter',
					],
					[
						'icon'        => [
						    'value' => 'fab fa-dribbble',
                            'library' => 'solid',
                        ],
						'link'        => [
							'url' => '#',
						],
						'social_name' => 'Dribbble',
					],
					[
						'icon'        => [
						    'value' => 'fab fa-linkedin-in',
                            'library' => 'solid',
                        ],
						'link'        => [
							'url' => '#',
						],
						'social_name' => 'Linkedin',
					],
				],
				'title_field' => '{{{ social_name }}}',
			]
		);

		$this->end_controls_section();
		// End Team Content
		// =====================


		//============================================
		// START TEAME STYLE
		//============================================

		// Start Name Style
		// =====================
		$this->start_controls_section(
			'name_style',
			[
				'label' => __( 'Name', 'qhost-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'name_color',
			[
				'label'     => __( 'Text Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team-member .team-info .name' => 'color: {{VALUE}};',
				],
			]
		);


		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'name_typography',
				'label' => __( 'Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .team-member .team-info .name',
			]
		);


		$this->end_controls_section();
		// End Name Style
		// =====================


		// Start Position Style
		// =====================
		$this->start_controls_section(
			'position_style',
			[
				'label' => __( 'Designation', 'qhost-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'position_color',
			[
				'label'     => __( 'Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team-member .team-info .designation' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'position_typography',
				'label' => __( 'Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .team-member .team-info .designation',
			]
		);

		$this->end_controls_section();
		// End Position Style
		// =====================


		// Start Description Style
		// =====================
		$this->start_controls_section(
			'member_short_info',
			[
				'label' => __( 'Description', 'qhost-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'short_info_color',
			[
				'label'     => __( 'Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team-member .member-short-info' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'short_info_typography',
				'label' => __( 'Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .team-member .member-short-info',
			]
		);

		$this->end_controls_section();
		// End Position Style
		// =====================


		// Start Icon Style
		// =====================
		$this->start_controls_section(
			'icon_style',
			[
				'label' => __( 'Social Icon', 'qhost-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'font_size',
			[
				'label'      => __( 'Font Size', 'qhost-core' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => [ 'px', 'em' ],
				'default'    => [
					'unit' => 'px',
					'size' => '14',
				],
				'selectors'  => [
					'{{WRAPPER}} .team-member .member-social li a' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->start_controls_tabs( 'team_icon_tabs' );

		$this->start_controls_tab(
			'team_icon_normal',
			[
				'label' => __( 'Normal', 'qhost-core' ),
			]
		);

		$this->add_control(
			'team_icon_color',
			[
				'label'     => __( 'Icon Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team-member .member-social li a' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'team_icon_hover',
			[
				'label' => __( 'Hover', 'qhost-core' ),
			]
		);

		$this->add_control(
			'team_icon_hover_color',
			[
				'label'     => __( 'Icon Color', 'qhost-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team-member .member-social li a:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();
		// End Icon Style
		// =====================
	}


	protected function render() {
		$settings = $this->get_settings_for_display();	

		require __DIR__ . '/templates/team/style1.php';
	}


	protected function _content_template() {

	}
}