<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit;

class Qhost_Testimonial_Two extends Widget_Base {

    public function get_name() {
        return 'tt-testimonial-two';
    }

    public function get_title() {
        return esc_html__( 'Qhost Testimonial Two', 'qhost-core' );
    }

    public function get_icon() {
        return 'eicon-testimonial';
    }

    public function get_categories() {
        return [ 'tt-elements' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'section_tab_style',
            [
                'label' => esc_html__('Testimonial', 'qhost-core'),
            ]
        );

        $this->add_control(
			'watermark',
			[
				'label' => esc_html__('Water Mark', 'qhost-core'),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('Show', 'qhost-core'),
				'label_off' => esc_html__('Hide', 'qhost-core'),
				'return_value' => 'yes',
				'default' => 'yes'
			]
		);

		 $this->add_control(
			'quote_image',
			[
				'label' => __( 'Quote Image', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);
      

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
			'image',
			[
				'label' => __( 'Author Image', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);


		$repeater->add_control(
			'name', [
				'label' => __( 'Name', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Mominul' , 'qhost-core' ),
				'label_block' => true,
			]
        );
        
        $repeater->add_control(
			'designation', [
				'label' => __( 'Designation', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Full-Stack Developer' , 'qhost-core' ),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'review_content', [
				'label' => __( 'Review Content', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'default' => __( '“If you need any help or assistance we\'d be happy to help. Just reply to this email. Trusted by Agency proud to work many well known brands”' , 'qhost-core' ),
				'show_label' => false,
			]
		);


		$this->add_control(
			'testimonials',
			[
				'label' => __( 'Testimonial', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'image' => [
                            'url' => \Elementor\Utils::get_placeholder_image_src(),
                        ],
						'name' => __( 'Name #1', 'qhost-core' ),
						'designation' => __( 'Web Developer', 'qhost-core' ),
						'review_content' => __( 'Item content. Click the edit button to change this text.', 'qhost-core' ),
					],
					[
						'image' =>  [
                            'url' => Utils::get_placeholder_image_src('saaspik_testimonial_three'),
                        ],					
						'name' => __( 'Name #2', 'qhost-core' ),
						'designation' => __( 'UI/UX Designer', 'qhost-core' ),
						'review_content' => __( 'Item content. Click the edit button to change this text.', 'qhost-core' ),
					],
					[
						'image' =>  [
                            'url' => Utils::get_placeholder_image_src('saaspik_testimonial_three'),
                        ],					
						'name' => __( 'Name #3', 'qhost-core' ),
						'designation' => __( 'UI/UX Designer', 'qhost-core' ),
						'review_content' => __( 'Item content. Click the edit button to change this text.', 'qhost-core' ),
					],
				],
				'title_field' => '{{{ name }}}',
			]
		);

		$this->end_controls_section();

   

        $this->end_controls_section();

        
		$this->start_controls_section( 'settingd_section', [
			'label' => esc_html__( 'Slider Control', 'qhost-core' ),
		] );
		
		$this->add_control(
			'pagination',
			[
				'label' => esc_html__('Navigation', 'qhost-core'),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('Show', 'qhost-core'),
				'label_off' => esc_html__('Hide', 'qhost-core'),
				'return_value' => 'yes',
				'default' => 'yes'
			]
		);
	

		$this->add_control(
			'loop',
			[
				'label' => esc_html__('Loop', 'qhost-core'),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('On', 'qhost-core'),
				'label_off' => esc_html__('Off', 'qhost-core'),
				'return_value' => 'true',
				'default' => 'yes'
			]
		);

		$this->add_control(
			'speed',
			[
				'label' => __('Speed', 'qhost-core'),
				'type' => Controls_Manager::NUMBER,
				'default' => 700,
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label' => esc_html__('Autoplay', 'qhost-core'),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('On', 'qhost-core'),
				'label_off' => esc_html__('Off', 'qhost-core'),
				'return_value' => 'true',
				'default' => 'yes'
			]
		);

		$this->add_control(
			'autoplay_time',
			[
				'label' => __('Autoplay Time', 'qhost-core'),
				'type' => Controls_Manager::NUMBER,
				'default' => 3000,
			]
		);

		$this->end_controls_section();


        // Style Sections

		$this->start_controls_section(
			'name_section',
			[
				'label' => __( 'Name', 'qhost-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'name_typography',
				'label' => __( 'Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .tt-testimonial .testimonial h4',
			]
		);

		$this->add_control(
			'name_color',
			[
				'label' => __( 'Color', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::COLOR,				
				'selectors' => [
					'{{WRAPPER}} .tt-testimonial .testimonial h4' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();

		
		$this->start_controls_section(
			'designation_section',
			[
				'label' => __( 'Designation', 'qhost-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'desi_typography',
				'label' => __( 'Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .tt-testimonial .testimonial span',
			]
		);

		$this->add_control(
			'desi_color',
			[
				'label' => __( 'Color', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::COLOR,				
				'selectors' => [
					'{{WRAPPER}} .tt-testimonial .testimonial span' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'review_section',
			[
				'label' => __( 'Review Content', 'qhost-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'review_typography',
				'label' => __( 'Typography', 'qhost-core' ),
				'selector' => '{{WRAPPER}} .tt-testimonial .testimonial p',
			]
		);

		$this->add_control(
			'review_color',
			[
				'label' => __( 'Color', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,				
				'selectors' => [
					'{{WRAPPER}} .tt-testimonial .testimonial p' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'bg_section',
			[
				'label' => __( 'Background', 'qhost-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'background',
				'label' => __( 'Background', 'qhost-core' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .tt-testimonial .testimonial',
			]
		);

		$this->add_control(
			'bg_shape_color',
			[
				'label' => __( 'BG Shape Color', 'qhost-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .testimonial-wrapper:before' => 'background: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();
    }

    protected function render( ) {

        $settings = $this->get_settings_for_display();
        $testimonials = $settings['testimonials'];    

        $this->add_render_attribute( 'wrapper', 'class', [		
			'swiper-container',
			'tt-testimonial-two',
		] );

      
			$slider_options = $this->get_slider_options( $settings );

			$this->add_render_attribute( 'wrapper', 'data-testi-two', wp_json_encode( $slider_options ) );
	

        require __DIR__.'/templates/testimonial/layout-3.php';

    }

    protected function _content_template() { }

    protected function get_slider_options( array $settings ) {

		// Loop
		if ( $settings['loop'] ) {
			$slider_options['loop'] = (bool)$settings['loop'];
		}

		// Speed
		if ( ! empty( $settings['speed'] ) ) {
			$slider_options['speed'] = $settings['speed'];
		}
		if ( $settings['autoplay'] ) {
			$slider_options['autoplay'] = (bool)$settings['autoplay'];
		}

		if ( $settings['autoplay'] ) {			
			$slider_options['autoplay'] = [
				'delay' => $settings['autoplay_time']				
			];		
		}

		if ( $settings['pagination'] ) {
			$slider_options['pagination'] = [
				'el' => '.swiper-pagination-two',
                'clickable' => true
			];
		}		


		return $slider_options;
    }  


}