<?php
/**
 * qhost functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package qhost
 */

/**
* Path Define
*/

define( 'QHOST_THEME_DIR', get_template_directory() );
define( 'KHOST_THEME_URI', get_template_directory_uri() );


/**
 * Implement the Custom Header feature.
 */
require QHOST_THEME_DIR . '/inc/custom-header.php';

/**
 * Load All Classes.
 */
require_once QHOST_THEME_DIR .'/inc/class/theme-autoload.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require QHOST_THEME_DIR . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require QHOST_THEME_DIR . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require QHOST_THEME_DIR . '/inc/jetpack.php';
}

/**
 * Filter the categories archive widget to add a span around post count
 */
function qhost_cat_count_span($links) {
	$links = str_replace('</a> ', ' <span class="post-count">', $links);
	$links = str_replace(')', ')</span></a>', $links);
	return $links;
}

add_filter('wp_list_categories', 'qhost_cat_count_span');

/**
 * Filter the archives widget to add a span around post count
 */
function qhost_archive_count_span($links) {
	$links = str_replace('</a>&nbsp;(', '<span class="post-count">(', $links);
	$links = str_replace(')', ')</span></a>', $links);
	return $links;
}

add_filter('get_archives_link', 'qhost_archive_count_span');

if (!function_exists('qhost_reorder_comment_fields')) {
    function qhost_reorder_comment_fields($fields ) {
        $new_fields = array();

        $myorder = array('author', 'email', 'url', 'comment');

        foreach( $myorder as $key ){
            $new_fields[ $key ] = isset($fields[ $key ]) ? $fields[ $key ] : '';
            unset( $fields[ $key ] );
        }

        if( $fields ) {
            foreach( $fields as $key => $val ) {
                $new_fields[ $key ] = $val;
            }
        }

        return $new_fields;
    }
}

add_filter('comment_form_fields', 'qhost_reorder_comment_fields');

/**
 * Enqueue svg to the media.
 * @return void
 */
add_filter('upload_mimes', 'qhost_svg_mime_types');

function qhost_svg_mime_types($mimes)
{
	$mimes['svg'] = 'image/svg+xml';
	return $mimes;
}