<?php
if (!defined('ABSPATH')) {
	exit;
}
/**
 * Qhost Theme Helper
 *
 *
 * @class        Qhost_Theme_Helper
 * @version      1.0
 * @category Class
 * @author       Themetags
 */

if (!class_exists('Qhost_Theme_Helper')) {
	Class Qhost_Theme_Helper {

		/**
		 * Constructor
		 */
		function __construct() {

			// A function for get an option
			if (!function_exists('qhost_option')) {
				function qhost_option($option = '', $default = null) {
					$options = get_option('qhost_framework'); // Attention: Set your unique id of the framework

					return (isset($options[$option])) ? $options[$option] : $default;
				}
			}

			add_action('qhost_after_body', array($this, 'qhost_preloader_markup'), 1);
		}


		/**
		 * Utility methods
		 * ---------------
		 */
		//Add breadcrumbs
		static function qhost_breadcrumb() {
			global $post;
			$qhost_opt = get_option('qhost_opt');
			$brseparator = '<span class="separator"> <span class="ti-angle-right"></span> </span>';
			if (!is_home()) {
				echo '<div class="breadcrumbs">';
				echo '<a href="';
				echo esc_url(home_url('/'));
				echo '">';
				echo esc_html__('Home', 'qhost');
				echo '</a>' . $brseparator;
				if (is_category() || is_single()) {
					$categories = get_the_category();
					if (count($categories) > 0) {
						echo '<a href="' . esc_url(get_category_link($categories[0]->term_id)) . '">' . esc_html($categories[0]->name) . '</a>';
					}
					if (is_single()) {
						if (count($categories) > 0) {
							echo '' . $brseparator;
						}
						the_title();
					}
				} elseif (is_page()) {
					if ($post->post_parent) {
						$anc = get_post_ancestors($post->ID);
						$title = get_the_title();
						foreach ($anc as $ancestor) {
							$output = '<a href="' . get_permalink($ancestor) . '" title="' . get_the_title($ancestor) . '">' . get_the_title($ancestor) . '</a>' . $brseparator;
						}
						echo wp_kses($output, array(
								'a' => array(
									'href' => array(),
									'title' => array()
								),
								'span' => array(
									'class' => array()
								)
							)
						);
						echo '<span title="' . $title . '"> ' . $title . '</span>';
					} else {
						echo '<span> ' . get_the_title() . '</span>';
					}
				} elseif (is_tag()) {
					single_tag_title();
				} elseif (is_day()) {
					printf(esc_html__('Archive for: %s', 'qhost'), '<span>' . get_the_date() . '</span>');
				} elseif (is_month()) {
					printf(esc_html__('Archive for: %s', 'qhost'), '<span>' . get_the_date(_x('F Y', 'monthly archives date format', 'qhost')) . '</span>');
				} elseif (is_year()) {
					printf(esc_html__('Archive for: %s', 'qhost'), '<span>' . get_the_date(_x('Y', 'yearly archives date format', 'qhost')) . '</span>');
				} elseif (is_author()) {
					echo "<span>" . esc_html__('Archive for', 'qhost');
					echo '</span>';
				} elseif (isset($_GET['paged']) && !empty($_GET['paged'])) {
					echo "<span>" . esc_html__('Blog Archives', 'qhost');
					echo '</span>';
				} elseif (is_search()) {
					echo "<span>" . esc_html__('Search Results', 'qhost');
					echo '</span>';
				}
				echo '</div>';
			} else {
				echo '<div class="breadcrumbs">';
				echo '<a href="';
				echo esc_url(home_url('/'));
				echo '">';
				echo esc_html__('Home', 'qhost');
				echo '</a>' . $brseparator;
				if (isset($qhost_opt['blog_header_text']) && $qhost_opt['blog_header_text'] != "") {
					echo esc_html($qhost_opt['blog_header_text']);
				} else {
					echo esc_html__('Blog', 'qhost');
				}
				echo '</div>';
			}
		}

		/**
		 * Displays navigation to next/previous pages when applicable.
		 *
		 * @since qhost 1.0
		 */
		static function qhost_content_nav($html_id) {
			global $wp_query;
			$html_id = esc_attr($html_id);
			if ($wp_query->max_num_pages > 1) : ?>
                <nav id="<?php echo esc_attr($html_id); ?>" class="navigation" role="navigation">
                    <h3 class="assistive-text"><?php esc_html_e('Post navigation', 'qhost'); ?></h3>
                    <div class="nav-previous"><?php next_posts_link(wp_kses(__('<span class="meta-nav">&larr;</span> Older posts', 'qhost'), array('span' => array('class' => array())))); ?></div>
                    <div class="nav-next"><?php previous_posts_link(wp_kses(__('Newer posts <span class="meta-nav">&rarr;</span>', 'qhost'), array('span' => array('class' => array())))); ?></div>
                </nav>
			<?php endif;
		}

		/* Pagination */

		static function qhost_post_pagination($nav_query = false) {

			global $wp_query, $wp_rewrite;

			// Don't print empty markup if there's only one page.
			if ($GLOBALS['wp_query']->max_num_pages < 2) {
				return;
			}

			// Prepare variables
			$query = $nav_query ? $nav_query : $wp_query;
			$max = $query->max_num_pages;
			$current_page = max(1, get_query_var('paged'));
			$big = 999999;
			?>
            <nav id="post-pagination">
				<?php
				echo '' . paginate_links(
						array(
							'base' => str_replace($big, '%#%', esc_url(get_pagenum_link($big))),
							'format' => '?paged=%#%',
							'current' => $current_page,
							'total' => $max,
							'type' => 'list',
							'prev_text' => '<i class="ei ei-arrow_left"></i>',
							'next_text' => '<i class="ei ei-arrow_right"></i>'
						)
					) . ' ';
				?>
            </nav><!-- .page-nav -->
			<?php
		}

		/**
		 * Template for comments and pingbacks.
		 *
		 * To override this walker in a child theme without modifying the comments template
		 * simply create your own qhost_comment(), and that function will be used instead.
		 *
		 * Used as a callback by wp_list_comments() for displaying the comments.
		 *
		 * @since qhost 1.0
		 */
		static function qhost_comment($comment, $args, $depth) {
			$GLOBALS['comment'] = $comment;
			switch ($comment->comment_type) :
				case 'pingback' :
				case 'trackback' :
					// Display trackbacks differently than normal comments.
					?>
                    <li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
                    <p><?php esc_html_e('Pingback:', 'qhost'); ?><?php comment_author_link(); ?><?php edit_comment_link(esc_html__('(Edit)', 'qhost'), '<span class="edit-link">', '</span>'); ?></p>
					<?php
					break;
				default :
					// Proceed with normal comments.
					global $post;
					?>
                    <li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
                    <article id="comment-<?php comment_ID(); ?>" class="comment">
                        <div class="comment-avatar">
							<?php echo get_avatar($comment, 50); ?>
                        </div>
                        <div class="comment-info">
                            <header class="comment-meta comment-author vcard">
								<?php
								printf('<cite><b class="fn">%1$s</b> %2$s</cite>',
									get_comment_author_link(),
									// If current post author is also comment author, make it known visually.
									($comment->user_id === $post->post_author) ? '<span>' . esc_html__('Post author', 'qhost') . '</span>' : ''
								);
								printf('<time datetime="%1$s">%2$s</time>',
									get_comment_time('c'),
									/* translators: 1: date, 2: time */
									sprintf(esc_html__('%1$s at %2$s', 'qhost'), get_comment_date(), get_comment_time())
								);
								?>
                                <div class="reply">
									<?php comment_reply_link(array_merge($args, array(
										'reply_text' => esc_html__('Reply', 'qhost'),
										'after' => '',
										'depth' => $depth,
										'max_depth' => $args['max_depth']
									))); ?>
                                </div><!-- .reply -->
                            </header><!-- .comment-meta -->
							<?php if ('0' == $comment->comment_approved) : ?>
                                <p class="comment-awaiting-moderation"><?php esc_html_e('Your comment is awaiting moderation.', 'qhost'); ?></p>
							<?php endif; ?>
                            <section class="comment-content comment">
								<?php comment_text(); ?>
								<?php edit_comment_link(esc_html__('Edit', 'qhost'), '<p class="edit-link">', '</p>'); ?>
                            </section><!-- .comment-content -->
                        </div>
                    </article><!-- #comment-## -->
					<?php
					break;
			endswitch; // end comment_type check
		}

		/**
		 * Set up post entry meta.
		 *
		 * Prints HTML with meta information for current post: categories, tags, permalink, author, and date.
		 *
		 * Create your own qhost_entry_meta() to override in a child theme.
		 *
		 * @since qhost 1.0
		 */
		static function qhost_entry_meta() {
			// Translators: used between list items, there is a space after the comma.
			$tag_list = get_the_tag_list('', ', ');
			$num_comments = (int)get_comments_number();
			$write_comments = '';
			if (comments_open()) {
				if ($num_comments == 0) {
					$comments = esc_html__('0 comments', 'qhost');
				} elseif ($num_comments > 1) {
					$comments = $num_comments . esc_html__(' comments', 'qhost');
				} else {
					$comments = esc_html__('1 comment', 'qhost');
				}
				$write_comments = '<a href="' . get_comments_link() . '">' . $comments . '</a>';
			}
			$utility_text = null;
			if ((post_password_required() || !comments_open()) && ($tag_list != false && isset($tag_list))) {
				$utility_text = esc_html__('Tags: %2$s', 'qhost');
			} elseif ($tag_list != false && isset($tag_list) && $num_comments != 0) {
				$utility_text = esc_html__('%1$s / Tags: %2$s', 'qhost');
			} elseif (($num_comments == 0 || !isset($num_comments)) && $tag_list == true) {
				$utility_text = esc_html__('Tags: %2$s', 'qhost');
			} else {
				$utility_text = esc_html__('%1$s', 'qhost');
			}
			printf($utility_text, $write_comments, $tag_list);
		}

		static function qhost_entry_meta_small() {
			// Translators: used between list items, there is a space after the comma.
			$categories_list = get_the_category_list(', ');
			$author = sprintf('<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s" rel="author">%3$s</a></span>',
				esc_url(get_author_posts_url(get_the_author_meta('ID'))),
				esc_attr(sprintf(wp_kses(__('View all posts by %s', 'qhost'), array('a' => array())), get_the_author())),
				get_the_author()
			);
			$utility_text = esc_html__('By %1$s', 'qhost');
			printf($utility_text, $author);
		}

		static function qhost_posted_on() {
			$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
			if (get_the_time('U') !== get_the_modified_time('U')) {
				$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
			}

			$time_string = sprintf($time_string,
				esc_attr(get_the_date(DATE_W3C)),
				esc_html(get_the_date()),
				esc_attr(get_the_modified_date(DATE_W3C)),
				esc_html(get_the_modified_date())
			);

			$posted_on = sprintf(

				'<a href="' . esc_url(get_permalink()) . '" rel="bookmark">' . $time_string . '</a>'
			);

			echo '<span class="posted-on">' . $posted_on . '</span>'; // WPCS: XSS OK.

		}

		static function qhost_posted_author_avatar() {
			global $post;


			printf(
				'<span class="author vcard">%1$s</span>',
				sprintf(
					'<a class="url fn n post-author" href="%1$s"> %2$s %3$s</a>',
					esc_url(get_author_posts_url(get_the_author_meta('ID'))),
					get_avatar(get_the_author_meta('ID'), 25),
					esc_html(get_the_author())
				)
			);


			$allowed_html = array(
				'span' => array(
					'class' => true,
				),
				'br' => array(),
				'em' => array(),
				'strong' => array()
			);
		}

		static function qhost_posted_by() {
			$byline = sprintf(
			/* translators: %s: post author. */
				esc_html_x('By %s', 'post author', 'qhost'),
				'<span class="author vcard"><a class="url fn n" href="' . esc_url(get_author_posts_url(get_the_author_meta('ID'))) . '">' . esc_html(get_the_author()) . '</a></span>'
			);

			echo '<span class="byline"> ' . $byline . '</span>'; // WPCS: XSS OK.

		}


		static function qhost_entry_cat() {
			// Hide category and tag text for pages.
			if ('post' === get_post_type()) {
				/* translators: used between list items, there is a space after the comma */
				$categories_list = get_the_category_list(esc_html__(' ', 'qhost'));
				if ($categories_list) {
					/* translators: 1: list of categories. */
					printf(esc_html__(' %1$s', 'qhost'), $categories_list); // WPCS: XSS OK.
				}

			}


			edit_post_link(
				sprintf(
					wp_kses(
					/* translators: %s: Name of current post. Only visible to screen readers */
						__('Edit <span class="screen-reader-text">%s</span>', 'qhost'),
						array(
							'span' => array(
								'class' => array(),
							),
						)
					),
					get_the_title()
				),
				'<span class="edit-link ml_5">',
				'</span>'
			);
		}

		static function qhost_posted_tag() {
			// Hide category and tag text for pages.
			if ('post' === get_post_type()) {

				/* translators: used between list items, there is a space after the comma */
				$tags_list = get_the_tag_list('', esc_html_x(' ', 'list item separator', 'qhost'));
				if ($tags_list) {
					/* translators: 1: list of tags. */
					printf('<div class="tagcloud">' . esc_html__('%1$s', 'qhost') . '</div>', $tags_list); // WPCS: XSS OK.
				}
			}
		}

		/**
		 * Trim text
		 */
		static function qhost_substring($string, $limit, $afterlimit = '[...]') {
			if (empty($string)) {
				return $string;
			}
			$string = explode(' ', strip_tags($string), $limit);

			if (count($string) >= $limit) {
				array_pop($string);
				$string = implode(" ", $string) . ' ' . $afterlimit;
			} else {
				$string = implode(" ", $string);
			}
			$string = preg_replace('`[[^]]*]`', '', $string);

			return strip_shortcodes($string);
		}

		/**
		 * Footer Widget Column.
		 *
		 * Set Column Footer Widget areas.
		 *
		 * @since qhost 1.0
		 */
		public function qhost_get_footer_column($footer_columns) {
			if ($footer_columns == 12) {
				return 1;
			} elseif ($footer_columns == 6) {
				return 2;
			} elseif ($footer_columns == 4) {
				return 3;
			} else {
				return 4;
			}
		}

		/**
		 * Render sidebars.
		 *
		 * All Page Sidebar Control.
		 *
		 * @since qhost 1.0
		 */


		public static function render_sidebars( $args = 'blog' ) {
		    $output = array();
			$sidebar_style = '';

			$layout = qhost_option($args . '_sidebar_layout') ? qhost_option($args . '_sidebar_layout') : 'right';
			$sidebar = 'sidebar_main-sidebar';
			$sidebar_width = qhost_option($args . '_sidebar_def_width', '8');
			$sidebar_gap = qhost_option($args . '_sidebar_gap', '45');
			$sidebar_class = $sidebar_style = '';

			if ( isset($sidebar_gap) && $sidebar_gap != 'def' && $layout != 'default' ) {
				$layout_pos = $layout == 'left' ? 'right' : 'left';
				$sidebar_style = 'style="padding-' . $layout_pos . ': ' . $sidebar_gap . 'px;"';
			}

			$column = 12;
			if ( $layout == 'left' || $layout == 'right' ) {
				$column = (int)$sidebar_width;
			} else {
				$sidebar = '';
			}

			if ( !is_active_sidebar($sidebar) ) {
				$column = 12;
				$sidebar = '';
				$layout = 'none';
			}

			$output['column'] = $column;
			$output['row_class'] = $layout != 'none' ? ' sidebar_' . esc_attr($layout) : '';
			$output['layout'] = $layout;
			$output['content'] = '';

			if ( $layout == 'left' || $layout == 'right' ) {
				$output['content'] .= '<div class="sidebar-container ' . $sidebar_class . 'col-lg-' . (12 - (int)$column) . '" ' . $sidebar_style . '>';
				if ( is_active_sidebar($sidebar) ) {
					$output['content'] .= "<aside class='sidebar'>";
					ob_start();
					dynamic_sidebar($sidebar);
					$output['content'] .= ob_get_clean();
					$output['content'] .= "</aside>";
				}
				$output['content'] .= "</div>";
			}
			return $output;
		}


		/**
		 * @param $name
		 * Name of dynamic sidebar
		 * Check sidebar is active then dynamic it.
		 */
		public static function generated_sidebar($name) {
			if (is_active_sidebar($name)) {
				dynamic_sidebar($name);
			}
		}

		private function post_author($author) {
			if (!(bool)$author) {
				return;
			}

			return '<span class="post_author">' . esc_html__("by", "qhost") . ' <a href="' . esc_url(get_author_posts_url(get_the_author_meta('ID'))) . '">' . esc_html(get_the_author_meta('display_name')) . '</a></span>';
		}

		/**
		 * Display Post Thumbnail.
		 */
		static function qhost_post_thumbnail() {
			if (post_password_required() || is_attachment() || !has_post_thumbnail()) {
				return;
			}

			if (is_singular()) : ?>

                <div class="feature-image">
					<?php the_post_thumbnail('qhost-post-single'); ?>
                </div><!-- .post-thumbnail -->

			<?php else : ?>
                <a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
					<?php the_post_thumbnail('full', array( 'alt' => the_title_attribute(array('echo' => false,)))); ?>
                </a>
			<?php
			endif; // End is_singular().
		}


		static function render_author_info() {
			$user_email = get_the_author_meta('user_email');
			$user_avatar = get_avatar($user_email, 120);
			$user_first = get_the_author_meta('first_name');
			$user_last = get_the_author_meta('last_name');
			$user_description = get_the_author_meta('description');
			$user_instagram = get_the_author_meta('instagram');
			$user_facebook = get_the_author_meta('facebook');
			$user_linkedin = get_the_author_meta('linkedin');
			$user_twitter = get_the_author_meta('twitter');

			$avatar_html = !empty($user_avatar) ? '<div class="author-info_avatar">' . $user_avatar . '</div>' : '';
			$name_html = !empty($user_first) || !empty($user_last) ? '<h5 class="author-info_name">' . $user_first . ' ' . $user_last . '</h5>' : '';

			$description = !empty($user_description) ? '<div class="author-info_description">' . $user_description . '</div>' : '';

			$social_array = array(
				'twitter' => get_the_author_meta('twitter'),
				'facebook-f' => get_the_author_meta('facebook'),
				'linkedin' => get_the_author_meta('linkedin'),
				'instagram' => get_the_author_meta('instagram'),
			);
			$social_html = '';
			foreach ($social_array as $key => $value) {
				$social_html .= !empty($value) ? '<a href="' . esc_url($value) . '" class="author-info_social-link fab fa-' . esc_attr($key) . '"></a>' : '';
			}
			$social_html = !empty($social_html) ? '<div class="author-info_social-wrapper">' . '<span class="title_soc_share">' . esc_html__('In Socials:', 'qhost') . '</span>' . $social_html . '</div>' : '';

			if ((bool)$name_html || (bool)$description || (bool)$social_html) {
				echo '<div class="author-info_wrapper clearfix">' . $avatar_html . '<div class="author-info_content">' . $name_html . $description . $social_html . '</div></div>';
			}

		}

		/**
		 * Preloader.
		 *
		 * Preloader Init.
		 *
		 * @since qhost 1.0
		 */

		public function qhost_preloader_markup() {
			$preloader = qhost_option('preloader');
			$preloader_opt = qhost_option('qhost_preloader');
			$preloader_type = qhost_option('preloader-type');
			$preloader_img = qhost_option('preloader-images');


			if (!empty($preloader_opt)) :
				$style_name = substr($preloader_opt, 0, -2);
				$style_div = substr($preloader_opt, -1);
				if ($preloader) : ?>

                    <div id="preloader">
						<?php if ($preloader_type == 'css') : ?>
                            <div id="loader">
                                <div class="loader-inner <?php echo esc_attr($style_name); ?>">
									<?php for ($div = 0; $div < $style_div; $div++) : ?>
                                        <div></div>
									<?php endfor; ?>
                                </div>
                            </div><!-- /#loader -->
						<?php elseif ($preloader_type == 'preloader-img') : ?>
							<?php $img = wp_get_attachment_image_src($preloader_img, 'full', true); ?>

                            <img class="pr" src="<?php echo esc_url($img[0]); ?>"
                                 width="<?php echo esc_attr($img[1]); ?>"
                                 height="<?php echo esc_attr($img[2]); ?>" alt="<?php get_bloginfo('name'); ?>"/>
						<?php endif; ?>
                    </div><!-- /#preloader -->
				<?php
				endif;
			endif;
		}


		public static function render_html($args) {
			return isset($args) ? $args : '';
		}

		static function qhost_entry_comments($post_id, $no_comments = 'No Comment') {

			$comments_number = get_comments_number($post_id);
			if ($comments_number == 0) {
				$comment_text = $no_comments;
			} elseif ($comments_number == 1) {
				$comment_text = esc_html__('1 Comment', 'qhost');
			} elseif ($comments_number > 1) {
				$comment_text = $comments_number . esc_html__(' Comments', 'qhost');
			}
			echo esc_html($comment_text);

		}

		/**
		 * Logo
		 */
		public static function branding_logo() {

			$logo_main = qhost_option('main_logo');
			$sticky = qhost_option('sticky_logo');
			$retina_logo = qhost_option('retina_logo');
			$retina_sticky = qhost_option('retina_logo_sticky');
			$is_sticky_header = qhost_option('header_sticky');

			// Logo Callback
			$logo = !empty($logo_main['url']) ? $logo_main['url'] : '';
			$logo_contrast = !empty($sticky['url']) ? $sticky['url'] : '';
			$retina_logo = !empty($retina_logo['url']) ? $retina_logo['url'] : '';
            $retina_logo_sticky = !empty($retina_sticky ['url']) ? $retina_sticky ['url'] : '';

            // Logo Meta Callback
            $meta = get_post_meta( get_the_ID(), 'qhost_page_options', true );

            $meta_true = isset( $meta['meta_header_type'] ) ? $meta['meta_header_type'] : '0';

			if ( $meta_true  ) {
			    $logo = !empty( $meta['meta_main_logo']['url'] ) ? $meta['meta_main_logo']['url'] : $logo;
                $logo_contrast = !empty( $meta['meta_sticky_logo']['url'] ) ? $meta['meta_sticky_logo']['url'] : $logo_contrast;
                $retina_logo = !empty( $meta['retina_logo']['url'] ) ? $meta['retina_logo']['url'] : $retina_logo;
                $retina_logo_sticky = !empty( $meta['retina_logo_sticky']['url'])  ? $meta['retina_logo_sticky']['url'] : $retina_logo_sticky;
            } ?>

            <a href="<?php echo esc_url(home_url('/')); ?>" rel="home">
			    <?php if (!empty($logo)) { ?>
                    <img <?php if (!empty($retina_logo)) echo 'srcset="' . esc_attr($retina_logo) . ' 2x"'; ?> src="<?php echo esc_url($logo); ?>" alt="<?php bloginfo('name'); ?>"  class="main-logo" />

					<?php if ($logo_contrast !== '' && $is_sticky_header == true): ?>
                        <img <?php if (!empty($retina_logo_sticky)) echo 'srcset="' . esc_attr($retina_logo_sticky) . ' 2x"'; ?> src="<?php echo esc_url($logo_contrast); ?>" alt="<?php bloginfo('name'); ?>" class="logo-sticky">
					<?php endif; ?>

                <?php } else { ?>
                    <h3><?php bloginfo('name'); ?></h3>
                <?php } ?>
			</a>
            <?php
		}

		static function render_post_list_share() { ?>

            <div class="share_social-wpapper">            
                <ul class="social-share-link">
                    <li>
                        <a class="share_post share_facebook" target="_blank" href="<?php echo esc_url('https://www.facebook.com/share.php?u=' . get_permalink()); ?>">
                            <i class="fab fa-facebook-f"></i>
                        </a>
                    </li>
                    <li>
                        <a class="share_post share_twitter" target="_blank" href="<?php echo esc_url('https://twitter.com/intent/tweet?text=' . get_the_title() . '&amp;url=' . get_permalink()); ?>">
                            <i class="fab fa-twitter"></i>
                        </a>
                    </li>
					<?php
                        $img_url = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'single-post-thumbnail');
                        if (strlen($img_url[0]) > 0) {
                            echo '<li>';
                            echo '<a class="share_post share_pinterest" target="_blank" href="' . esc_url('https://pinterest.com/pin/create/button/?url=' . get_permalink() . '&media=' . $img_url[0]) . '"><i class="fab fa-pinterest-p"></i></a>';
                            echo '</li>';
                        }
					?>
                    <li>
                        <a class="share_post share_linkedin" target="_blank" href="<?php echo esc_url('http://www.linkedin.com/shareArticle?mini=true&url=' . substr(urlencode(get_permalink()), 0, 1024)); ?>&title=<?php echo esc_attr(substr(urlencode(html_entity_decode(get_the_title())), 0, 200)); ?>">
                            <i class="fab fa-linkedin-in"></i>
                        </a>
                    </li>
                </ul>
            </div>

			<?php
		}

		/**
		 * Returns array of title tags
		 *
		 * @param bool $first_empty
		 * @param array $additional_elements
		 *
		 * @return array
		 */
		static function qhost_get_title_tag($first_empty = false, $additional_elements = array())	{
			$title_tag = array();

			if ($first_empty) {
				$title_tag[''] = esc_html__('Default', 'qhost');
			}

			$title_tag['h1'] = 'h1';
			$title_tag['h2'] = 'h2';
			$title_tag['h3'] = 'h3';
			$title_tag['h4'] = 'h4';
			$title_tag['h5'] = 'h5';
			$title_tag['h6'] = 'h6';

			if (!empty($additional_elements)) {
				$title_tag = array_merge($title_tag, $additional_elements);
			}

			return $title_tag;
		}
	}

	// Instantiate theme
	new Qhost_Theme_Helper();
}