<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }
/**
* Qhost Theme Support
*
*
* @class        Qhost_Theme_Support
* @version      1.0
* @category     Class
* @author       ThemeTags
*/

if (!class_exists('Qhost_Theme_Support')) {
    class Qhost_Theme_Support{

        private static $instance = null;
        public static function get_instance( ) {
            if ( null == self::$instance ) {
                self::$instance = new self( );
            }

            return self::$instance;
        }

        public function __construct () {
            //Register Nav Menu
            add_action('init', array($this, 'register_my_menus') );
            //Add translation file
            add_action('init', array($this, 'enqueue_translation_files') );
            //Add widget support
            add_action('widgets_init', array($this, 'sidebar_register') );

            add_action( 'after_setup_theme', array($this, 'qhost_setup' ));
            add_action( 'after_setup_theme', array($this, 'qhost_content_width' ));
        }
        

        function qhost_setup() {

        	if (function_exists('add_theme_support')) {
                add_theme_support('post-thumbnails');
                set_post_thumbnail_size(770, 465, array('center', 'center')); // Hard crop center center

                add_theme_support('automatic-feed-links');
                add_theme_support('revisions');
                add_theme_support( 'title-tag' );
                add_theme_support('post-formats', array('gallery', 'video', 'quote', 'audio', 'link'));
                add_theme_support( 'html5', array('search-form', 'comment-form', 'comment-list', 'gallery',	'caption') );
              
                
                // Set up the WordPress core custom background feature.
                add_theme_support( 'custom-background', apply_filters( 'qhost_custom_background_args', array(
					'default-color' => 'ffffff',
					'default-image' => '',
				) ) );

                /**
				 * Add support for core custom logo.
				 *
				 * @link https://codex.wordpress.org/Theme_Logo
				 */
				add_theme_support( 'custom-logo', array(
					'height'      => 50,
					'width'       => 200,
					'flex-width'  => true,
					'flex-height' => true,
				) );

				//Image Size		
                add_image_size( 'qhost-recent-post-thumb', 85, 85, true );
                add_image_size( 'qhost-post-single', 750, 400, true );
            }
        }


        public function register_my_menus(){
            register_nav_menus(
                array(
                    'primary' => esc_html__('Primary Menu', 'qhost'),
                )
            );
        }

        public function enqueue_translation_files(){
            load_theme_textdomain('qhost', get_template_directory() . '/languages/');
        }

         public function sidebar_register(){
             
            // Default wrapper for widget and title
            $wrapper_before = '<div id="%1$s" class="widget qhost_widget %2$s">';
            $wrapper_after = '</div>';
            $title_before = '<h3 class="widget-title">';
            $title_after = '</h3>';
 
            register_sidebar( array(
                'name' => esc_html('Sidebar Main', 'qhost'),
                'id' => "sidebar_main-sidebar",
                'description' => esc_html__('Add widget here to appear it in sidebar.', 'qhost'),
                'before_widget' => $wrapper_before,
                'after_widget' => $wrapper_after,
                'before_title' => $title_before,
                'after_title' => $title_after,
            ));       
            

            // Register Footer Sidebar
            $footer_columns = array(
                array(
                    'name' => esc_html__( 'Footer Column 1', 'qhost' ),
                    'id' => 'footer_column_1'
                ),
                array(
                    'name' => esc_html__( 'Footer Column 2', 'qhost' ),
                    'id' => 'footer_column_2'
                ),
                array(
                    'name' => esc_html__( 'Footer Column 3', 'qhost' ),
                    'id' => 'footer_column_3'
                ),
                array(
                    'name' => esc_html__( 'Footer Column 4', 'qhost' ),
                    'id' => 'footer_column_4'
                ),
            );


            foreach ($footer_columns as $key => $footer_column) {
                register_sidebar( array(
                    'name'          => $footer_column['name'],
                    'id'            => $footer_column['id'],
                    'description' => esc_html__('This area will display in footer like a column. Add widget here to appear it in footer column.', 'qhost'),
                    'before_widget' => $wrapper_before,
                    'after_widget' => $wrapper_after,
                    'before_title' => $title_before,
                    'after_title' => $title_after,
                ));
            }
        }

        /**
		 * Set the content width in pixels, based on the theme's design and stylesheet.
		 *
		 * Priority 0 to make it available to lower priority callbacks.
		 *
		 * @global int $content_width
		 */
		function qhost_content_width() {
			// This variable is intended to be overruled from themes.
			// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
			// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
			$GLOBALS['content_width'] = apply_filters( 'qhost_content_width', 1170 );
		}

    }
    new Qhost_Theme_Support();
}
