<?php
// Control core classes for avoid errors
if ( class_exists( 'CSF' ) ) {

	// Set a unique slug-like ID
	$prefix = 'qhost_framework';


	// Create options
	CSF::createOptions( $prefix, array(
		'menu_title'      => esc_html__( 'Theme Option', 'qhost' ),
		'menu_slug'       => 'qhost-framework',
		'framework_title' => esc_html__( 'Theme Settings', 'qhost' ),
		'theme'           => 'light',
		'sticky_header'   => 'true',
	) );

	// General Setting
	CSF::createSection( $prefix, array(
		'title'  => esc_html__( 'General', 'qhost' ),
		'icon'   => 'fa fa-building-o',
		'fields' => array(
			array(
				'id'    => 'preloader_switch',
				'type'  => 'switcher',
				'title' => esc_html__( 'Enable Preloader', 'qhost' ),
			),
			array(
				'id'         => 'preloader-type',
				'type'       => 'select',
				'title'      => esc_html__( 'Preloader type', 'qhost' ),
				'options'    => array(
					'css'    => esc_html__( 'CSS', 'qhost' ),
					'images' => esc_html__( 'Media', 'qhost' )
				),
				'dependency' => array( 'preloader_switch', '==', true ),
			),
			array(
				'id'         => 'preloader-images',
				'type'       => 'media',
				'title'      => esc_html__( 'Preloader Image', 'qhost' ),
				'add_title'  => esc_html__( 'Upload Your Image', 'qhost' ),
				'dependency' => array( 'preloader_switch|preloader-type', '==', 'true|images' ),
			),
			array(
				'id'         => 'preloader',
				'type'       => 'select',
				'title'      => esc_html__( 'Preloader Style', 'qhost' ),
				'class'      => 'chosen',
				'dependency' => array( 'preloader_switch|preloader-type', '==', 'true|css' ),
				'options'    => array(
					'ball-pulse-3'                 => esc_html__( 'Ball Pulse', 'qhost' ),
					'ball-grid-pulse-9'            => esc_html__( 'Ball Grid Pulse', 'qhost' ),
					'ball-clip-rotate-1'           => esc_html__( 'Ball Clip Rotate', 'qhost' ),
					'ball-clip-rotate-pulse-2'     => esc_html__( 'Ball Clip Rotate Pulse', 'qhost' ),
					'ball-clip-rotate-multiple-2'  => esc_html__( 'Ball Clip Rotate Multiple', 'qhost' ),
					'ball-pulse-rise-6'            => esc_html__( 'Ball Pulse Rise', 'qhost' ),
					'ball-pulse-sync-3'            => esc_html__( 'Ball Pulse Sync', 'qhost' ),
					'ball-beat-3'                  => esc_html__( 'Ball Beat', 'qhost' ),
					'ball-grid-beat-9'             => esc_html__( 'Ball Gird Beat', 'qhost' ),
					'ball-rotate-1'                => esc_html__( 'Ball Rotate', 'qhost' ),
					'ball-zig-zag-2'               => esc_html__( 'Ball Zig-Zag', 'qhost' ),
					'ball-zig-zag-deflect-2'       => esc_html__( 'Ball-Zig-Zag Deflect', 'qhost' ),
					'ball-triangle-path-3'         => esc_html__( 'Ball Triangle Path', 'qhost' ),
					'ball-scale-1'                 => esc_html__( 'Ball Scale', 'qhost' ),
					'ball-scale-ripple-1'          => esc_html__( 'Ball Scale Ripple', 'qhost' ),
					'ball-scale-multiple-3'        => esc_html__( 'Ball Scale Multiple', 'qhost' ),
					'ball-scale-ripple-multiple-3' => esc_html__( 'Ball Scale Ripple Multiple', 'qhost' ),
					'ball-spin-fade-loader-8'      => esc_html__( 'Ball Spin Fade Loader', 'qhost' ),
					'square-spin-1'                => esc_html__( 'Square Spin', 'qhost' ),
					'cube-transition-2'            => esc_html__( 'Cube Transition', 'qhost' ),
					'line-scale-5'                 => esc_html__( 'Line Scale', 'qhost' ),
					'line-scale-party-4'           => esc_html__( 'Line Scale Party', 'qhost' ),
					'line-scale-pulse-out-5'       => esc_html__( 'Line Scale Pulse Out', 'qhost' ),
					'line-scale-pulse-out-rapid-5' => esc_html__( 'Line Scale Pulse Out Rapid', 'qhost' ),
					'line-spin-fade-loader-8'      => esc_html__( 'Line Spin Fade Loader', 'qhost' ),
					'triangle-skew-spin-1'         => esc_html__( 'Triangle Skew Spin', 'qhost' ),
					'pacman-5'                     => esc_html__( 'Pacman', 'qhost' ),
					'semi-circle-spin-5'           => esc_html__( 'Semi Circle Spin', 'qhost' ),
				),
			),
			array(
				'id'         => 'preloader_color',
				'title'      => esc_html__( 'Preloader background', 'qhost' ),
				'type'       => 'color',
				'default'    => 'rgba(150,41,230,0.97)',
				'dependency' => array( 'preloader_switch', '==', 'true' ),
			),
			array(
				'id'      => 'back_to_top',
				'type'    => 'switcher',
				'title'   => esc_html__( 'Display Back To Top Button', 'qhost' ),
				'default' => true
			),
			array(
				'id'      => 'smooth_scroll',
				'type'    => 'switcher',
				'title'   => esc_html__( 'Enable Enable/Disable Smooth Scroll', 'qhost' ),
				'default' => false
			),
			array(
				'id'       => 'custom-css',
				'type'     => 'code_editor',
				'title'    => 'CSS Editor',
				'settings' => array(
					'theme' => 'mbo',
					'mode'  => 'css',
				),
				'default'  => '.element{ color: #ffbc00; }',
			)
		)
	) );


	// Header Setting
	CSF::createSection( $prefix, array(
		'title'  => esc_html__( 'Header', 'qhost' ),
		'icon'   => 'fa fa-home',
		'fields' => array(

			array(
				'id'      => 'header_sticky',
				'type'    => 'switcher',
				'title'   => esc_html__( 'Enable Header Sticky', 'qhost' ),
				'default' => true,
			),

			array(
				'type'    => 'text',
				'title'   => esc_html__( 'Responsive Menu', 'qhost' ),
				'id'      => 'nav_btn_link',
				'default' => '992',
			),

			array(
				'id'      => 'nav_button_switch',
				'type'    => 'switcher',
				'title'   => esc_html__( 'Nav Button Show/Hide', 'qhost' ),
				'default' => false,
			),

			array(
				'type'       => 'text',
				'title'      => esc_html__( 'Nav Button Link', 'qhost' ),
				'id'         => 'nav_btn_link',
				'default'    => '#',
				'dependency' => array( 'nav_button_switch', '==', true ),
			),

			array(
				'type'       => 'text',
				'title'      => esc_html__( 'Nav Button Text', 'qhost' ),
				'id'         => 'nav_btn_text',
				'default'    => __( " Client Area", "qhost" ),
				'dependency' => array( 'nav_button_switch', '==', true ),
			),

			array(
				'type'    => 'subheading',
				'content' => esc_html__( 'Logo Settings', 'qhost' ),
			),

			array(
				'id'        => 'main_logo',
				'type'      => 'media',
				'title'     => esc_html__( 'Main Logo', 'qhost' ),
				'add_title' => esc_html__( 'Upload', 'qhost' ),
				'desc'      => esc_html__( 'Upload logo for Header', 'qhost' ),
			),

			array(
				'id'        => 'retina_logo',
				'type'      => 'media',
				'title'     => esc_html__( 'Main Retina Logo @2x', 'qhost' ),
				'add_title' => esc_html__( 'Upload', 'qhost' ),
				'desc'      => esc_html__( 'Upload logo for Header', 'qhost' ),
			),

			array(
				'id'        => 'sticky_logo',
				'type'      => 'media',
				'title'     => esc_html__( 'Sticky Logo', 'qhost' ),
				'desc'      => esc_html__( 'Upload logo for Header Sticky and Inner Page.', 'qhost' ),
				'add_title' => esc_html__( 'Upload', 'qhost' ),
			),

			array(
				'id'        => 'retina_logo_sticky',
				'type'      => 'media',
				'title'     => esc_html__( 'Sticky Retina Logo @2x', 'qhost' ),
				'desc'      => esc_html__( 'Upload Retina logo for Header Sticky.', 'qhost' ),
				'add_title' => esc_html__( 'Upload', 'qhost' ),
			),

			array(
				'type'    => 'heading',
				'content' => esc_html__( 'Header Menu Style', 'qhost' ),
			),

			array(
				'id'     => 'menu_color',
				'type'   => 'color',
				'title'  => esc_html__( 'Menu Text Color', 'qhost' ),
				'desc'   => esc_html__( 'You can change menu text color.', 'qhost' ),
				'output' => array(
					'color'        => '
					.site-header .site-main-menu li > a, 
					.menu-transperant .site-header .site-main-menu li > a,
					.site-header.header-one .site-main-menu li > a,
					.site-header .header-inner .site-nav.nav-two .nav-right .nav-btn',
					'border-color' => '.site-header .header-inner .site-nav.nav-two .nav-right .nav-btn,'
				)
			),

			array(
				'id'     => 'menu_color_hover',
				'type'   => 'color',
				'title'  => esc_html__( 'Menu Text Hover Color', 'qhost' ),
				'desc'   => esc_html__( 'You can change menu text hover color.', 'qhost' ),
				'output' => array(
					'color' => '
					.site-header .site-main-menu li > a:hover, 
					.menu-transperant .site-header .site-main-menu li > a:hover, 
					.site-header .site-main-menu li > a:after,
					.site-header .site-main-menu li.current_page_item a,
					.site-header .header-inner .site-nav .nav-right .nav-btn,
					.site-header.pix-header-fixed .header-inner .site-nav .nav-right .nav-btn,
					.site-header .header-inner .site-nav.nav-two .nav-right .nav-btn,
					.site-header.pix-header-fixed .header-inner .site-nav.nav-two .nav-right .nav-btn',

					'background' => '.site-header .site-main-menu li > a:after, 
					.site-header .site-main-menu li > a:hover:after, 
					.site-header .site-main-menu li > a.current_page:after,
					.site-header.pix-header-fixed .header-inner .site-nav .nav-right .nav-btn:hover,
					.site-header .header-inner .site-nav.nav-two .nav-right .nav-btn:hover',

					'border-color' => '.site-header.pix-header-fixed .header-inner .site-nav .nav-right .nav-btn,
					.site-header .header-inner .site-nav.nav-two .nav-right .nav-btn,
					.site-header.pix-header-fixed .header-inner .site-nav.nav-two .nav-right .nav-btn,
					.site-header .header-inner .site-nav.nav-two .nav-right .nav-btn:hover'
				)
			),
			array(
				'id'     => 'menu_color_dropdown',
				'type'   => 'color',
				'title'  => esc_html__( 'Menu Dropdown Text Color', 'qhost' ),
				'desc'   => esc_html__( 'You can change menu text color.', 'qhost' ),
				'output' => '.site-header .site-main-menu li .sub-menu li a, .menu-transperant .site-header .site-main-menu li .sub-menu li a'
			),

			array(
				'id'               => 'menu_color_hover_dropdown',
				'type'             => 'color',
				'title'            => esc_html__( 'Menu Dropdown Text Hover Color', 'qhost' ),
				'desc'             => esc_html__( 'You can change menu text hover color.', 'qhost' ),
				'output'           => array(
					'color' => '.site-header .site-main-menu li .sub-menu li a:hover, 
					.menu-transperant .site-header .site-main-menu li .sub-menu li a:hover,
					.site-header .site-main-menu li.current-menu-parent .current_page_item > a,
					.site-header.pix-header-fixed .header-inner .site-nav.nav-two .site-main-menu li a:hover,
					.site-header.pix-header-fixed .site-main-menu li.current_page_item a,
					.site-header.pix-header-fixed .header-inner .site-nav.nav-two .nav-right .nav-btn',

					'background'   => '.site-header.pix-header-fixed .header-inner .site-nav.nav-two .nav-right .nav-btn:hover',
					'border-color' => '.site-header.pix-header-fixed .header-inner .site-nav.nav-two .nav-right .nav-btn, 
					.site-header.pix-header-fixed .header-inner .site-nav.nav-two .nav-right .nav-btn:hover'

				),
				'output_important' => true
			),

			array(
				'type'    => 'subheading',
				'content' => esc_html__( 'Header Sticky Menu Style', 'qhost' ),
			),

			array(
				'id'     => 'sticky_menu_color',
				'type'   => 'color',
				'title'  => esc_html__( 'Menu Text Color', 'qhost' ),
				'desc'   => esc_html__( 'You can change menu text color.', 'qhost' ),
				'output' => '.site-header.pix-header-fixed .site-main-menu li a, .site-header.pix-header-fixed .site-main-menu li .sub-menu li a'
			),

			array(
				'id'        => 'sticky_menu_color_hover',
				'type'      => 'color',
				'title'     => esc_html__( 'Menu Text Hover Color', 'qhost' ),
				'desc'      => esc_html__( 'You can change menu text hover color.', 'qhost' ),
				'add_title' => esc_html__( 'Upload', 'qhost' ),
				'output'    => array(
					'color' => '
					.site-header.pix-header-fixed .site-main-menu li a:hover, 
					.site-header.pix-header-fixed .site-main-menu li a.current_page,
					.site-header.pix-header-fixed .site-main-menu li .sub-menu li a:hover, 
					.site-header.pix-header-fixed .site-main-menu li .sub-menu li a.current_page',

				)
			),
		)
	) );

	//Footer Setting
	CSF::createSection( $prefix, array(
		'title'  => esc_html__( 'Footer', 'qhost' ),
		'icon'   => 'fa fa-support',
		'fields' => array(

			array(
				'id'    => 'copyright_text',
				'type'  => 'textarea',
				'title' => esc_html__( 'Copyright Text', 'qhost' ),
			),

			array(
				'type'    => 'subheading',
				'content' => esc_html__( ' Footer Style', 'qhost' ),
			),

			array(
				'id'          => 'footer_bg_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Footer Background Color', 'qhost' ),
				'output'      => '.site-footer',
				'output_mode' => 'background',
			),	

			array(
				'id'     => 'footer__overlay_bg',
				'type'   => 'background',
				'title'  => esc_html__( 'Header Background', 'qhost' ),
				'desc'   => esc_html__( 'Default: Featured image, if fail will get image from global settings.', 'qhost' ),
				'output' => '.footer-overlay',
			),

			array(
				'id'     => 'footer-widget',
				'type'   => 'color',
				'title'  => esc_html__( 'Widget Title Color', 'qhost' ),
				'output' => '.site-footer .widget-title',
			),

			array(
				'id'     => 'footer-widget-content',
				'type'   => 'color',
				'title'  => esc_html__( 'Widget Content Color', 'qhost' ),
				'output' => '.site-footer .widget p, .site-footer .site-info .copyright p',
			),

			array(
				'id'     => 'footer-link',
				'type'   => 'color',
				'title'  => esc_html__( 'Link Color', 'qhost' ),
				'output' => '.site-footer .widget ul li a',
			),
			array(
				'id'     => 'footer-link-hover',
				'type'   => 'color',
				'title'  => esc_html__( 'Link Color Hover', 'qhost' ),
				'output' => array(
					'background' => '.site-footer .widget ul.menu li a:after',
					'color'      => '.site-footer .widget ul.menu li a:hover',
				)
			),

			array(
				'type'    => 'subheading',
				'content' => esc_html__( ' Spacing', 'qhost' ),
			),

			array(
				'id'          => 'footer_padding_top',
				'type'        => 'spacing',
				'title'       => __( 'Padding Top/Bottom', 'qhost' ),
				'output'      => '.site-footer .footer-wrapper',
				'output_mode' => 'padding', //
				'left'        => false,
				'right'       => false,
				'default'     => array(
					'top'    => '95',
					'bottom' => '30',
					'unit'   => 'px',
				),
			),

		)
	) );

	//Page Header
	CSF::createSection( $prefix, array(
		'title'  => esc_html__( 'Page Header', 'qhost' ),
		'icon'   => 'fa fa-picture-o',
		'fields' => array(

			array(
				'type'    => 'subheading',
				'content' => esc_html__( ' Page Header Settings', 'qhost' ),
			),
			array(
				'id'      => 'page_header',
				'type'    => 'switcher',
				'title'   => esc_html__( 'Page Header Enable', 'qhost' ),
				'default' => true,
			),


			array(
				'id'         => 'header-background',
				'type'       => 'color',
				'title'      => 'Background Color',
				'dependency' => array( 'page_header_style_main', '==', 'partical_main' ),
				'output'     => [
					'background' => '.page-banner.header-particle, .page-banner.blog-details-banner',
				]
			),

			array(
				'id'      => 'banner_height',
				'type'    => 'slider',
				'title'   => 'Banner Height',
				'min'     => 250,
				'max'     => 550,
				'step'    => 1,
				'unit'    => 'px',
				'default' => 550,
			),

			array(
				'id'    => 'page_header_default_title',
				'type'  => 'text',
				'title' => esc_html__( 'Default Title', 'qhost' ),
				'desc'  => esc_html__( 'Set the default title for the page header', 'qhost' ),
			),
			array(
				'id'     => 'custom_title_typography',
				'type'   => 'typography',
				'title'  => esc_html__( 'Title Typography', 'qhost' ),
				'output' => array(
					'color' => '.page-banner .page-title-wrapper .page-title, .page-banner .saaspik_breadcrumbs li a',
				),
			),
			array(
				'id'     => 'page_header_image',
				'type'   => 'background',
				'title'  => esc_html__( 'Header Background', 'qhost' ),
				'desc'   => esc_html__( 'Default: Featured image, if fail will get image from global settings.', 'qhost' ),
				'output' => '.page-header-bg',
			),

			array(
				'id'    => 'right_image',
				'type'  => 'media',
				'title' => esc_html__('Upload Right Image', 'qhost'),
			),
		)
	) );

	//Blog Setting
	CSF::createSection( $prefix, array(
		'title'  => esc_html__( 'Blog', 'qhost' ),
		'icon'   => 'fa fa-file-text-o',
		'fields' => array(

			array(
				'id'         => 'blog-masonry-column',
				'type'       => 'image_select',
				'title'      => esc_html__( 'Columns', 'qhost' ),
				'desc'       => esc_html__( 'Display number of post per row', 'qhost' ),
				'radio'      => true,
				'options'    => array(
					'6' => KHOST_THEME_URI . '/assets/images/layout/2cols.png',
					'4' => KHOST_THEME_URI . '/assets/images/layout/3cols.png',
				),
				'default'    => '6',
				'dependency' => array( 'blog-style_masonry', '==', true ),
			),

			array(
				'id'      => 'blog_sidebar_layout',
				'type'    => 'image_select',
				'title'   => esc_html__( 'Layout', 'qhost' ),
				'radio'   => true,
				'options' => array(
					'left'       => KHOST_THEME_URI . '/assets/images/layout/left-sidebar.png',
					'no-sidebar' => KHOST_THEME_URI . '/assets/images/layout/no-sidebar.png',
					'right'      => KHOST_THEME_URI . '/assets/images/layout/right-sidebar.png',
				),
				'default' => 'right',
			),

			array(
				'id'       => 'blog_sidebar_def_width',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Blog Archive Sidebar Width', 'qhost' ),
				'options'  => array(
					'9' => '25%',
					'8' => '33%',
				),
				'default'  => '8',
				'required' => array( 'blog_sidebar_layout', '!=', 'none' ),
			),

			array(
				'id'       => 'blog_sidebar_gap',
				'type'     => 'select',
				'title'    => esc_html__( 'Blog Archive Sidebar Side Gap', 'qhost' ),
				'options'  => array(
					'def' => 'Default',
					'0'   => '0',
					'15'  => '15',
					'20'  => '20',
					'25'  => '25',
					'30'  => '30',
					'35'  => '35',
					'40'  => '40',
					'45'  => '45',
					'50'  => '50',
				),
				'default'  => '45',
				'required' => array( 'blog_sidebar_layout', '!=', 'none' ),
			),

			array(
				'id'      => 'author_info',
				'type'    => 'switcher',
				'title'   => esc_html__( 'Display Author Bio Box', 'qhost' ),
				'default' => false
			),

			array(
				'id'      => 'share_post',
				'type'    => 'switcher',
				'title'   => esc_html__( 'Share On Post', 'qhost' ),
				'default' => false
			),

			array(
				'id'      => 'blog_list_meta_author',
				'type'    => 'switcher',
				'title'   => esc_html__( 'Hide post-meta author?', 'qhost' ),
				'default' => true,
			),
			array(
				'id'      => 'blog_list_meta_comments',
				'type'    => 'switcher',
				'title'   => esc_html__( 'Hide post-meta comments?', 'qhost' ),
				'default' => true,
			),
			array(
				'id'      => 'blog_list_meta_categories',
				'type'    => 'switcher',
				'title'   => esc_html__( 'Hide post-meta categories?', 'qhost' ),
				'default' => true,
			),
			array(
				'id'      => 'blog_list_meta_date',
				'type'    => 'switcher',
				'title'   => esc_html__( 'Hide post-meta date?', 'qhost' ),
				'default' => true,
			),


			array(
				'id'     => 'single_post_page_header_image',
				'type'   => 'background',
				'title'  => esc_html__( 'Header Background', 'qhost' ),
				'desc'   => esc_html__( 'Default: Featured image, if fail will get image from global settings.', 'qhost' ),
				'output' => '.single-post-header-bg',
			),

		)
	) );


	//Social Link
	CSF::createSection( $prefix, array(
		'title'  => esc_html__( 'Social Link', 'qhost' ),
		'icon'   => 'fa fa-globe',
		'desc'   => esc_html__( 'This social profiles will display in your whole site.', 'qhost' ),
		'fields' => array(

			array(
				'id'           => 'social_links',
				'type'         => 'group',
				'title'        => esc_html__( 'Saaspik Social links', 'qhost' ),
				'desc'         => esc_html__( 'This social profiles will display in your whole site.', 'qhost' ),
				'button_title' => esc_html__( 'Add New', 'qhost' ),
				'fields'       => array(

					array(
						'id'    => 'name',
						'type'  => 'text',
						'title' => esc_html__( 'Name', 'qhost' ),
					),
					array(
						'id'    => 'url',
						'type'  => 'text',
						'title' => esc_html__( 'Url', 'qhost' )
					),
					array(
						'id'    => 'icon',
						'type'  => 'icon',
						'title' => esc_html__( 'Icon', 'qhost' )
					)

				),

				'default' => array(
					array(
						'name' => esc_html__( 'Facebook', 'qhost' ),
						'url'  => esc_url( 'http://facebook.com' ),
						'icon' => 'ti-facebook'
					),

					array(
						'name' => esc_html__( 'Twitter', 'qhost' ),
						'url'  => esc_url( 'http://twitter.com' ),
						'icon' => 'ti-twitter-alt'
					),

					array(
						'name' => esc_html__( 'Dribbble', 'qhost' ),
						'url'  => esc_url( 'http://dribbble.com' ),
						'icon' => 'ti-dribbble'
					)

				),
				array(
					'type'    => 'notice',
					'class'   => 'info',
					'content' => esc_html__( 'This social profiles will display in your whole site.', 'qhost' ),
				),
			),
		)
	) );

	//Error Page
	CSF::createSection($prefix, array(
		'title' => esc_html__('404 Page', 'qhost'),
		'icon' => 'fa fa-exclamation',
		'fields' => array(

			array(
				'id' => 'error_image',
				'type' => 'media',
				'title' => esc_html__('Image', 'qhost'),
				'add_title' => esc_html__('Upload', 'qhost'),               
			),

			array(
				'type' => 'text',
				'title' => esc_html__('Error Title', 'qhost'),
				'id' => 'error_title',               
				'default' => esc_html__('Page not Found', 'qhost'),
			),

			array(
				'type' => 'textarea',
				'title' => esc_html__('Description', 'qhost'),
				'id' => 'error_description',                
				'default' => esc_html__('There many variations of passages available but the majority have suffered alteration in that that injected humour.', 'qhost'),
			),
		)
	));

	//Typography
	CSF::createSection( $prefix, array(
		'title'  => esc_html__( 'Typography', 'qhost' ),
		'icon'   => 'fa fa-font',
		'fields' => array(
			array(
				'type'    => 'subheading',
				'content' => esc_html__( 'Body Font Settings', 'qhost' ),
			),

			array(
				'id'      => 'body-font',
				'type'    => 'typography',
				'title'   => esc_html__( 'Body', 'qhost' ),
				'output'  => 'body',
				'default' => array(
					'color'       => '#777983',
					'font-size'   => '16',
					'line-height' => '28',
					'unit'        => 'px',
					'type'        => 'google',
				),
			),
			array(
				'type'    => 'subheading',
				'content' => esc_html__( 'Heading Font Settings', 'qhost' ),
			),
			array(
				'id'      => 'heading-h1',
				'type'    => 'typography',
				'title'   => esc_html__( 'Heading H1', 'qhost' ),
				'output'  => 'h1',
				'default' => array(
					'font-size' => '40',
					'unit'      => 'px',
					'type'      => 'google',
				),
			),
			array(
				'id'      => 'heading-h2',
				'type'    => 'typography',
				'title'   => esc_html__( 'Heading H2', 'qhost' ),
				'output'  => 'h2',
				'default' => array(
					'font-size' => '32',
					'unit'      => 'px',
					'type'      => 'google',
				),
			),
			array(
				'id'      => 'heading-h3',
				'type'    => 'typography',
				'title'   => esc_html__( 'Heading H3', 'qhost' ),
				'output'  => 'h3',
				'default' => array(
					'font-size' => '28',
					'unit'      => 'px',
					'type'      => 'google',
				),
			),
			array(
				'id'      => 'heading-h4',
				'type'    => 'typography',
				'title'   => esc_html__( 'Heading H4', 'qhost' ),
				'output'  => 'h4',
				'default' => array(
					'font-size' => '24',
					'unit'      => 'px',
					'type'      => 'google',
				),
			),
			array(
				'id'      => 'heading-h5',
				'type'    => 'typography',
				'title'   => esc_html__( 'Heading H5', 'qhost' ),
				'output'  => 'h5',
				'default' => array(
					'font-size' => '20',
					'unit'      => 'px',
					'type'      => 'google',
				),
			),

			array(
				'id'      => 'heading-h6',
				'type'    => 'typography',
				'title'   => esc_html__( 'Heading H6', 'qhost' ),
				'output'  => 'h6',
				'default' => array(
					'font-size' => '16',
					'unit'      => 'px',
					'type'      => 'google',
				),
			),

		)
	) );

	//Color Scheme
	CSF::createSection( $prefix, array(
		'title'  => esc_html__( 'Color Scheme', 'qhost' ),
		'icon'   => 'fa fa-star',
		'icon'   => 'fa fa-paint-brush',
		'fields' => array(

			array(
				'type'    => 'subheading',
				'content' => esc_html__( 'General Color', 'qhost' ),
			),

			array(
				'id'     => 'body-color',
				'type'   => 'color',
				'title'  => esc_html__( 'Body Color', 'qhost' ),
				'output' => 'body'
			),

			array(
				'id'     => 'main_heading-color',
				'type'   => 'color',
				'title'  => esc_html__( 'Heading Color', 'qhost' ),
				'output' => '
				h1,h2,h3,h4,h5,h6, .blog-content .entry-title a, .tt-icon-box .box-title, .pricing-table .price-feture li span, .blog-post-list .entry-content .entry-title a',
			),

			array(
				'id'     => 'main_primary-color',
				'type'   => 'color',
				'title'  => esc_html__( 'Primary Color', 'qhost' ),
				'desc'   => esc_html__( 'Main Color Scheme', 'qhost' ),
				'output' => array(
					'color'            => '
						.tt-btn:hover, .tt-app-btn.btn-outline, .tt-app-btn.btn-light, .tt-app-btn.btn-light.btn-outline:hover, .tt-app-btn:hover, .tt-icon-box .box-title:hover, .tt-icon-box .box-title a:hover, .tt-btn.btn-outline, .tt-process-box .icon-container, 
						.pricing-switch-wrap span.afterinput.active,
						.pricing-switch-wrap span.beforeinput.active, .pricing-table .pricing-header .price, .post-grid .blog-content .entry-title a:hover, .post-meta li i, .post-meta li a:hover,
						a:hover, a:focus, a:active, .tt-blog-posts .post-grid .blog-content .read_more_btn:hover i, .tt-icon-box.style-six .icon-container, .single_faq_content h4 span,
						.tt-icon-box.style-two .icon-container, .tt-list li i, .team-member .member-social li a:hover, .tt-countdown-wrapper .tt-countdown .counter-icon, .site-footer .site-info .copyright p a:hover,
						.tt-icon-box .icon-container, .blog-post-list .entry-content .entry-title a:hover, .blog-post-list .post-meta-wrapper .post-meta i, .blog-post-list .post-meta-wrapper .post-meta a:hover,
						.blog-post-list .blog-footer .read-more:hover, .blog-post-list .blog-footer .read-more:hover i, .widget ul li a:hover, .apdash-widget-recent-posts .post-title a:hover,
						.comment-list .comment .comment-body .comment-reply-link:hover, .tt-btn.btn-outline,.tt-icon-box.style-four.with-image .icon-container i,
						.comment-form #submit:hover, .tt-btn.btn-light, .play-btn i, .banner--seven .banner-newsletter .promo-text, .popup-play-btn',
					'background'       => '
						.tt-btn,.tt-btn.btn-outline:hover, .tt-list.list-dice li:before, .tt-icon-box.style-four .icon-container, .newsletter-form .newsletter-submit,
						.tt-app-btn, .tt-app-btn.btn-outline:hover, .tagcloud a:hover, .tt-icon-box.style-four.with-image .icon-container i:hover, .tt-icon-box.style-nine:hover,
						.popup-play-btn:hover',
					'background-color' => '.pricing-switch-wrap .switch-icon:after, .tt-icon-box.style-two:hover:before, .tt-icon-box.style-two:before, blockquote:before, blockquote:after,
                    .comment-form #submit, .banner--six .banner-contact-form .tt-btn, .banner--seven .banner-newsletter .banner-newsletter-form .newsletter-submit',
					'border-color'     => '
						.tt-btn, .tt-btn.btn-outline, .pricing-switch-wrap .switch-icon, .tt-icon-box.style-six .icon-container, .tt-app-btn, .tt-icon-box.style-one:hover,
						.tagcloud a:hover, .widget_search .search-form input:focus, .comment-form #submit:hover, .comment-form input[type="text"]:focus, .comment-form textarea:focus,
						.tt-icon-box.style-four.with-image .icon-container i, .banner--six .banner-contact-form .tt-btn, .banner--seven .banner-newsletter .banner-newsletter-form .newsletter-submit,
						.banner--seven .banner-newsletter, .pricing-table:hover, .pricing-table.featured',

					'border-right-color' => '.pricing-table.featured .trend:before, .advanced-pricing-table .pricing-table.featured .trend:before'
				),
			),

			array(
				'id'     => 'saspik-link-color',
				'type'   => 'link_color',
				'title'  => 'Link Color',
				'color'  => true,
				'hover'  => true,
				'focus'  => true,
				'output' => '.post .author a, .product .author a, 
				.post .blog-content .read-more, .post .blog-content .post-meta li a:hover,
				.product .blog-content .read-more'
			),

			array(
				'type'    => 'subheading',
				'content' => esc_html__( 'Section Background Color', 'qhost' ),
			),

			array(
				'id'      => 'gradient_on_off',
				'type'    => 'button_set',
				'title'   => esc_html__( 'Use Theme Gradient?', 'qhost' ),
				'options' => array(
					'on'  => esc_html__( 'On', 'qhost' ),
					'off' => esc_html__( 'Off', 'qhost' ),
				),
				'default' => 'on'
			),

			array(
				'id'                    => 'section_background',
				'type'                  => 'background',
				'title'                 => 'Background Gradient Color',
				'background_color'      => true,
				'background_gradient'   => true,
				'background_image'      => false,
				'background_position'   => false,
				'background_repeat'     => false,
				'background_attachment' => false,
				'background_size'       => false,
				'background_origin'     => false,
				'background_clip'       => false,
				'background_blend-mode' => false,
				'default'               => array(
					'background-gradient-direction' => 'to left',
				),
				'output'                => '.call-to-action, .section-bg, .bg-angle, .banner.banner-one, .newsletter, .newsletter-two',
				'output_important'      => true,
				'dependency'            => array( 'gradient_on_off', '==', 'on' ),
			),

			array(
				'id'               => 'section-bg-color',
				'type'             => 'color',
				'title'            => esc_html__( 'Background Color', 'qhost' ),
				'output'           => array(
					'background' => '.call-to-action, .section-bg, .bg-angle, .newsletter, .newsletter-two'
				),
				'output_important' => true,
			),
		)
	) );

	//Backup
	CSF::createSection( $prefix, array(
		'title'  => esc_html__( 'Backup', 'qhost' ),
		'icon'   => 'fa fa-download',
		'fields' => array(
			array(
				'type' => 'backup',
			),
		)
	) );
}